Class: Anthropic::Helpers::Streaming::ContentBlockStopEvent
- Inherits:
-
Models::RawContentBlockStopEvent
- Object
- Internal::Type::BaseModel
- Models::RawContentBlockStopEvent
- Anthropic::Helpers::Streaming::ContentBlockStopEvent
- Defined in:
- lib/anthropic/helpers/streaming/events.rb,
sig/anthropic/helpers/streaming/events.rbs
Instance Attribute Summary collapse
-
#content_block ⇒ Anthropic::Models::TextBlock, Anthropic::Models::ToolUseBlock
The completed content block when streaming for this block ends.
-
#index ⇒ Integer
The index of the content block that has stopped streaming.
- #type ⇒ Symbol, :content_block_stop
Instance Method Summary collapse
- #initialize ⇒ Object constructor
Methods inherited from Models::RawContentBlockStopEvent
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
109 |
# File 'sig/anthropic/helpers/streaming/events.rbs', line 109
def initialize: (
|
Instance Attribute Details
#content_block ⇒ Anthropic::Models::TextBlock, Anthropic::Models::ToolUseBlock
The completed content block when streaming for this block ends.
150 |
# File 'lib/anthropic/helpers/streaming/events.rb', line 150 required :content_block, Anthropic::Models::ContentBlock |
#index ⇒ Integer
The index of the content block that has stopped streaming.
139 |
# File 'lib/anthropic/helpers/streaming/events.rb', line 139 required :index, Integer |
#type ⇒ Symbol, :content_block_stop
144 |
# File 'lib/anthropic/helpers/streaming/events.rb', line 144 required :type, const: :content_block_stop |