Module: Anthropic::Models::Beta::AgentCreateParams::Tool

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/agent_create_params.rb,
sig/anthropic/models/beta/agent_create_params.rbs

Overview

Union type for tool configurations in the tools array.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentToolset20260401Params, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Some parameter documentations has been truncated, see Anthropic::Models::Beta::AgentCreateParams::Tool for more details.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [ArrayAnthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams, ArrayAnthropic::Models::Beta::BetaManagedAgentsMCPToolConfigParams] :configs Per-tool configuration overrides.

    @option args [Anthropic::Models::Beta::BetaManagedAgentsAgentToolsetDefaultConfigParams, nil, Anthropic::Models::Beta::BetaManagedAgentsMCPToolsetDefaultConfigParams, nil] :default_config Default configuration for all tools in a toolset.

    @option args [String] :mcp_server_name Name of the MCP server. Must match a server name from the mcp_servers array. 1-2

    @option args [String] :description Description of what the tool does, shown to the agent to help it decide when to

    @option args [Anthropic::Models::Beta::BetaManagedAgentsCustomToolInputSchema] :input_schema JSON Schema for custom tool input parameters.

    @option args [String] :name Unique name for the tool. 1-128 characters; letters, digits, underscores, and hy

Returns:

Raises:

  • (ArgumentError)


170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/anthropic/models/beta/agent_create_params.rb', line 170

def self.new(type:, **args)
  case type.to_sym
  when :agent_toolset_20260401
    Anthropic::Beta::BetaManagedAgentsAgentToolset20260401Params.new(**args)
  when :mcp_toolset
    Anthropic::Beta::BetaManagedAgentsMCPToolsetParams.new(**args)
  when :custom
    Anthropic::Beta::BetaManagedAgentsCustomToolParams.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::AgentCreateParams::tool]

Returns:

  • (::Array[Anthropic::Models::Beta::AgentCreateParams::tool])


107
# File 'sig/anthropic/models/beta/agent_create_params.rbs', line 107

def self?.variants: -> ::Array[Anthropic::Models::Beta::AgentCreateParams::tool]