Class: Anthropic::Models::Beta::BetaAdvisorTool20260301

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_advisor_tool_20260301.rb

Defined Under Namespace

Modules: AllowedCaller

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(model:, allowed_callers: nil, cache_control: nil, caching: nil, defer_loading: nil, max_uses: nil, strict: nil, name: :advisor, type: :advisor_20260301) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaAdvisorTool20260301 for more details.

Parameters:

  • model (Symbol, String, Anthropic::Models::Model)

    The model that will complete your prompt.

  • allowed_callers (Array<Symbol, Anthropic::Models::Beta::BetaAdvisorTool20260301::AllowedCaller>) (defaults to: nil)
  • cache_control (Anthropic::Models::Beta::BetaCacheControlEphemeral, nil) (defaults to: nil)

    Create a cache control breakpoint at this content block.

  • caching (Anthropic::Models::Beta::BetaCacheControlEphemeral, nil) (defaults to: nil)

    Caching for the advisor’s own prompt. When set, each advisor call writes a cache

  • defer_loading (Boolean) (defaults to: nil)

    If true, tool will not be included in initial system prompt. Only loaded when re

  • max_uses (Integer, nil) (defaults to: nil)

    Maximum number of times the tool can be used in the API request.

  • strict (Boolean) (defaults to: nil)

    When true, guarantees schema validation on tool names and inputs

  • name (Symbol, :advisor) (defaults to: :advisor)

    Name of the tool.

  • type (Symbol, :advisor_20260301) (defaults to: :advisor_20260301)


# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 68

Instance Attribute Details

#allowed_callersArray<Symbol, Anthropic::Models::Beta::BetaAdvisorTool20260301::AllowedCaller>?



32
33
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 32

optional :allowed_callers,
-> { Anthropic::Internal::Type::ArrayOf[enum: Anthropic::Beta::BetaAdvisorTool20260301::AllowedCaller] }

#cache_controlAnthropic::Models::Beta::BetaCacheControlEphemeral?

Create a cache control breakpoint at this content block.



39
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 39

optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true

#cachingAnthropic::Models::Beta::BetaCacheControlEphemeral?

Caching for the advisor’s own prompt. When set, each advisor call writes a cache entry at the given TTL so subsequent calls in the same conversation read the stable prefix. When omitted, the advisor prompt is not cached.



47
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 47

optional :caching, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true

#defer_loadingBoolean?

If true, tool will not be included in initial system prompt. Only loaded when returned via tool_reference from tool search.

Returns:



54
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 54

optional :defer_loading, Anthropic::Internal::Type::Boolean

#max_usesInteger?

Maximum number of times the tool can be used in the API request.

Returns:

  • (Integer, nil)


60
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 60

optional :max_uses, Integer, nil?: true

#modelSymbol, ...

The model that will complete your prompt.

See [models](docs.anthropic.com/en/docs/models-overview) for additional details and options.

Returns:



14
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 14

required :model, union: -> { Anthropic::Model }

#nameSymbol, :advisor

Name of the tool.

This is how the tool will be called by the model and in ‘tool_use` blocks.

Returns:

  • (Symbol, :advisor)


22
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 22

required :name, const: :advisor

#strictBoolean?

When true, guarantees schema validation on tool names and inputs

Returns:



66
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 66

optional :strict, Anthropic::Internal::Type::Boolean

#typeSymbol, :advisor_20260301

Returns:

  • (Symbol, :advisor_20260301)


27
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 27

required :type, const: :advisor_20260301