Class: Anthropic::Models::Beta::BetaBrowserStateTabEntry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaBrowserStateTabEntry
- Defined in:
- lib/anthropic/models/beta/beta_browser_state_tab_entry.rb,
sig/anthropic/models/beta/beta_browser_state_tab_entry.rbs
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Whether this tab is the active tab after this call.
-
#tab_id ⇒ String
The caller-assigned identifier for this tab, unique within the inventory.
-
#title ⇒ String
The title of the page the tab is showing.
-
#url ⇒ String
The URL of the page the tab is showing.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
20 |
# File 'sig/anthropic/models/beta/beta_browser_state_tab_entry.rbs', line 20
def initialize: (
|
Instance Attribute Details
#active ⇒ Boolean?
Whether this tab is the active tab after this call. Whenever tabs is
non-empty, exactly one entry is marked active: true.
30 |
# File 'lib/anthropic/models/beta/beta_browser_state_tab_entry.rb', line 30 optional :active, Anthropic::Internal::Type::Boolean |
#tab_id ⇒ String
The caller-assigned identifier for this tab, unique within the inventory.
11 |
# File 'lib/anthropic/models/beta/beta_browser_state_tab_entry.rb', line 11 required :tab_id, String |
#title ⇒ String
The title of the page the tab is showing. May be empty.
17 |
# File 'lib/anthropic/models/beta/beta_browser_state_tab_entry.rb', line 17 required :title, String |
#url ⇒ String
The URL of the page the tab is showing. May be empty.
23 |
# File 'lib/anthropic/models/beta/beta_browser_state_tab_entry.rb', line 23 required :url, String |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/anthropic/models/beta/beta_browser_state_tab_entry.rbs', line 27
def to_hash: -> {
|