Class: Anthropic::Models::Beta::BetaCacheMissModelChanged

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_cache_miss_model_changed.rb,
sig/anthropic/models/beta/beta_cache_miss_model_changed.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



14
# File 'sig/anthropic/models/beta/beta_cache_miss_model_changed.rbs', line 14

def initialize: (

Instance Attribute Details

#cache_missed_input_tokensInteger

Approximate number of input tokens that would have been read from cache had the prefix matched the previous request.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


12
# File 'lib/anthropic/models/beta/beta_cache_miss_model_changed.rb', line 12

required :cache_missed_input_tokens, Integer

#typeSymbol, :model_changed

Parameters:

  • value (:model_changed)

Returns:

  • (Symbol, :model_changed)


17
# File 'lib/anthropic/models/beta/beta_cache_miss_model_changed.rb', line 17

required :type, const: :model_changed

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/anthropic/models/beta/beta_cache_miss_model_changed.rbs', line 19

def to_hash: -> {