Module: Anthropic::Models::Beta::BetaCitationsDelta::Citation

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_citations_delta.rb,
sig/anthropic/models/beta/beta_citations_delta.rbs

Overview

See Also:

  • Anthropic::Models::Beta::BetaCitationsDelta#citation

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCitationCharLocation, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaCitationsDelta::Citation for more details.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :cited_text The full text of the cited block range, concatenated.

    @option args [Integer] :document_index

    @option args [String, nil] :document_title

    @option args [Integer] :end_char_index

    @option args [String, nil] :file_id

    @option args [Integer] :start_char_index

    @option args [Integer] :end_page_number

    @option args [Integer] :start_page_number

    @option args [Integer] :end_block_index Exclusive 0-based end index of the cited block range in the source's content a

    @option args [Integer] :start_block_index 0-based index of the first cited block in the source's content array.

    @option args [String] :encrypted_index

    @option args [String, nil] :title

    @option args [String] :url

    @option args [Integer] :search_result_index 0-based index of the cited search result among all search_result content block

    @option args [String] :source

Returns:

Raises:

  • (ArgumentError)


82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/anthropic/models/beta/beta_citations_delta.rb', line 82

def self.new(type:, **args)
  case type.to_sym
  when :char_location
    Anthropic::Beta::BetaCitationCharLocation.new(**args)
  when :page_location
    Anthropic::Beta::BetaCitationPageLocation.new(**args)
  when :content_block_location
    Anthropic::Beta::BetaCitationContentBlockLocation.new(**args)
  when :web_search_result_location
    Anthropic::Beta::BetaCitationsWebSearchResultLocation.new(**args)
  when :search_result_location
    Anthropic::Beta::BetaCitationSearchResultLocation.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::BetaCitationsDelta::citation]

Returns:

  • (::Array[Anthropic::Models::Beta::BetaCitationsDelta::citation])


37
# File 'sig/anthropic/models/beta/beta_citations_delta.rbs', line 37

def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaCitationsDelta::citation]