Module: Anthropic::Models::Beta::BetaCloudConfig::Networking

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_cloud_config.rb,
sig/anthropic/models/beta/beta_cloud_config.rbs

Overview

Network configuration policy.

See Also:

  • Anthropic::Models::Beta::BetaCloudConfig#networking

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaUnrestrictedNetwork, Anthropic::Models::Beta::BetaLimitedNetwork

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaCloudConfig::Networking for more details.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [Boolean] :allow_mcp_servers Permits outbound access to MCP server endpoints configured on the agent, beyond

    @option args [Boolean] :allow_package_managers Permits outbound access to public package registries (PyPI, npm, etc.) beyond th

    @option args [Array] :allowed_hosts Specifies domains the container can reach.

Returns:

Raises:

  • (ArgumentError)


69
70
71
72
73
74
75
76
77
78
# File 'lib/anthropic/models/beta/beta_cloud_config.rb', line 69

def self.new(type:, **args)
  case type.to_sym
  when :unrestricted
    Anthropic::Beta::BetaUnrestrictedNetwork.new(**args)
  when :limited
    Anthropic::Beta::BetaLimitedNetwork.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::BetaCloudConfig::networking]

Returns:

  • (::Array[Anthropic::Models::Beta::BetaCloudConfig::networking])


39
# File 'sig/anthropic/models/beta/beta_cloud_config.rbs', line 39

def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaCloudConfig::networking]