Class: Anthropic::Models::Beta::BetaCompactionBlockParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaCompactionBlockParam
- Defined in:
- lib/anthropic/models/beta/beta_compaction_block_param.rb,
sig/anthropic/models/beta/beta_compaction_block_param.rbs
Defined Under Namespace
Modules: ToolChange
Instance Attribute Summary collapse
-
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
-
#content ⇒ String?
Summary of previously compacted content, or null if compaction failed.
-
#encrypted_content ⇒ String?
Opaque metadata from prior compaction, to be round-tripped verbatim.
-
#signature ⇒ String?
The block's signature as returned, to be sent back verbatim.
-
#tool_changes ⇒ Array<Anthropic::Models::Beta::BetaRequestToolAdditionBlock, Anthropic::Models::Beta::BetaRequestToolRemovalBlock>?
The tool changes of the compacted range, as the server returned them on this block: the
tool_additionandtool_removalentries that take the request'stoolsto the tool set in effect at the end of the range. - #type ⇒ Symbol, :compaction
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
29 |
# File 'sig/anthropic/models/beta/beta_compaction_block_param.rbs', line 29
def initialize: (
|
Instance Attribute Details
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
16 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 16 optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true |
#content ⇒ String?
Summary of previously compacted content, or null if compaction failed
22 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 22 optional :content, String, nil?: true |
#encrypted_content ⇒ String?
Opaque metadata from prior compaction, to be round-tripped verbatim
28 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 28 optional :encrypted_content, String, nil?: true |
#signature ⇒ String?
The block's signature as returned, to be sent back verbatim
34 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 34 optional :signature, String, nil?: true |
#tool_changes ⇒ Array<Anthropic::Models::Beta::BetaRequestToolAdditionBlock, Anthropic::Models::Beta::BetaRequestToolRemovalBlock>?
The tool changes of the compacted range, as the server returned them on this
block: the tool_addition and tool_removal entries that take the request's
tools to the tool set in effect at the end of the range. Send them back
unchanged with the block.
43 44 45 46 47 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 43 optional :tool_changes, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaCompactionBlockParam::ToolChange] }, nil?: true |
#type ⇒ Symbol, :compaction
10 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 10 required :type, const: :compaction |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/anthropic/models/beta/beta_compaction_block_param.rbs', line 38
def to_hash: -> {
|