Module: Anthropic::Models::Beta::BetaDocumentBlock::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_document_block.rb,
sig/anthropic/models/beta/beta_document_block.rbs
Overview
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaBase64PDFSource, Anthropic::Models::Beta::BetaPlainTextSource
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaBase64PDFSource, Anthropic::Models::Beta::BetaPlainTextSource)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaBase64PDFSource, Anthropic::Models::Beta::BetaPlainTextSource
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
64 65 66 67 68 69 70 71 72 73 |
# File 'lib/anthropic/models/beta/beta_document_block.rb', line 64 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Beta::BetaBase64PDFSource.new(**args) when :text Anthropic::Beta::BetaPlainTextSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaBase64PDFSource, Anthropic::Models::Beta::BetaPlainTextSource)
|
|
# File 'lib/anthropic/models/beta/beta_document_block.rb', line 48
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaDocumentBlock::source]
44 |
# File 'sig/anthropic/models/beta/beta_document_block.rbs', line 44
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaDocumentBlock::source]
|