Class: Anthropic::Models::Beta::BetaDreamModelConfigParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_dream_model_config_param.rb,
sig/anthropic/models/beta/beta_dream_model_config_param.rbs

Defined Under Namespace

Modules: Speed

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, speed: nil) ⇒ Object

Model identifier and configuration applied to every pipeline stage.

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaDreamModelConfigParam for more details.

Parameters:

  • Model identifier, e.g. "claude-opus-5". 1-256 characters.

  • (defaults to: nil)

    Inference speed mode. fast provides significantly faster output token generati



# File 'lib/anthropic/models/beta/beta_dream_model_config_param.rb', line 21


Instance Attribute Details

#idString

Model identifier, e.g. "claude-opus-5". 1-256 characters.

Parameters:

Returns:



11
# File 'lib/anthropic/models/beta/beta_dream_model_config_param.rb', line 11

required :id, String

#speedSymbol, ...

Inference speed mode. fast provides significantly faster output token generation at premium pricing. Not all models support fast; invalid combinations are rejected at create time.

Parameters:

Returns:



19
# File 'lib/anthropic/models/beta/beta_dream_model_config_param.rb', line 19

optional :speed, enum: -> { Anthropic::Beta::BetaDreamModelConfigParam::Speed }, nil?: true

Instance Method Details

#to_hash{

Returns:



22
# File 'sig/anthropic/models/beta/beta_dream_model_config_param.rbs', line 22

def to_hash: -> {