Module: Anthropic::Models::Beta::BetaEnvironment::Config
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_environment.rb,
sig/anthropic/models/beta/beta_environment.rbs
Overview
Environment configuration (either Anthropic Cloud or self-hosted)
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
125 126 127 128 129 130 131 132 133 134 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 125 def self.new(type:, **args) case type.to_sym when :cloud Anthropic::Beta::BetaCloudConfig.new(**args) when :self_hosted Anthropic::Beta::BetaSelfHostedConfig.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig)
|
|
# File 'lib/anthropic/models/beta/beta_environment.rb', line 109
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaEnvironment::config]
78 |
# File 'sig/anthropic/models/beta/beta_environment.rbs', line 78
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaEnvironment::config]
|