Module: Anthropic::Models::Beta::BetaFallbackParam::Thinking
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_fallback_param.rb,
sig/anthropic/models/beta/beta_fallback_param.rbs
Overview
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaThinkingConfigEnabled, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaThinkingConfigEnabled, Anthropic::Models::Beta::BetaThinkingConfigDisabled, Anthropic::Models::Beta::BetaThinkingConfigAdaptive)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaThinkingConfigEnabled, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaFallbackParam::Thinking for more details.
106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/anthropic/models/beta/beta_fallback_param.rb', line 106 def self.new(type:, **args) case type.to_sym when :enabled Anthropic::Beta::BetaThinkingConfigEnabled.new(**args) when :disabled Anthropic::Beta::BetaThinkingConfigDisabled.new(**args) when :adaptive Anthropic::Beta::BetaThinkingConfigAdaptive.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaThinkingConfigEnabled, Anthropic::Models::Beta::BetaThinkingConfigDisabled, Anthropic::Models::Beta::BetaThinkingConfigAdaptive)
|
|
# File 'lib/anthropic/models/beta/beta_fallback_param.rb', line 87
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaFallbackParam::thinking]
61 |
# File 'sig/anthropic/models/beta/beta_fallback_param.rbs', line 61
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaFallbackParam::thinking]
|