Class: Anthropic::Models::Beta::BetaImageBlockParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaImageBlockParam
- Defined in:
- lib/anthropic/models/beta/beta_image_block_param.rb,
sig/anthropic/models/beta/beta_image_block_param.rbs
Defined Under Namespace
Modules: Source
Instance Attribute Summary collapse
-
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
- #source ⇒ Anthropic::Models::Beta::BetaBase64ImageSource, ...
-
#transformations ⇒ Anthropic::Models::Beta::BetaImageTransformationsParam?
Configures the transformations the server applies to this image before the model observes it.
- #type ⇒ Symbol, :image
Instance Method Summary collapse
-
#initialize(source:, cache_control: nil, transformations: nil, type: :image) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaImageBlockParam for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(source:, cache_control: nil, transformations: nil, type: :image) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaImageBlockParam for more details.
|
|
# File 'lib/anthropic/models/beta/beta_image_block_param.rb', line 32
|
Instance Attribute Details
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
21 |
# File 'lib/anthropic/models/beta/beta_image_block_param.rb', line 21 optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true |
#source ⇒ Anthropic::Models::Beta::BetaBase64ImageSource, ...
10 |
# File 'lib/anthropic/models/beta/beta_image_block_param.rb', line 10 required :source, union: -> { Anthropic::Beta::BetaImageBlockParam::Source } |
#transformations ⇒ Anthropic::Models::Beta::BetaImageTransformationsParam?
Configures the transformations the server applies to this image before the model observes it. Each key names a condition the server transforms images for; its value selects the transformation applied. Omitted keys keep their default behavior, and an empty object is equivalent to omitting the field.
30 |
# File 'lib/anthropic/models/beta/beta_image_block_param.rb', line 30 optional :transformations, -> { Anthropic::Beta::BetaImageTransformationsParam }, nil?: true |
#type ⇒ Symbol, :image
15 |
# File 'lib/anthropic/models/beta/beta_image_block_param.rb', line 15 required :type, const: :image |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/anthropic/models/beta/beta_image_block_param.rbs', line 30
def to_hash: -> {
|