Module: Anthropic::Models::Beta::BetaIterationsUsageItem
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_iterations_usage.rb,
sig/anthropic/models/beta/beta_iterations_usage.rbs
Overview
Token usage for a sampling iteration.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaMessageIterationUsage, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaMessageIterationUsage, Anthropic::Models::Beta::BetaCompactionIterationUsage, Anthropic::Models::Beta::BetaAdvisorMessageIterationUsage, Anthropic::Models::Beta::BetaFallbackMessageIterationUsage)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaMessageIterationUsage, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaIterationsUsageItem for more details.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/anthropic/models/beta/beta_iterations_usage.rb', line 56 def self.new(type:, **args) case type.to_sym when :message Anthropic::Beta::BetaMessageIterationUsage.new(**args) when :compaction Anthropic::Beta::BetaCompactionIterationUsage.new(**args) when :advisor_message Anthropic::Beta::BetaAdvisorMessageIterationUsage.new(**args) when :fallback_message Anthropic::Beta::BetaFallbackMessageIterationUsage.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaMessageIterationUsage, Anthropic::Models::Beta::BetaCompactionIterationUsage, Anthropic::Models::Beta::BetaAdvisorMessageIterationUsage, Anthropic::Models::Beta::BetaFallbackMessageIterationUsage)
|
|
# File 'lib/anthropic/models/beta/beta_iterations_usage.rb', line 29
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::beta_iterations_usage_item]
15 |
# File 'sig/anthropic/models/beta/beta_iterations_usage.rbs', line 15
def self?.variants: -> ::Array[Anthropic::Models::Beta::beta_iterations_usage_item]
|