Class: Anthropic::Models::Beta::BetaLimitedNetworkParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaLimitedNetworkParams
- Defined in:
- lib/anthropic/models/beta/beta_limited_network_params.rb
Instance Attribute Summary collapse
-
#allow_mcp_servers ⇒ Boolean?
Permits outbound access to MCP server endpoints configured on the agent, beyond those listed in the ‘allowed_hosts` array.
-
#allow_package_managers ⇒ Boolean?
Permits outbound access to public package registries (PyPI, npm, etc.) beyond those listed in the ‘allowed_hosts` array.
-
#allowed_hosts ⇒ Array<String>?
Specifies domains the container can reach.
-
#type ⇒ Symbol, :limited
Network policy type.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Anthropic::Internal::Type::BaseModel
Instance Attribute Details
#allow_mcp_servers ⇒ Boolean?
Permits outbound access to MCP server endpoints configured on the agent, beyond those listed in the ‘allowed_hosts` array. Defaults to `false`.
18 |
# File 'lib/anthropic/models/beta/beta_limited_network_params.rb', line 18 optional :allow_mcp_servers, Anthropic::Internal::Type::Boolean, nil?: true |
#allow_package_managers ⇒ Boolean?
Permits outbound access to public package registries (PyPI, npm, etc.) beyond those listed in the ‘allowed_hosts` array. Defaults to `false`.
25 |
# File 'lib/anthropic/models/beta/beta_limited_network_params.rb', line 25 optional :allow_package_managers, Anthropic::Internal::Type::Boolean, nil?: true |
#allowed_hosts ⇒ Array<String>?
Specifies domains the container can reach.
31 |
# File 'lib/anthropic/models/beta/beta_limited_network_params.rb', line 31 optional :allowed_hosts, Anthropic::Internal::Type::ArrayOf[String], nil?: true |
#type ⇒ Symbol, :limited
Network policy type
11 |
# File 'lib/anthropic/models/beta/beta_limited_network_params.rb', line 11 required :type, const: :limited |