Module: Anthropic::Models::Beta::BetaManagedAgentsAgent::Skill
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_agent.rb,
sig/anthropic/models/beta/beta_managed_agents_agent.rbs
Overview
Resolved skill as returned in API responses.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
167 168 169 170 171 172 173 174 175 176 |
# File 'lib/anthropic/models/beta/beta_managed_agents_agent.rb', line 167 def self.new(type:, **args) case type.to_sym when :anthropic Anthropic::Beta::BetaManagedAgentsAnthropicSkill.new(**args) when :custom Anthropic::Beta::BetaManagedAgentsCustomSkill.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_agent.rb', line 147
|
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_agent.rb', line 151
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgent::skill]
110 |
# File 'sig/anthropic/models/beta/beta_managed_agents_agent.rbs', line 110
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgent::skill]
|