Module: Anthropic::Models::Beta::BetaManagedAgentsAgent::Tool
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_agent.rb,
sig/anthropic/models/beta/beta_managed_agents_agent.rbs
Overview
Union type for tool configurations returned in API responses.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentToolset20260401, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAgentToolset20260401, Anthropic::Models::Beta::BetaManagedAgentsMCPToolset, Anthropic::Models::Beta::BetaManagedAgentsCustomTool)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentToolset20260401, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/anthropic/models/beta/beta_managed_agents_agent.rb', line 227 def self.new(type:, **args) case type.to_sym when :agent_toolset_20260401 Anthropic::Beta::BetaManagedAgentsAgentToolset20260401.new(**args) when :mcp_toolset Anthropic::Beta::BetaManagedAgentsMCPToolset.new(**args) when :custom Anthropic::Beta::BetaManagedAgentsCustomTool.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_agent.rb', line 199
|
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAgentToolset20260401, Anthropic::Models::Beta::BetaManagedAgentsMCPToolset, Anthropic::Models::Beta::BetaManagedAgentsCustomTool)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_agent.rb', line 203
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgent::tool]
150 |
# File 'sig/anthropic/models/beta/beta_managed_agents_agent.rbs', line 150
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgent::tool]
|