Module: Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams::PermissionPolicy

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb,
sig/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rbs

Overview

Permission policy for tool execution.

See Also:

  • Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams#permission_policy

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

Returns:

Raises:

  • (ArgumentError)


86
87
88
89
90
91
92
93
94
95
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb', line 86

def self.new(type:, **args)
  case type.to_sym
  when :always_allow
    Anthropic::Beta::BetaManagedAgentsAlwaysAllowPolicy.new(**args)
  when :always_ask
    Anthropic::Beta::BetaManagedAgentsAlwaysAskPolicy.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams::permission_policy]

Returns:

  • (::Array[Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams::permission_policy])


64
# File 'sig/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rbs', line 64

def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams::permission_policy]