Class: Anthropic::Models::Beta::BetaManagedAgentsAgentToolset20260401BashInput

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rb,
sig/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



22
# File 'sig/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rbs', line 22

def initialize: (

Instance Attribute Details

#commandString?

Shell command to execute. Omit only when restart is true.

Parameters:

  • (String)

Returns:

  • (String, nil)


11
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rb', line 11

optional :command, String

#restartBoolean?

When true, restart the persistent bash session instead of running a command. Subsequent calls without restart will run against the fresh session.

Parameters:

Returns:



18
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rb', line 18

optional :restart, Anthropic::Internal::Type::Boolean

#timeout_msInteger?

Per-call timeout in milliseconds. Defaults to the runner-wide tool timeout when omitted or zero.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


25
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rb', line 25

optional :timeout_ms, Integer

Instance Method Details

#to_hash{ command: String, restart: bool, timeout_ms: Integer }

Returns:

  • ({ command: String, restart: bool, timeout_ms: Integer })


28
# File 'sig/anthropic/models/beta/beta_managed_agents_agent_toolset20260401_bash_input.rbs', line 28

def to_hash: -> { command: String, restart: bool, timeout_ms: Integer }