Module: Anthropic::Models::Beta::BetaManagedAgentsAgentToolsetDefaultConfig::PermissionPolicy
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_agent_toolset_default_config.rb,
sig/anthropic/models/beta/beta_managed_agents_agent_toolset_default_config.rbs
Overview
Permission policy for tool execution.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
52 53 54 55 56 57 58 59 60 61 |
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_toolset_default_config.rb', line 52 def self.new(type:, **args) case type.to_sym when :always_allow Anthropic::Beta::BetaManagedAgentsAlwaysAllowPolicy.new(**args) when :always_ask Anthropic::Beta::BetaManagedAgentsAlwaysAskPolicy.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_toolset_default_config.rb', line 40
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgentToolsetDefaultConfig::permission_policy]
34 |
# File 'sig/anthropic/models/beta/beta_managed_agents_agent_toolset_default_config.rbs', line 34
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsAgentToolsetDefaultConfig::permission_policy]
|