Class: Anthropic::Models::Beta::BetaManagedAgentsCustomToolParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_managed_agents_custom_tool_params.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(description:, input_schema:, name:, type:) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsCustomToolParams for more details.

A custom tool that is executed by the API client rather than the agent. When the agent calls this tool, an ‘agent.custom_tool_use` event is emitted and the session goes idle, waiting for the client to provide the result via a `user.custom_tool_result` event.

Parameters:



# File 'lib/anthropic/models/beta/beta_managed_agents_custom_tool_params.rb', line 32

Instance Attribute Details

#descriptionString

Description of what the tool does, shown to the agent to help it decide when to use the tool. 1-1024 characters.

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/beta_managed_agents_custom_tool_params.rb', line 12

required :description, String

#input_schemaAnthropic::Models::Beta::BetaManagedAgentsCustomToolInputSchema

JSON Schema for custom tool input parameters.



18
# File 'lib/anthropic/models/beta/beta_managed_agents_custom_tool_params.rb', line 18

required :input_schema, -> { Anthropic::Beta::BetaManagedAgentsCustomToolInputSchema }

#nameString

Unique name for the tool. 1-128 characters; letters, digits, underscores, and hyphens.

Returns:

  • (String)


25
# File 'lib/anthropic/models/beta/beta_managed_agents_custom_tool_params.rb', line 25

required :name, String

#typeSymbol, Anthropic::Models::Beta::BetaManagedAgentsCustomToolParams::Type



30
# File 'lib/anthropic/models/beta/beta_managed_agents_custom_tool_params.rb', line 30

required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsCustomToolParams::Type }