Class: Anthropic::Models::Beta::BetaManagedAgentsDeploymentSystemMessageEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaManagedAgentsDeploymentSystemMessageEvent
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_deployment_system_message_event.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#content ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsSystemContentBlock>
System content blocks to append.
- #type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsDeploymentSystemMessageEvent::Type
Instance Method Summary collapse
-
#initialize(content:, type:) ⇒ Object
constructor
Privileged context for the accompanying turn and all subsequent turns, appended to the session’s system context as a ‘role: “system”` turn rather than replacing the top-level system prompt.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content:, type:) ⇒ Object
Privileged context for the accompanying turn and all subsequent turns, appended to the session’s system context as a ‘role: “system”` turn rather than replacing the top-level system prompt.
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment_system_message_event.rb', line 19
|
Instance Attribute Details
#content ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsSystemContentBlock>
System content blocks to append. Text-only.
11 12 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment_system_message_event.rb', line 11 required :content, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::BetaManagedAgentsSystemContentBlock] } |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsDeploymentSystemMessageEvent::Type
17 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment_system_message_event.rb', line 17 required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsDeploymentSystemMessageEvent::Type } |