Module: Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserMessageEvent::Content

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_managed_agents_deployment_user_message_event.rb,
sig/anthropic/models/beta/beta_managed_agents_deployment_user_message_event.rbs

Overview

Content block in a user message. Can be text, image, or document.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :text The text content.

    @option args [Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64ImageSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLImageSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileImageSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource] :source Union type for image source variants.

    @option args [String, nil] :context Additional context about the document for the model.

    @option args [String, nil] :title The title of the document.

Returns:

Raises:

  • (ArgumentError)


64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment_user_message_event.rb', line 64

def self.new(type:, **args)
  case type.to_sym
  when :text
    Anthropic::Beta::Sessions::BetaManagedAgentsTextBlock.new(**args)
  when :image
    Anthropic::Beta::Sessions::BetaManagedAgentsImageBlock.new(**args)
  when :document
    Anthropic::Beta::Sessions::BetaManagedAgentsDocumentBlock.new(**args)
  when :redacted
    Anthropic::Beta::Sessions::BetaManagedAgentsRedactedBlock.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserMessageEvent::content]

Returns:

  • (::Array[Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserMessageEvent::content])


36
# File 'sig/anthropic/models/beta/beta_managed_agents_deployment_user_message_event.rbs', line 36

def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserMessageEvent::content]