Module: Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig::Checkout
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_github_repository_resource_config.rb,
sig/anthropic/models/beta/beta_managed_agents_github_repository_resource_config.rbs
Overview
Branch or commit to check out. Defaults to the repository's default branch.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsBranchCheckout, Anthropic::Models::Beta::BetaManagedAgentsCommitCheckout
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsBranchCheckout, Anthropic::Models::Beta::BetaManagedAgentsCommitCheckout)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsBranchCheckout, Anthropic::Models::Beta::BetaManagedAgentsCommitCheckout
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/anthropic/models/beta/beta_managed_agents_github_repository_resource_config.rb', line 82 def self.new(type:, **args) case type.to_sym when :branch Anthropic::Beta::BetaManagedAgentsBranchCheckout.new(**args) when :commit Anthropic::Beta::BetaManagedAgentsCommitCheckout.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsBranchCheckout, Anthropic::Models::Beta::BetaManagedAgentsCommitCheckout)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_github_repository_resource_config.rb', line 66
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig::checkout]
54 |
# File 'sig/anthropic/models/beta/beta_managed_agents_github_repository_resource_config.rbs', line 54
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig::checkout]
|