Class: Anthropic::Models::Beta::BetaManagedAgentsGrepToolConfigParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaManagedAgentsGrepToolConfigParams
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rb,
sig/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rbs
Defined Under Namespace
Modules: PermissionPolicy, Type
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean?
Whether this tool is enabled and available to Claude.
-
#name ⇒ Symbol, :grep
Must be "grep".
-
#permission_policy ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, ...
Permission policy for tool execution.
- #type ⇒ Symbol, ...
Instance Method Summary collapse
-
#initialize(enabled: nil, permission_policy: nil, type: nil, name: :grep) ⇒ Object
constructor
Configuration override for the grep tool.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(enabled: nil, permission_policy: nil, type: nil, name: :grep) ⇒ Object
Configuration override for the grep tool.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsGrepToolConfigParams for more details.
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rb', line 33
|
Instance Attribute Details
#enabled ⇒ Boolean?
Whether this tool is enabled and available to Claude. Overrides the default_config setting.
18 |
# File 'lib/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rb', line 18 optional :enabled, Anthropic::Internal::Type::Boolean, nil?: true |
#name ⇒ Symbol, :grep
Must be "grep".
11 |
# File 'lib/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rb', line 11 required :name, const: :grep |
#permission_policy ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, ...
Permission policy for tool execution.
24 25 26 |
# File 'lib/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rb', line 24 optional :permission_policy, union: -> { Anthropic::Beta::BetaManagedAgentsGrepToolConfigParams::PermissionPolicy }, nil?: true |
#type ⇒ Symbol, ...
31 |
# File 'lib/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rb', line 31 optional :type, enum: -> { Anthropic::Beta::BetaManagedAgentsGrepToolConfigParams::Type } |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/anthropic/models/beta/beta_managed_agents_grep_tool_config_params.rbs', line 34
def to_hash: -> {
|