Module: Anthropic::Models::Beta::BetaManagedAgentsModelConfig::Effort

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_managed_agents_model_config.rb,
sig/anthropic/models/beta/beta_managed_agents_model_config.rbs

Overview

How hard Claude works on each turn. Sets output_config.effort on every Messages call the session makes.

See Also:

  • Anthropic::Models::Beta::BetaManagedAgentsModelConfig#effort

Defined Under Namespace

Modules: Type

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsEffortLow, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/anthropic/models/beta/beta_managed_agents_model_config.rb', line 101

def self.new(type:, **args)
  case type.to_sym
  when :low
    Anthropic::Beta::BetaManagedAgentsEffortLow.new(**args)
  when :medium
    Anthropic::Beta::BetaManagedAgentsEffortMedium.new(**args)
  when :high
    Anthropic::Beta::BetaManagedAgentsEffortHigh.new(**args)
  when :xhigh
    Anthropic::Beta::BetaManagedAgentsEffortXhigh.new(**args)
  when :max
    Anthropic::Beta::BetaManagedAgentsEffortMax.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/beta_managed_agents_model_config.rb', line 85

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::BetaManagedAgentsModelConfig::effort]

Returns:

  • (::Array[Anthropic::Models::Beta::BetaManagedAgentsModelConfig::effort])


71
# File 'sig/anthropic/models/beta/beta_managed_agents_model_config.rbs', line 71

def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsModelConfig::effort]