Module: Anthropic::Models::Beta::BetaManagedAgentsSessionThreadAgent::Skill
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_session_thread_agent.rb,
sig/anthropic/models/beta/beta_managed_agents_session_thread_agent.rbs
Overview
Resolved skill as returned in API responses.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
114 115 116 117 118 119 120 121 122 123 |
# File 'lib/anthropic/models/beta/beta_managed_agents_session_thread_agent.rb', line 114 def self.new(type:, **args) case type.to_sym when :anthropic Anthropic::Beta::BetaManagedAgentsAnthropicSkill.new(**args) when :custom Anthropic::Beta::BetaManagedAgentsCustomSkill.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkill, Anthropic::Models::Beta::BetaManagedAgentsCustomSkill)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_session_thread_agent.rb', line 98
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsSessionThreadAgent::skill]
74 |
# File 'sig/anthropic/models/beta/beta_managed_agents_session_thread_agent.rbs', line 74
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsSessionThreadAgent::skill]
|