Module: Anthropic::Models::Beta::BetaManagedAgentsStartEventPreview

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_managed_agents_start_event_preview.rb

Class Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentMessagePreview, Anthropic::Models::Beta::BetaManagedAgentsAgentThinkingPreview

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsStartEventPreview for more details.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :id The id the buffered agent.message will carry if it is emitted. Matches the event

Returns:

Raises:

  • (ArgumentError)


32
33
34
35
36
37
38
39
40
41
# File 'lib/anthropic/models/beta/beta_managed_agents_start_event_preview.rb', line 32

def self.new(type:, **args)
  case type.to_sym
  when :"agent.message"
    Anthropic::Beta::BetaManagedAgentsAgentMessagePreview.new(**args)
  when :"agent.thinking"
    Anthropic::Beta::BetaManagedAgentsAgentThinkingPreview.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end