Class: Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb,
sig/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rbs

Defined Under Namespace

Modules: Content, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, tool_use_id:, type:, content: nil, is_error: nil, processed_at: nil, session_thread_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent for more details.

Event sent by the client providing the result of an agent-toolset tool execution. Only valid on self_hosted environments, where sandbox-routed tools are executed by the client rather than the server.

Parameters:



# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 53

Instance Attribute Details

#idString

Unique identifier for this event.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 11

required :id, String

#is_errorBoolean?

Whether the tool execution resulted in an error.

Parameters:

Returns:



38
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 38

optional :is_error, Anthropic::Internal::Type::Boolean, nil?: true

#processed_atTime?

A timestamp in RFC 3339 format

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


44
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 44

optional :processed_at, Time, nil?: true

#session_thread_idString?

Routes this result to a subagent thread. Copy from the agent.tool_use event's session_thread_id.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


51
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 51

optional :session_thread_id, String, nil?: true

#tool_use_idString

The id of the agent.tool_use event this result corresponds to, which can be found in the last session.status_idle event's stop_reason.event_ids field.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 20

required :tool_use_id, String

#typeSymbol, Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent::Type

Parameters:

  • value (Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent::type_)

Returns:



25
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 25

required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsUserToolResultEvent::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 82

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rbs', line 46

def to_hash: -> {