Class: Anthropic::Models::Beta::BetaManagedAgentsVault
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaManagedAgentsVault
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_vault.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#display_name ⇒ String
Human-readable name for the vault.
-
#id ⇒ String
Unique identifier for the vault.
-
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata attached to the vault.
- #type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsVault::Type
-
#updated_at ⇒ Time
A timestamp in RFC 3339 format.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, display_name:, metadata:, type:, updated_at:) ⇒ Object
constructor
A vault that stores credentials for use by agents during sessions.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, display_name:, metadata:, type:, updated_at:) ⇒ Object
A vault that stores credentials for use by agents during sessions.
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 49
|
Instance Attribute Details
#archived_at ⇒ Time?
A timestamp in RFC 3339 format
18 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 18 required :archived_at, Time, nil?: true |
#created_at ⇒ Time
A timestamp in RFC 3339 format
24 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 24 required :created_at, Time |
#display_name ⇒ String
Human-readable name for the vault.
30 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 30 required :display_name, String |
#id ⇒ String
Unique identifier for the vault.
12 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata attached to the vault.
36 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 36 required :metadata, Anthropic::Internal::Type::HashOf[String] |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsVault::Type
41 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 41 required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsVault::Type } |
#updated_at ⇒ Time
A timestamp in RFC 3339 format
47 |
# File 'lib/anthropic/models/beta/beta_managed_agents_vault.rb', line 47 required :updated_at, Time |