Module: Anthropic::Models::Beta::BetaManagedAgentsWebFetchToolConfigParams::PermissionPolicy
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_web_fetch_tool_config_params.rb,
sig/anthropic/models/beta/beta_managed_agents_web_fetch_tool_config_params.rbs
Overview
Permission policy for tool execution.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy, Anthropic::Models::Beta::BetaManagedAgentsAutoPolicy)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/anthropic/models/beta/beta_managed_agents_web_fetch_tool_config_params.rb', line 119 def self.new(type:, **args) case type.to_sym when :always_allow Anthropic::Beta::BetaManagedAgentsAlwaysAllowPolicy.new(**args) when :always_ask Anthropic::Beta::BetaManagedAgentsAlwaysAskPolicy.new(**args) when :auto Anthropic::Beta::BetaManagedAgentsAutoPolicy.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_web_fetch_tool_config_params.rb', line 103
|
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, Anthropic::Models::Beta::BetaManagedAgentsAlwaysAskPolicy, Anthropic::Models::Beta::BetaManagedAgentsAutoPolicy)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_web_fetch_tool_config_params.rb', line 107
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsWebFetchToolConfigParams::permission_policy]
80 |
# File 'sig/anthropic/models/beta/beta_managed_agents_web_fetch_tool_config_params.rbs', line 80
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsWebFetchToolConfigParams::permission_policy]
|