Class: Anthropic::Models::Beta::BetaMessageIterationUsage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaMessageIterationUsage
- Defined in:
- lib/anthropic/models/beta/beta_message_iteration_usage.rb,
sig/anthropic/models/beta/beta_message_iteration_usage.rbs
Instance Attribute Summary collapse
-
#cache_creation ⇒ Anthropic::Models::Beta::BetaCacheCreation?
Breakdown of cached tokens by TTL.
-
#cache_creation_input_tokens ⇒ Integer
The number of input tokens used to create the cache entry.
-
#cache_read_input_tokens ⇒ Integer
The number of input tokens read from the cache.
-
#input_tokens ⇒ Integer
The number of input tokens which were used.
-
#model ⇒ Symbol, ...
The model that will complete your prompt.
-
#output_tokens ⇒ Integer
The number of output tokens which were used.
-
#type ⇒ Symbol, :message
Usage for a sampling iteration.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
32 |
# File 'sig/anthropic/models/beta/beta_message_iteration_usage.rbs', line 32
def initialize: (
|
Instance Attribute Details
#cache_creation ⇒ Anthropic::Models::Beta::BetaCacheCreation?
Breakdown of cached tokens by TTL
11 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 11 required :cache_creation, -> { Anthropic::Beta::BetaCacheCreation }, nil?: true |
#cache_creation_input_tokens ⇒ Integer
The number of input tokens used to create the cache entry.
17 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 17 required :cache_creation_input_tokens, Integer |
#cache_read_input_tokens ⇒ Integer
The number of input tokens read from the cache.
23 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 23 required :cache_read_input_tokens, Integer |
#input_tokens ⇒ Integer
The number of input tokens which were used.
29 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 29 required :input_tokens, Integer |
#model ⇒ Symbol, ...
The model that will complete your prompt.
See models for additional details and options.
38 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 38 required :model, union: -> { Anthropic::Model } |
#output_tokens ⇒ Integer
The number of output tokens which were used.
44 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 44 required :output_tokens, Integer |
#type ⇒ Symbol, :message
Usage for a sampling iteration
50 |
# File 'lib/anthropic/models/beta/beta_message_iteration_usage.rb', line 50 required :type, const: :message |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/anthropic/models/beta/beta_message_iteration_usage.rbs', line 42
def to_hash: -> {
|