Class: Anthropic::Models::Beta::BetaMidConversationSystemBlockParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb,
sig/anthropic/models/beta/beta_mid_conversation_system_block_param.rbs

Defined Under Namespace

Modules: Content

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, cache_control: nil, type: :mid_conv_system) ⇒ Object

System instructions that appear mid-conversation.

Use this block to provide or update system-level instructions at a specific point in the conversation, rather than only via the top-level system parameter.

Parameters:



# File 'lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb', line 25

Instance Attribute Details

#cache_controlAnthropic::Models::Beta::BetaCacheControlEphemeral?

Create a cache control breakpoint at this content block.

Parameters:

  • value (Anthropic::Beta::BetaCacheControlEphemeral, nil)

Returns:



23
# File 'lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb', line 23

optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true

#contentArray<Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaRequestToolAdditionBlock, Anthropic::Models::Beta::BetaRequestToolRemovalBlock>

System instruction text blocks.

Parameters:

  • value (::Array[Anthropic::Models::Beta::BetaMidConversationSystemBlockParam::content])

Returns:



11
12
# File 'lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb', line 11

required :content,
-> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaMidConversationSystemBlockParam::Content] }

#typeSymbol, :mid_conv_system

Parameters:

  • value (:mid_conv_system)

Returns:

  • (Symbol, :mid_conv_system)


17
# File 'lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb', line 17

required :type, const: :mid_conv_system

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/anthropic/models/beta/beta_mid_conversation_system_block_param.rbs', line 26

def to_hash: -> {