Module: Anthropic::Models::Beta::BetaMidConversationSystemBlockParam::Content
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb,
sig/anthropic/models/beta/beta_mid_conversation_system_block_param.rbs
Overview
Mid-conversation directive to surface a declared tool.
tool references a tool (or MCP toolset) by name from the request's tools; it
is offered to the model from this point in the conversation onward.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaTextBlockParam, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaRequestToolAdditionBlock, Anthropic::Models::Beta::BetaRequestToolRemovalBlock)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaTextBlockParam, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaMidConversationSystemBlockParam::Content for more details.
87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb', line 87 def self.new(type:, **args) case type.to_sym when :text Anthropic::Beta::BetaTextBlockParam.new(**args) when :tool_addition Anthropic::Beta::BetaRequestToolAdditionBlock.new(**args) when :tool_removal Anthropic::Beta::BetaRequestToolRemovalBlock.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaRequestToolAdditionBlock, Anthropic::Models::Beta::BetaRequestToolRemovalBlock)
|
|
# File 'lib/anthropic/models/beta/beta_mid_conversation_system_block_param.rb', line 63
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaMidConversationSystemBlockParam::content]
40 |
# File 'sig/anthropic/models/beta/beta_mid_conversation_system_block_param.rbs', line 40
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaMidConversationSystemBlockParam::content]
|