Class: Anthropic::Models::Beta::BetaModelInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_model_info.rb,
sig/anthropic/models/beta/beta_model_info.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Models#retrieve

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



35
# File 'sig/anthropic/models/beta/beta_model_info.rbs', line 35

def initialize: (

Instance Attribute Details

#allowed_fallback_modelsArray<String>?

Model IDs this model accepts as fallbacks[i].model on the Messages API. An empty list means the fallbacks parameter is not supported for this model as primary.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


20
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 20

required :allowed_fallback_models, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#capabilitiesAnthropic::Models::Beta::BetaModelCapabilities?

Model capability information.

Parameters:

  • value (Anthropic::Beta::BetaModelCapabilities, nil)

Returns:



26
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 26

required :capabilities, -> { Anthropic::Beta::BetaModelCapabilities }, nil?: true

#created_atTime

RFC 3339 datetime string representing the time at which the model was released. May be set to an epoch value if the release date is unknown.

Parameters:

  • value (Time)

Returns:

  • (Time)


33
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 33

required :created_at, Time

#display_nameString

A human-readable name for the model.

Parameters:

  • value (String)

Returns:

  • (String)


39
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 39

required :display_name, String

#idString

Unique model identifier.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 12

required :id, String

#max_input_tokensInteger?

Maximum input context window size in tokens for this model.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


45
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 45

required :max_input_tokens, Integer, nil?: true

#max_tokensInteger?

Maximum value for the max_tokens parameter when using this model.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


51
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 51

required :max_tokens, Integer, nil?: true

#typeSymbol, :model

Object type.

For Models, this is always "model".

Parameters:

  • value (:model)

Returns:

  • (Symbol, :model)


59
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 59

required :type, const: :model

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/anthropic/models/beta/beta_model_info.rbs', line 46

def to_hash: -> {