Class: Anthropic::Models::Beta::BetaRawMessageDeltaEvent::Delta
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaRawMessageDeltaEvent::Delta
- Defined in:
- lib/anthropic/models/beta/beta_raw_message_delta_event.rb,
sig/anthropic/models/beta/beta_raw_message_delta_event.rbs
Overview
Instance Attribute Summary collapse
-
#container ⇒ Anthropic::Models::Beta::BetaContainer?
Information about the container used in the request (for the code execution tool).
-
#stop_details ⇒ Anthropic::Models::Beta::BetaRefusalStopDetails?
Structured information about a refusal.
- #stop_reason ⇒ Symbol, ...
- #stop_sequence ⇒ String?
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
59 |
# File 'sig/anthropic/models/beta/beta_raw_message_delta_event.rbs', line 59
def initialize: (
|
Instance Attribute Details
#container ⇒ Anthropic::Models::Beta::BetaContainer?
Information about the container used in the request (for the code execution tool)
88 |
# File 'lib/anthropic/models/beta/beta_raw_message_delta_event.rb', line 88 required :container, -> { Anthropic::Beta::BetaContainer }, nil?: true |
#stop_details ⇒ Anthropic::Models::Beta::BetaRefusalStopDetails?
Structured information about a refusal.
94 |
# File 'lib/anthropic/models/beta/beta_raw_message_delta_event.rb', line 94 required :stop_details, -> { Anthropic::Beta::BetaRefusalStopDetails }, nil?: true |
#stop_reason ⇒ Symbol, ...
99 |
# File 'lib/anthropic/models/beta/beta_raw_message_delta_event.rb', line 99 required :stop_reason, enum: -> { Anthropic::Beta::BetaStopReason }, nil?: true |
#stop_sequence ⇒ String?
104 |
# File 'lib/anthropic/models/beta/beta_raw_message_delta_event.rb', line 104 required :stop_sequence, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/anthropic/models/beta/beta_raw_message_delta_event.rbs', line 66
def to_hash: -> {
|