Module: Anthropic::Models::Beta::BetaRefusalStopDetails::Category
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/anthropic/models/beta/beta_refusal_stop_details.rb,
sig/anthropic/models/beta/beta_refusal_stop_details.rbs
Overview
The policy category that triggered a refusal.
Constant Summary collapse
- CYBER =
The request could enable cyber harm, such as malware or exploit development. Benign cybersecurity work can also trigger this category.
:cyber- BIO =
The request could enable biological harm, such as dangerous lab methods. Beneficial life sciences work can also trigger this category.
:bio- FRONTIER_LLM =
The request could assist the development of competing AI models, which is restricted under Anthropic's commercial terms. Benign machine learning work can also trigger this category.
:frontier_llm- REASONING_EXTRACTION =
The request asks the model to reproduce its internal reasoning in the response text. To get reasoning in a structured form instead, use adaptive thinking.
:reasoning_extraction- GENERAL_HARMS =
The request could be related to an area that was determined as harmful. Benign work might sometimes trigger this category.
:general_harms
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[Anthropic::Models::Beta::BetaRefusalStopDetails::category]
68 |
# File 'sig/anthropic/models/beta/beta_refusal_stop_details.rbs', line 68
def self?.values: -> ::Array[Anthropic::Models::Beta::BetaRefusalStopDetails::category]
|