Module: Anthropic::Models::Beta::BetaRequestDocumentBlock::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_request_document_block.rb,
sig/anthropic/models/beta/beta_request_document_block.rbs
Overview
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaBase64PDFSource, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::BetaBase64PDFSource, Anthropic::Models::Beta::BetaPlainTextSource, Anthropic::Models::Beta::BetaContentBlockSource, Anthropic::Models::Beta::BetaURLPDFSource, Anthropic::Models::Beta::BetaFileDocumentSource)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaBase64PDFSource, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/anthropic/models/beta/beta_request_document_block.rb', line 102 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Beta::BetaBase64PDFSource.new(**args) when :text Anthropic::Beta::BetaPlainTextSource.new(**args) when :content Anthropic::Beta::BetaContentBlockSource.new(**args) when :url Anthropic::Beta::BetaURLPDFSource.new(**args) when :file Anthropic::Beta::BetaFileDocumentSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_request_document_block.rb', line 76
|
.variants ⇒ Array(Anthropic::Models::Beta::BetaBase64PDFSource, Anthropic::Models::Beta::BetaPlainTextSource, Anthropic::Models::Beta::BetaContentBlockSource, Anthropic::Models::Beta::BetaURLPDFSource, Anthropic::Models::Beta::BetaFileDocumentSource)
|
|
# File 'lib/anthropic/models/beta/beta_request_document_block.rb', line 80
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaRequestDocumentBlock::source]
71 |
# File 'sig/anthropic/models/beta/beta_request_document_block.rbs', line 71
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaRequestDocumentBlock::source]
|