Class: Anthropic::Models::Beta::BetaTargetStoreHeldError

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_target_store_held_error.rb,
sig/anthropic/models/beta/beta_target_store_held_error.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeBetaTargetStoreHeldError

Returns a new instance of BetaTargetStoreHeldError.

Parameters:

  • message: (String)
  • type: (:conflict_error)


16
# File 'sig/anthropic/models/beta/beta_target_store_held_error.rbs', line 16

def initialize: (?message: String, ?type: :conflict_error) -> void

Instance Attribute Details

#messageString?

Human-readable description of the conflict, naming the dream that holds the target store when the server can identify it.

Parameters:

  • (String)

Returns:

  • (String, nil)


17
# File 'lib/anthropic/models/beta/beta_target_store_held_error.rb', line 17

optional :message, String

#typeSymbol, :conflict_error

Parameters:

  • value (:conflict_error)

Returns:

  • (Symbol, :conflict_error)


10
# File 'lib/anthropic/models/beta/beta_target_store_held_error.rb', line 10

required :type, const: :conflict_error

Instance Method Details

#to_hash{ type: :conflict_error, message: String }

Returns:

  • ({ type: :conflict_error, message: String })


18
# File 'sig/anthropic/models/beta/beta_target_store_held_error.rbs', line 18

def to_hash: -> { type: :conflict_error, message: String }