Module: Anthropic::Models::Beta::BetaTextCitation
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_text_citation.rb
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCitationCharLocation, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaCitationCharLocation, Anthropic::Models::Beta::BetaCitationPageLocation, Anthropic::Models::Beta::BetaCitationContentBlockLocation, Anthropic::Models::Beta::BetaCitationsWebSearchResultLocation, Anthropic::Models::Beta::BetaCitationSearchResultLocation)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCitationCharLocation, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaTextCitation for more details.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/anthropic/models/beta/beta_text_citation.rb', line 66 def self.new(type:, **args) case type.to_sym when :char_location Anthropic::Beta::BetaCitationCharLocation.new(**args) when :page_location Anthropic::Beta::BetaCitationPageLocation.new(**args) when :content_block_location Anthropic::Beta::BetaCitationContentBlockLocation.new(**args) when :web_search_result_location Anthropic::Beta::BetaCitationsWebSearchResultLocation.new(**args) when :search_result_location Anthropic::Beta::BetaCitationSearchResultLocation.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaCitationCharLocation, Anthropic::Models::Beta::BetaCitationPageLocation, Anthropic::Models::Beta::BetaCitationContentBlockLocation, Anthropic::Models::Beta::BetaCitationsWebSearchResultLocation, Anthropic::Models::Beta::BetaCitationSearchResultLocation)
|
|
# File 'lib/anthropic/models/beta/beta_text_citation.rb', line 21
|