Module: Anthropic::Models::Beta::BetaThinkingConfigParam
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_thinking_config_param.rb
Overview
Configuration for enabling Claude's extended thinking.
When enabled, responses include thinking content blocks showing Claude's
thinking process before the final answer. Requires a minimum budget of 1,024
tokens and counts towards your max_tokens limit.
See extended thinking for details.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaThinkingConfigEnabled, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaThinkingConfigEnabled, Anthropic::Models::Beta::BetaThinkingConfigDisabled, Anthropic::Models::Beta::BetaThinkingConfigAdaptive)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaThinkingConfigEnabled, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaThinkingConfigParam for more details.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/anthropic/models/beta/beta_thinking_config_param.rb', line 45 def self.new(type:, **args) case type.to_sym when :enabled Anthropic::Beta::BetaThinkingConfigEnabled.new(**args) when :disabled Anthropic::Beta::BetaThinkingConfigDisabled.new(**args) when :adaptive Anthropic::Beta::BetaThinkingConfigAdaptive.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaThinkingConfigEnabled, Anthropic::Models::Beta::BetaThinkingConfigDisabled, Anthropic::Models::Beta::BetaThinkingConfigAdaptive)
|
|
# File 'lib/anthropic/models/beta/beta_thinking_config_param.rb', line 26
|