Module: Anthropic::Models::Beta::BetaThinkingDroppedInputTransformation::Reason

Extended by:
Internal::Type::Enum
Defined in:
lib/anthropic/models/beta/beta_thinking_dropped_input_transformation.rb,
sig/anthropic/models/beta/beta_thinking_dropped_input_transformation.rbs

Overview

Which binding check removed the block: model_binding_mismatch — it was created by a model whose reasoning the requested model may not read; prefix_binding_mismatch — the conversation before it differs from the conversation it was created in (the rest of that turn's consecutive thinking blocks are removed with it, each with this reason); organization_binding_mismatch — it was created under a different organization (an Anthropic organization, AWS account or Google Cloud project) and this organization is not one of its additional organizations; end_user_binding_mismatch — it was created for a different end user, or was removed by the consumer-organization binding. A block that would fail several checks reports one reason, in this order of precedence: organization_binding_mismatch, end_user_binding_mismatch, model_binding_mismatch, prefix_binding_mismatch.

See Also:

  • Anthropic::Models::Beta::BetaThinkingDroppedInputTransformation#reason

Constant Summary collapse

MODEL_BINDING_MISMATCH =

Returns:

:model_binding_mismatch
PREFIX_BINDING_MISMATCH =

Returns:

:prefix_binding_mismatch
ORGANIZATION_BINDING_MISMATCH =

Returns:

:organization_binding_mismatch
END_USER_BINDING_MISMATCH =

Returns:

:end_user_binding_mismatch

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[Anthropic::Models::Beta::BetaThinkingDroppedInputTransformation::reason]

Returns:



46
# File 'sig/anthropic/models/beta/beta_thinking_dropped_input_transformation.rbs', line 46

def self?.values: -> ::Array[Anthropic::Models::Beta::BetaThinkingDroppedInputTransformation::reason]