Module: Anthropic::Models::Beta::BetaToolResultBlockParam::Content::Content
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_tool_result_block_param.rb,
sig/anthropic/models/beta/beta_tool_result_block_param.rbs
Overview
Tool reference block that can be included in tool_result content.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaTextBlockParam, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaImageBlockParam, Anthropic::Models::Beta::BetaSearchResultBlockParam, Anthropic::Models::Beta::BetaRequestDocumentBlock, Anthropic::Models::Beta::BetaToolReferenceBlockParam, Anthropic::Models::Beta::BetaBrowserStateBlockParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaTextBlockParam, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaToolResultBlockParam::Content::Content for more details.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/anthropic/models/beta/beta_tool_result_block_param.rb', line 124 def self.new(type:, **args) case type.to_sym when :text Anthropic::Beta::BetaTextBlockParam.new(**args) when :image Anthropic::Beta::BetaImageBlockParam.new(**args) when :search_result Anthropic::Beta::BetaSearchResultBlockParam.new(**args) when :document Anthropic::Beta::BetaRequestDocumentBlock.new(**args) when :tool_reference Anthropic::Beta::BetaToolReferenceBlockParam.new(**args) when :browser_state Anthropic::Beta::BetaBrowserStateBlockParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaImageBlockParam, Anthropic::Models::Beta::BetaSearchResultBlockParam, Anthropic::Models::Beta::BetaRequestDocumentBlock, Anthropic::Models::Beta::BetaToolReferenceBlockParam, Anthropic::Models::Beta::BetaBrowserStateBlockParam)
|
|
# File 'lib/anthropic/models/beta/beta_tool_result_block_param.rb', line 86
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaToolResultBlockParam::Content::content]
71 |
# File 'sig/anthropic/models/beta/beta_tool_result_block_param.rbs', line 71
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaToolResultBlockParam::Content::content]
|