Module: Anthropic::Models::Beta::BetaUserProfile::AccessType

Extended by:
Internal::Type::Enum
Defined in:
lib/anthropic/models/beta/beta_user_profile.rb,
sig/anthropic/models/beta/beta_user_profile.rbs

Overview

How the platform uses the API on behalf of the entity this profile represents. application: the platform sells a product that uses the API behind the scenes, and the profile represents an individual end-user of that product. passthrough: the platform resells raw inference, and the profile identifies the resold-to company.

See Also:

  • Anthropic::Models::Beta::BetaUserProfile#access_type

Constant Summary collapse

APPLICATION =

The user profile represents an individual end-user of a product that the platform builds on the API. New profiles get this value by default.

:application
PASSTHROUGH =

The user profile represents a company that the platform resells Claude access to.

:passthrough

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values ⇒ ::Array[Anthropic::Models::Beta::BetaUserProfile::access_type]



101
# File 'sig/anthropic/models/beta/beta_user_profile.rbs', line 101

def self?.values: -> ::Array[Anthropic::Models::Beta::BetaUserProfile::access_type]