Module: Anthropic::Models::Beta::BetaWebFetchURLSources::ClientToolResults

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_web_fetch_url_sources.rb,
sig/anthropic/models/beta/beta_web_fetch_url_sources.rbs

Overview

Which client tools' results contribute fetchable URLs: "all", "none", or an only or except list of client tool names from tools.

See Also:

  • Anthropic::Models::Beta::BetaWebFetchURLSources#client_tool_results

Defined Under Namespace

Modules: Type

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaWebFetchURLSourceAll, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/anthropic/models/beta/beta_web_fetch_url_sources.rb', line 96

def self.new(type:, **args)
  case type.to_sym
  when :all
    Anthropic::Beta::BetaWebFetchURLSourceAll.new(**args)
  when :none
    Anthropic::Beta::BetaWebFetchURLSourceNone.new(**args)
  when :only
    Anthropic::Beta::BetaWebFetchURLSourceOnly.new(**args)
  when :except
    Anthropic::Beta::BetaWebFetchURLSourceExcept.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/beta_web_fetch_url_sources.rb', line 78

.variantsArray(Anthropic::Models::Beta::BetaWebFetchURLSourceAll, Anthropic::Models::Beta::BetaWebFetchURLSourceNone, Anthropic::Models::Beta::BetaWebFetchURLSourceOnly, Anthropic::Models::Beta::BetaWebFetchURLSourceExcept)



# File 'lib/anthropic/models/beta/beta_web_fetch_url_sources.rb', line 82

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::BetaWebFetchURLSources::client_tool_results]

Returns:

  • (::Array[Anthropic::Models::Beta::BetaWebFetchURLSources::client_tool_results])


66
# File 'sig/anthropic/models/beta/beta_web_fetch_url_sources.rbs', line 66

def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaWebFetchURLSources::client_tool_results]