Module: Anthropic::Models::Beta::BetaWebFetchURLSources::UserInput
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_web_fetch_url_sources.rb,
sig/anthropic/models/beta/beta_web_fetch_url_sources.rbs
Overview
Whether URLs in user messages are fetchable: "all" or "none".
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaWebFetchURLSourceAll, Anthropic::Models::Beta::BetaWebFetchURLSourceNone
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::BetaWebFetchURLSourceAll, Anthropic::Models::Beta::BetaWebFetchURLSourceNone)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaWebFetchURLSourceAll, Anthropic::Models::Beta::BetaWebFetchURLSourceNone
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
218 219 220 221 222 223 224 225 226 227 |
# File 'lib/anthropic/models/beta/beta_web_fetch_url_sources.rb', line 218 def self.new(type:, **args) case type.to_sym when :all Anthropic::Beta::BetaWebFetchURLSourceAll.new(**args) when :none Anthropic::Beta::BetaWebFetchURLSourceNone.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_web_fetch_url_sources.rb', line 202
|
.variants ⇒ Array(Anthropic::Models::Beta::BetaWebFetchURLSourceAll, Anthropic::Models::Beta::BetaWebFetchURLSourceNone)
|
|
# File 'lib/anthropic/models/beta/beta_web_fetch_url_sources.rb', line 206
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaWebFetchURLSources::user_input]
150 |
# File 'sig/anthropic/models/beta/beta_web_fetch_url_sources.rbs', line 150
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaWebFetchURLSources::user_input]
|