Class: Anthropic::Models::Beta::DeploymentListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/deployment_list_params.rb,
sig/anthropic/models/beta/deployment_list_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Deployments#list

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_id: nil, created_at_gte: nil, created_at_lte: nil, include_archived: nil, limit: nil, page: nil, status: nil, betas: nil, workspace_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::DeploymentListParams for more details.

Parameters:

  • (defaults to: nil)

    Filter by agent ID.

  • (defaults to: nil)

    Return deployments created at or after this time (inclusive).

  • (defaults to: nil)

    Return deployments created at or before this time (inclusive).

  • (defaults to: nil)

    When true, includes archived deployments. Default: false (exclude archived).

  • (defaults to: nil)

    Maximum results per page. Default 20, maximum 100.

  • (defaults to: nil)

    Opaque pagination cursor.

  • (defaults to: nil)

    Filter by status: active or paused. Omit for both. To include archived deplo

  • (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • (defaults to: nil)
  • (defaults to: {})


# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 65


Instance Attribute Details

#agent_idString?

Filter by agent ID.

Parameters:

Returns:



15
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 15

optional :agent_id, String

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



58
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 58

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#created_at_gteTime?

Return deployments created at or after this time (inclusive).

Parameters:

Returns:



21
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 21

optional :created_at_gte, Time

#created_at_lteTime?

Return deployments created at or before this time (inclusive).

Parameters:

Returns:



27
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 27

optional :created_at_lte, Time

#include_archivedBoolean?

When true, includes archived deployments. Default: false (exclude archived).

Parameters:

Returns:



33
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 33

optional :include_archived, Anthropic::Internal::Type::Boolean

#limitInteger?

Maximum results per page. Default 20, maximum 100.

Parameters:

Returns:



39
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 39

optional :limit, Integer

#pageString?

Opaque pagination cursor.

Parameters:

Returns:



45
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 45

optional :page, String

#statusSymbol, ...

Filter by status: active or paused. Omit for both. To include archived deployments, use include_archived instead; the two cannot be combined.

Returns:



52
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 52

optional :status, enum: -> { Anthropic::Beta::BetaManagedAgentsDeploymentStatus }

#workspace_idString?

Parameters:

Returns:



63
# File 'lib/anthropic/models/beta/deployment_list_params.rb', line 63

optional :workspace_id, String

Instance Method Details

#to_hash{

Returns:



75
# File 'sig/anthropic/models/beta/deployment_list_params.rbs', line 75

def to_hash: -> {