Class: Anthropic::Models::Beta::DeploymentRunListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/deployment_run_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at_gt: nil, created_at_gte: nil, created_at_lt: nil, created_at_lte: nil, deployment_id: nil, has_error: nil, limit: nil, page: nil, trigger_type: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::DeploymentRunListParams for more details.

session_

Parameters:

  • created_at_gt (Time) (defaults to: nil)

    Return runs created strictly after this time (exclusive).

  • created_at_gte (Time) (defaults to: nil)

    Return runs created at or after this time (inclusive).

  • created_at_lt (Time) (defaults to: nil)

    Return runs created strictly before this time (exclusive).

  • created_at_lte (Time) (defaults to: nil)

    Return runs created at or before this time (inclusive).

  • deployment_id (String) (defaults to: nil)

    Filter to a specific deployment. Omit to list across all deployments in the work

  • has_error (Boolean) (defaults to: nil)

    Filter: true for runs with non-null error, false for runs with non-null

  • limit (Integer) (defaults to: nil)

    Maximum results per page. Default 20, maximum 1000.

  • page (String) (defaults to: nil)

    Opaque pagination cursor. Pass next_page from the previous response. Invalid or

  • trigger_type (Symbol, Anthropic::Models::Beta::BetaManagedAgentsTriggerType) (defaults to: nil)

    Filter runs by what triggered them. Omit to return all runs.

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 75

Instance Attribute Details

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



73
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 73

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#created_at_gtTime?

Return runs created strictly after this time (exclusive).

Returns:

  • (Time, nil)


15
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 15

optional :created_at_gt, Time

#created_at_gteTime?

Return runs created at or after this time (inclusive).

Returns:

  • (Time, nil)


21
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 21

optional :created_at_gte, Time

#created_at_ltTime?

Return runs created strictly before this time (exclusive).

Returns:

  • (Time, nil)


27
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 27

optional :created_at_lt, Time

#created_at_lteTime?

Return runs created at or before this time (inclusive).

Returns:

  • (Time, nil)


33
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 33

optional :created_at_lte, Time

#deployment_idString?

Filter to a specific deployment. Omit to list across all deployments in the workspace. Filtering by a non-existent deployment_id returns 200 with empty data.

Returns:

  • (String, nil)


41
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 41

optional :deployment_id, String

#has_errorBoolean?

Filter: true for runs with non-null error, false for runs with non-null session_id. Omit for all.

Returns:



48
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 48

optional :has_error, Anthropic::Internal::Type::Boolean

#limitInteger?

Maximum results per page. Default 20, maximum 1000.

Returns:

  • (Integer, nil)


54
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 54

optional :limit, Integer

#pageString?

Opaque pagination cursor. Pass next_page from the previous response. Invalid or expired cursors return 400.

Returns:

  • (String, nil)


61
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 61

optional :page, String

#trigger_typeSymbol, ...

Filter runs by what triggered them. Omit to return all runs.



67
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 67

optional :trigger_type, enum: -> { Anthropic::Beta::BetaManagedAgentsTriggerType }