Class: Anthropic::Models::Beta::DeploymentUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/deployment_update_params.rb,
sig/anthropic/models/beta/deployment_update_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Deployments#update

Defined Under Namespace

Modules: Agent, Resource

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(deployment_id:, agent: nil, budget: nil, description: nil, environment_id: nil, initial_events: nil, metadata: nil, name: nil, resources: nil, schedule: nil, vault_ids: nil, betas: nil, workspace_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::DeploymentUpdateParams for more details.

Parameters:



# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 108

Instance Attribute Details

#agent ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentParams, ...

Agent to deploy. Accepts the agent ID string, which re-pins to the latest version, or an agent object with both id and version specified. Omit to preserve. Cannot be cleared.



23
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 23

optional :agent, union: -> { Anthropic::Beta::DeploymentUpdateParams::Agent }

#betas ⇒ Array<Symbol, String, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



95
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 95

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#budget ⇒ Anthropic::Models::Beta::BetaManagedAgentsBudgetLimit?

A hard spend ceiling. The session stops issuing new model requests once the tracked list cost reaches max_list_cost.

Parameters:

  • value (Anthropic::Beta::BetaManagedAgentsBudgetLimit, nil)

Returns:



30
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 30

optional :budget, -> { Anthropic::Beta::BetaManagedAgentsBudgetLimit }, nil?: true

#deployment_id ⇒ String

Unique identifier of the deployment to update.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 15

required :deployment_id, String

#description ⇒ String?

Description. Omit to preserve; send empty string or null to clear.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


36
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 36

optional :description, String, nil?: true

#environment_id ⇒ String?

ID of the environment where sessions run. Omit to preserve. Cannot be cleared.

Parameters:

  • (String)

Returns:

  • (String, nil)


42
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 42

optional :environment_id, String

#initial_events ⇒ Array<Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserMessageEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSystemMessageEventParams>?

Initial events. Full replacement. Omit to preserve. Cannot be cleared. At least 1, maximum 50.



49
50
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 49

optional :initial_events,
-> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaManagedAgentsDeploymentInitialEventParams] }

#metadata ⇒ Hash{Symbol=>String, nil}?

Metadata patch. Set a key to a string to upsert it, or to null to delete it. Omit the field to preserve. The stored bag is limited to 16 keys (up to 64 chars each) with values up to 512 chars.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


58
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 58

optional :metadata, Anthropic::Internal::Type::HashOf[String, nil?: true], nil?: true

#name ⇒ String?

Human-readable name. Must be non-empty. Omit to preserve. Cannot be cleared.

Parameters:

  • (String)

Returns:

  • (String, nil)


64
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 64

optional :name, String

#resources ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceParams, Anthropic::Models::Beta::BetaManagedAgentsFileResourceParams, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam>?

Session resources. Full replacement. Omit to preserve; send empty array or null to clear. Maximum 500.



71
72
73
74
75
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 71

optional :resources,
-> {
  Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::DeploymentUpdateParams::Resource]
},
nil?: true

#schedule ⇒ Anthropic::Models::Beta::BetaManagedAgentsScheduleParams?

5-field POSIX cron schedule. Literal wall-clock matching in the configured timezone.

Parameters:

  • value (Anthropic::Beta::BetaManagedAgentsScheduleParams, nil)

Returns:



82
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 82

optional :schedule, -> { Anthropic::Beta::BetaManagedAgentsScheduleParams }, nil?: true

#vault_ids ⇒ Array<String>?

Vault IDs. Full replacement. Omit to preserve; send empty array or null to clear. Maximum 50.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


89
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 89

optional :vault_ids, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#workspace_id ⇒ String?

Optional header to select the Workspace for this request. The value is a Workspace ID (for example, wrkspc_011CZkZaBF1tNoB5wlCeusgy).

Only needed for credentials that can act on more than one Workspace. A credential that belongs to a specific Workspace may omit it; if sent, it must match that Workspace.

Parameters:

  • (String)

Returns:

  • (String, nil)


106
# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 106

optional :workspace_id, String

Class Method Details

.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAgentParams, String)



# File 'lib/anthropic/models/beta/deployment_update_params.rb', line 151

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


87
# File 'sig/anthropic/models/beta/deployment_update_params.rbs', line 87

def to_hash: -> {