Class: Anthropic::Models::Beta::DreamListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/dream_list_params.rb,
sig/anthropic/models/beta/dream_list_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Dreams#list

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at_gt: nil, created_at_lt: nil, include_archived: nil, limit: nil, page: nil, statuses: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::DreamListParams for more details.

Parameters:

  • created_at_gt (Time) (defaults to: nil)

    Return dreams with created_at strictly after this timestamp (exclusive lower b

  • created_at_lt (Time) (defaults to: nil)

    Return dreams with created_at strictly before this timestamp (exclusive upper

  • include_archived (Boolean) (defaults to: nil)

    Query parameter for include_archived

  • limit (Integer) (defaults to: nil)

    Query parameter for limit

  • page (String) (defaults to: nil)

    Query parameter for page

  • statuses (Array<Symbol, Anthropic::Models::Beta::BetaDreamStatus>) (defaults to: nil)

    Filter by lifecycle status. Repeat the parameter to match any of multiple status

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/dream_list_params.rb', line 56

Instance Attribute Details

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



54
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 54

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#created_at_gtTime?

Return dreams with created_at strictly after this timestamp (exclusive lower bound, RFC 3339). Unset applies no lower bound.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


16
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 16

optional :created_at_gt, Time

#created_at_ltTime?

Return dreams with created_at strictly before this timestamp (exclusive upper bound, RFC 3339). Unset applies no upper bound.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


23
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 23

optional :created_at_lt, Time

#include_archivedBoolean?

Query parameter for include_archived

Parameters:

Returns:



29
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 29

optional :include_archived, Anthropic::Internal::Type::Boolean

#limitInteger?

Query parameter for limit

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


35
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 35

optional :limit, Integer

#pageString?

Query parameter for page

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 41

optional :page, String

#statusesArray<Symbol, Anthropic::Models::Beta::BetaDreamStatus>?

Filter by lifecycle status. Repeat the parameter to match any of multiple statuses. Empty applies no status filter.

Returns:



48
# File 'lib/anthropic/models/beta/dream_list_params.rb', line 48

optional :statuses, -> { Anthropic::Internal::Type::ArrayOf[enum: Anthropic::Beta::BetaDreamStatus] }

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/anthropic/models/beta/dream_list_params.rbs', line 63

def to_hash: -> {