Module: Anthropic::Models::Beta::EnvironmentCreateParams::Config

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/environment_create_params.rb,
sig/anthropic/models/beta/environment_create_params.rbs

Overview

Environment configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCloudConfigParams, Anthropic::Models::Beta::BetaSelfHostedConfigParams

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Some parameter documentations has been truncated, see Anthropic::Models::Beta::EnvironmentCreateParams::Config for more details.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [Anthropic::Models::Beta::BetaUnrestrictedNetwork, Anthropic::Models::Beta::BetaLimitedNetworkParams, nil] :networking Network configuration policy. Omit on update to preserve the existing value.

    @option args [Anthropic::Models::Beta::BetaPackagesParams, nil] :packages Specify packages (and optionally their versions) available in this environment.

Returns:

Raises:

  • (ArgumentError)


102
103
104
105
106
107
108
109
110
111
# File 'lib/anthropic/models/beta/environment_create_params.rb', line 102

def self.new(type:, **args)
  case type.to_sym
  when :cloud
    Anthropic::Beta::BetaCloudConfigParams.new(**args)
  when :self_hosted
    Anthropic::Beta::BetaSelfHostedConfigParams.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::EnvironmentCreateParams::config]

Returns:

  • (::Array[Anthropic::Models::Beta::EnvironmentCreateParams::config])


64
# File 'sig/anthropic/models/beta/environment_create_params.rbs', line 64

def self?.variants: -> ::Array[Anthropic::Models::Beta::EnvironmentCreateParams::config]