Class: Anthropic::Models::Beta::Environments::BetaSelfHostedWork
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Environments::BetaSelfHostedWork
- Defined in:
- lib/anthropic/models/beta/environments/beta_self_hosted_work.rb
Overview
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#acknowledged_at ⇒ String?
RFC 3339 timestamp when the work item was acknowledged and assigned to a self-hosted sandbox.
-
#created_at ⇒ String
RFC 3339 timestamp when work was created.
-
#data ⇒ Anthropic::Models::Beta::Environments::BetaSessionWorkData
The actual work to be performed.
-
#environment_id ⇒ String
Environment identifier this work belongs to (e.g., ‘env_…`).
-
#id ⇒ String
Work identifier (e.g., ‘work_…’).
-
#latest_heartbeat_at ⇒ String?
RFC 3339 timestamp of the most recent heartbeat.
-
#metadata ⇒ Hash{Symbol=>String}
User-provided metadata key-value pairs associated with this work item.
-
#started_at ⇒ String?
RFC 3339 timestamp when work execution started.
-
#state ⇒ Symbol, Anthropic::Models::Beta::Environments::BetaSelfHostedWork::State
Current state of the work item.
-
#stop_requested_at ⇒ String?
RFC 3339 timestamp when stop was requested.
-
#stopped_at ⇒ String?
RFC 3339 timestamp when work execution stopped.
-
#type ⇒ Symbol, :work
The type of object (always ‘work’).
Instance Method Summary collapse
-
#initialize(id:, acknowledged_at:, created_at:, data:, environment_id:, latest_heartbeat_at:, metadata:, started_at:, state:, stop_requested_at:, stopped_at:, type: :work) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaSelfHostedWork for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, acknowledged_at:, created_at:, data:, environment_id:, latest_heartbeat_at:, metadata:, started_at:, state:, stop_requested_at:, stopped_at:, type: :work) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Environments::BetaSelfHostedWork for more details.
Work resource representing a unit of work in a self-hosted environment.
Work items are queued when sessions are created or when long-dormant sessions receive new messages. The environment worker polls for work to execute in a self-hosted sandbox.
|
|
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 82
|
Instance Attribute Details
#acknowledged_at ⇒ String?
RFC 3339 timestamp when the work item was acknowledged and assigned to a self-hosted sandbox
20 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 20 required :acknowledged_at, String, nil?: true |
#created_at ⇒ String
RFC 3339 timestamp when work was created
26 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 26 required :created_at, String |
#data ⇒ Anthropic::Models::Beta::Environments::BetaSessionWorkData
The actual work to be performed
32 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 32 required :data, -> { Anthropic::Beta::Environments::BetaSessionWorkData } |
#environment_id ⇒ String
Environment identifier this work belongs to (e.g., ‘env_…`)
38 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 38 required :environment_id, String |
#id ⇒ String
Work identifier (e.g., ‘work_…’)
13 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 13 required :id, String |
#latest_heartbeat_at ⇒ String?
RFC 3339 timestamp of the most recent heartbeat
44 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 44 required :latest_heartbeat_at, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}
User-provided metadata key-value pairs associated with this work item
50 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 50 required :metadata, Anthropic::Internal::Type::HashOf[String] |
#started_at ⇒ String?
RFC 3339 timestamp when work execution started
56 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 56 required :started_at, String, nil?: true |
#state ⇒ Symbol, Anthropic::Models::Beta::Environments::BetaSelfHostedWork::State
Current state of the work item
62 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 62 required :state, enum: -> { Anthropic::Beta::Environments::BetaSelfHostedWork::State } |
#stop_requested_at ⇒ String?
RFC 3339 timestamp when stop was requested
68 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 68 required :stop_requested_at, String, nil?: true |
#stopped_at ⇒ String?
RFC 3339 timestamp when work execution stopped
74 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 74 required :stopped_at, String, nil?: true |
#type ⇒ Symbol, :work
The type of object (always ‘work’)
80 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work.rb', line 80 required :type, const: :work |