Class: Anthropic::Models::Beta::Environments::BetaSelfHostedWorkListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Environments::BetaSelfHostedWorkListResponse
- Defined in:
- lib/anthropic/models/beta/environments/beta_self_hosted_work_list_response.rb
Instance Attribute Summary collapse
-
#data ⇒ Array<Anthropic::Models::Beta::Environments::BetaSelfHostedWork>
List of work items.
-
#next_page ⇒ String?
Opaque cursor for fetching the next page of results.
Instance Method Summary collapse
-
#initialize(data:, next_page:) ⇒ Object
constructor
Response when listing work items with cursor-based pagination.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, next_page:) ⇒ Object
Response when listing work items with cursor-based pagination.
|
|
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_list_response.rb', line 21
|
Instance Attribute Details
#data ⇒ Array<Anthropic::Models::Beta::Environments::BetaSelfHostedWork>
List of work items
12 13 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_list_response.rb', line 12 required :data, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::Environments::BetaSelfHostedWork] } |
#next_page ⇒ String?
Opaque cursor for fetching the next page of results
19 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_list_response.rb', line 19 required :next_page, String, nil?: true |