Class: Anthropic::Models::Beta::Environments::BetaSelfHostedWorkQueueStats
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Environments::BetaSelfHostedWorkQueueStats
- Defined in:
- lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb
Overview
Instance Attribute Summary collapse
-
#depth ⇒ Integer
Number of work items waiting to be picked up (lag from consumer group).
-
#oldest_queued_at ⇒ String?
RFC 3339 timestamp of oldest item in the work stream (includes both queued and pending items), null if stream empty.
-
#pending ⇒ Integer
Number of work items being processed (polled but not acknowledged).
-
#type ⇒ Symbol, :work_queue_stats
The type of object.
-
#workers_polling ⇒ Integer?
Number of workers that have polled for work in the last 30 seconds.
Instance Method Summary collapse
-
#initialize(depth:, oldest_queued_at:, pending:, workers_polling:, type: :work_queue_stats) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaSelfHostedWorkQueueStats for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(depth:, oldest_queued_at:, pending:, workers_polling:, type: :work_queue_stats) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Environments::BetaSelfHostedWorkQueueStats for more details.
Statistics about the work queue for an environment.
Uses Redis Stream consumer group metrics for O(1) queries.
|
|
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb', line 41
|
Instance Attribute Details
#depth ⇒ Integer
Number of work items waiting to be picked up (lag from consumer group)
13 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb', line 13 required :depth, Integer |
#oldest_queued_at ⇒ String?
RFC 3339 timestamp of oldest item in the work stream (includes both queued and pending items), null if stream empty
20 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb', line 20 required :oldest_queued_at, String, nil?: true |
#pending ⇒ Integer
Number of work items being processed (polled but not acknowledged)
26 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb', line 26 required :pending, Integer |
#type ⇒ Symbol, :work_queue_stats
The type of object
32 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb', line 32 required :type, const: :work_queue_stats |
#workers_polling ⇒ Integer?
Number of workers that have polled for work in the last 30 seconds. Requires worker_id to be sent with poll requests.
39 |
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_queue_stats.rb', line 39 required :workers_polling, Integer, nil?: true |