Class: Anthropic::Models::Beta::Environments::BetaSelfHostedWorkUpdateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/environments/beta_self_hosted_work_update_request.rb

Direct Known Subclasses

WorkUpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(metadata:) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Environments::BetaSelfHostedWorkUpdateRequest for more details.

Request to update work item metadata.

Parameters:

  • metadata (Hash{Symbol=>String, nil})

    Metadata patch. Set a key to a string to upsert it, or to null to delete it. Omi



# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_update_request.rb', line 15

Instance Attribute Details

#metadataHash{Symbol=>String, nil}

Metadata patch. Set a key to a string to upsert it, or to null to delete it. Omit the field to preserve existing metadata.

Returns:

  • (Hash{Symbol=>String, nil})


13
# File 'lib/anthropic/models/beta/environments/beta_self_hosted_work_update_request.rb', line 13

required :metadata, Anthropic::Internal::Type::HashOf[String, nil?: true]