Class: Anthropic::Models::Beta::Environments::BetaSessionWorkData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/environments/beta_session_work_data.rb,
sig/anthropic/models/beta/environments/beta_session_work_data.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, type: :session) ⇒ BetaSessionWorkData

Work data for session work items.

This resource type is used when work represents a session that needs to be executed in a self-hosted environment.

Parameters:

  • id (String)

    Session identifier (e.g., 'session_...')

  • type (Symbol, :session) (defaults to: :session)

    Type of work data

  • id: (String)
  • type: (:session) (defaults to: :session)


# File 'lib/anthropic/models/beta/environments/beta_session_work_data.rb', line 20

Instance Attribute Details

#idString

Session identifier (e.g., 'session_...')

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/environments/beta_session_work_data.rb', line 12

required :id, String

#typeSymbol, :session

Type of work data

Parameters:

  • value (:session)

Returns:

  • (Symbol, :session)


18
# File 'lib/anthropic/models/beta/environments/beta_session_work_data.rb', line 18

required :type, const: :session

Instance Method Details

#to_hash{ id: String, type: :session }

Returns:

  • ({ id: String, type: :session })


14
# File 'sig/anthropic/models/beta/environments/beta_session_work_data.rbs', line 14

def to_hash: -> { id: String, type: :session }