Class: Anthropic::Models::Beta::Environments::WorkPollParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/environments/work_poll_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(environment_id:, block_ms: nil, reclaim_older_than_ms: nil, betas: nil, anthropic_worker_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Environments::WorkPollParams for more details.

Parameters:

  • environment_id (String)
  • block_ms (Integer, nil) (defaults to: nil)

    How long to wait for work to arrive before returning. Must be 1-999 in milliseco

  • reclaim_older_than_ms (Integer, nil) (defaults to: nil)

    Reclaim unacknowledged work items older than this many milliseconds. If omitted,

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • anthropic_worker_id (String) (defaults to: nil)

    Unique identifier for the specific worker polling, used to track aggregated envi

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 45

Instance Attribute Details

#anthropic_worker_idString?

Unique identifier for the specific worker polling, used to track aggregated environment-level work metrics in Console

Returns:

  • (String, nil)


43
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 43

optional :anthropic_worker_id, String

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



36
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 36

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#block_msInteger?

How long to wait for work to arrive before returning. Must be 1-999 in milliseconds. Defaults to non-blocking (returns immediately if no work is available).

Returns:

  • (Integer, nil)


23
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 23

optional :block_ms, Integer, nil?: true

#environment_idString

Returns:

  • (String)


15
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 15

required :environment_id, String

#reclaim_older_than_msInteger?

Reclaim unacknowledged work items older than this many milliseconds. If omitted, uses the default (5000ms).

Returns:

  • (Integer, nil)


30
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 30

optional :reclaim_older_than_ms, Integer, nil?: true