Class: Anthropic::Models::Beta::MemoryStoreUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/memory_store_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(memory_store_id:, description: nil, metadata: nil, name: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::MemoryStoreUpdateParams for more details.

Parameters:

  • memory_store_id (String)
  • description (String, nil) (defaults to: nil)

    New description for the store, up to 1024 characters. Pass an empty string to cl

  • metadata (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    Metadata patch. Set a key to a string to upsert it, or to null to delete it. Omi

  • name (String, nil) (defaults to: nil)

    New human-readable name for the store. 1–255 characters; no control characters.

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/memory_store_update_params.rb', line 45

Instance Attribute Details

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



43
# File 'lib/anthropic/models/beta/memory_store_update_params.rb', line 43

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#descriptionString?

New description for the store, up to 1024 characters. Pass an empty string to clear it.

Returns:

  • (String, nil)


21
# File 'lib/anthropic/models/beta/memory_store_update_params.rb', line 21

optional :description, String, nil?: true

#memory_store_idString

Returns:

  • (String)


14
# File 'lib/anthropic/models/beta/memory_store_update_params.rb', line 14

required :memory_store_id, String

#metadataHash{Symbol=>String, nil}?

Metadata patch. Set a key to a string to upsert it, or to null to delete it. Omit the field to preserve. The stored bag is limited to 16 keys (up to 64 chars each) with values up to 512 chars.

Returns:

  • (Hash{Symbol=>String, nil}, nil)


29
# File 'lib/anthropic/models/beta/memory_store_update_params.rb', line 29

optional :metadata, Anthropic::Internal::Type::HashOf[String, nil?: true], nil?: true

#nameString?

New human-readable name for the store. 1–255 characters; no control characters. Renaming changes the slug used for the store’s ‘mount_path` in sessions created after the update.

Returns:

  • (String, nil)


37
# File 'lib/anthropic/models/beta/memory_store_update_params.rb', line 37

optional :name, String, nil?: true