Class: Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsDeletedMemory
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsDeletedMemory
- Defined in:
- lib/anthropic/models/beta/memory_stores/beta_managed_agents_deleted_memory.rb,
sig/anthropic/models/beta/memory_stores/beta_managed_agents_deleted_memory.rbs
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the deleted memory (a
mem_...value). - #type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsDeletedMemory::Type
Instance Method Summary collapse
-
#initialize(id:, type:) ⇒ Object
constructor
Tombstone returned by Delete a memory.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, type:) ⇒ Object
Tombstone returned by Delete a memory. Deleting a memory does not erase its version history: its versions remain listable via List memory versions while they are retained (each version is kept for at least the version retention period after it was written, unless the store itself is deleted).
|
|
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_deleted_memory.rb', line 20
|
Instance Attribute Details
#id ⇒ String
ID of the deleted memory (a mem_... value).
13 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_deleted_memory.rb', line 13 required :id, String |
#type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsDeletedMemory::Type
18 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_deleted_memory.rb', line 18 required :type, enum: -> { Anthropic::Beta::MemoryStores::BetaManagedAgentsDeletedMemory::Type } |
Instance Method Details
#to_hash ⇒ {
21 |
# File 'sig/anthropic/models/beta/memory_stores/beta_managed_agents_deleted_memory.rbs', line 21
def to_hash: -> {
|