Class: Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsServiceAccountActor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/memory_stores/beta_managed_agents_service_account_actor.rb,
sig/anthropic/models/beta/memory_stores/beta_managed_agents_service_account_actor.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(service_account_id:, type: :service_account_actor) ⇒ Object

Attribution for a write made by a workload authenticated as a service account, for example via Workload Identity Federation.

Parameters:

  • service_account_id (String)

    ID of the service account that performed the write (a svac_... value).

  • type (Symbol, :service_account_actor) (defaults to: :service_account_actor)


# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_service_account_actor.rb', line 19

Instance Attribute Details

#service_account_idString

ID of the service account that performed the write (a svac_... value).

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_service_account_actor.rb', line 12

required :service_account_id, String

#typeSymbol, :service_account_actor

Parameters:

  • value (:service_account_actor)

Returns:

  • (Symbol, :service_account_actor)


17
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_service_account_actor.rb', line 17

required :type, const: :service_account_actor

Instance Method Details

#to_hash{

Returns:

  • ({)


18
# File 'sig/anthropic/models/beta/memory_stores/beta_managed_agents_service_account_actor.rbs', line 18

def to_hash: -> {