Class: Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsSessionActor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsSessionActor
- Defined in:
- lib/anthropic/models/beta/memory_stores/beta_managed_agents_session_actor.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#session_id ⇒ String
ID of the session that performed the write (a ‘sesn_…` value).
- #type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsSessionActor::Type
Instance Method Summary collapse
-
#initialize(session_id:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsSessionActor for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(session_id:, type:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsSessionActor for more details.
Attribution for a write made by an agent during a session, through the mounted filesystem at ‘/mnt/memory/`.
|
|
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_session_actor.rb', line 21
|
Instance Attribute Details
#session_id ⇒ String
ID of the session that performed the write (a ‘sesn_…` value). Look up the session via [Retrieve a session](/en/api/sessions-retrieve) for further provenance.
14 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_session_actor.rb', line 14 required :session_id, String |
#type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsSessionActor::Type
19 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_session_actor.rb', line 19 required :type, enum: -> { Anthropic::Beta::MemoryStores::BetaManagedAgentsSessionActor::Type } |