Class: Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsUserActor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsUserActor
- Defined in:
- lib/anthropic/models/beta/memory_stores/beta_managed_agents_user_actor.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
- #type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsUserActor::Type
-
#user_id ⇒ String
ID of the user who performed the write (a ‘user_…` value).
Instance Method Summary collapse
-
#initialize(type:, user_id:) ⇒ Object
constructor
Attribution for a write made by a human user through the Anthropic Console.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(type:, user_id:) ⇒ Object
Attribution for a write made by a human user through the Anthropic Console.
|
|
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_user_actor.rb', line 19
|
Instance Attribute Details
#type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsUserActor::Type
11 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_user_actor.rb', line 11 required :type, enum: -> { Anthropic::Beta::MemoryStores::BetaManagedAgentsUserActor::Type } |
#user_id ⇒ String
ID of the user who performed the write (a ‘user_…` value).
17 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_user_actor.rb', line 17 required :user_id, String |