Class: Anthropic::Models::Beta::MessageCountTokensParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::MessageCountTokensParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/message_count_tokens_params.rb,
sig/anthropic/models/beta/message_count_tokens_params.rbs
Overview
Defined Under Namespace
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Top-level cache control automatically applies a cache_control marker to the last cacheable block in the request.
-
#context_management ⇒ Anthropic::Models::Beta::BetaContextManagementConfig?
Context management configuration.
-
#mcp_servers ⇒ Array<Anthropic::Models::Beta::BetaRequestMCPServerURLDefinition>?
MCP servers to be utilized in this request.
-
#messages ⇒ Array<Anthropic::Models::Beta::BetaMessageParam>
Input messages.
-
#model ⇒ Symbol, ...
The model that will complete your prompt.
-
#output_config ⇒ Anthropic::Models::Beta::BetaOutputConfig?
Configuration options for the model's output, such as the output format.
- #output_format ⇒ Anthropic::Models::Beta::BetaJSONOutputFormat? deprecated Deprecated.
-
#speed ⇒ Symbol, ...
The inference speed mode for this request.
-
#system_ ⇒ String, ...
System prompt.
-
#thinking ⇒ Anthropic::Models::Beta::BetaThinkingConfigEnabled, ...
Configuration for enabling Claude's extended thinking.
-
#tool_choice ⇒ Anthropic::Models::Beta::BetaToolChoiceAuto, ...
How the model should use the provided tools.
-
#tools ⇒ Array<Anthropic::Models::Beta::BetaTool, Anthropic::Models::Beta::BetaToolBash20241022, Anthropic::Models::Beta::BetaToolBash20250124, Anthropic::Models::Beta::BetaCodeExecutionTool20250522, Anthropic::Models::Beta::BetaCodeExecutionTool20250825, Anthropic::Models::Beta::BetaCodeExecutionTool20260120, Anthropic::Models::Beta::BetaCodeExecutionTool20260521, Anthropic::Models::Beta::BetaToolComputerUse20241022, Anthropic::Models::Beta::BetaMemoryTool20250818, Anthropic::Models::Beta::BetaToolComputerUse20250124, Anthropic::Models::Beta::BetaToolTextEditor20241022, Anthropic::Models::Beta::BetaToolComputerUse20251124, Anthropic::Models::Beta::BetaToolTextEditor20250124, Anthropic::Models::Beta::BetaToolTextEditor20250429, Anthropic::Models::Beta::BetaToolTextEditor20250728, Anthropic::Models::Beta::BetaWebSearchTool20250305, Anthropic::Models::Beta::BetaWebFetchTool20250910, Anthropic::Models::Beta::BetaWebSearchTool20260209, Anthropic::Models::Beta::BetaWebFetchTool20260209, Anthropic::Models::Beta::BetaWebFetchTool20260309, Anthropic::Models::Beta::BetaWebSearchTool20260318, Anthropic::Models::Beta::BetaWebFetchTool20260318, Anthropic::Models::Beta::BetaAdvisorTool20260301, Anthropic::Models::Beta::BetaToolSearchToolBm25_20251119, Anthropic::Models::Beta::BetaToolSearchToolRegex20251119, Anthropic::Models::Beta::BetaMCPToolset>?
Definitions of tools that the model may use.
-
#user_profile_id ⇒ String?
The user profile ID to attribute this request to.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(messages:, model:, cache_control: nil, context_management: nil, mcp_servers: nil, output_config: nil, output_format: nil, speed: nil, system_: nil, thinking: nil, tool_choice: nil, tools: nil, betas: nil, user_profile_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MessageCountTokensParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(messages:, model:, cache_control: nil, context_management: nil, mcp_servers: nil, output_config: nil, output_format: nil, speed: nil, system_: nil, thinking: nil, tool_choice: nil, tools: nil, betas: nil, user_profile_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::MessageCountTokensParams for more details.
|
|
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 266
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
257 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 257 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Top-level cache control automatically applies a cache_control marker to the last cacheable block in the request.
96 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 96 optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true |
#context_management ⇒ Anthropic::Models::Beta::BetaContextManagementConfig?
Context management configuration.
This allows you to control how Claude manages context across multiple requests, such as whether to clear function results or not.
105 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 105 optional :context_management, -> { Anthropic::Beta::BetaContextManagementConfig }, nil?: true |
#mcp_servers ⇒ Array<Anthropic::Models::Beta::BetaRequestMCPServerURLDefinition>?
MCP servers to be utilized in this request
111 112 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 111 optional :mcp_servers, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::BetaRequestMCPServerURLDefinition] } |
#messages ⇒ Array<Anthropic::Models::Beta::BetaMessageParam>
Input messages.
Our models are trained to operate on alternating user and assistant
conversational turns. When creating a new Message, you specify the prior
conversational turns with the messages parameter, and the model then generates
the next Message in the conversation. Consecutive user or assistant turns
in your request will be combined into a single turn.
Each input message must be an object with a role and content. You can
specify a single user-role message, or you can include multiple user and
assistant messages.
If the final message uses the assistant role, the response content will
continue immediately from the content in that message. This can be used to
constrain part of the model's response.
Example with a single user message:
[{ "role": "user", "content": "Hello, Claude" }]
Example with multiple conversational turns:
[
{ "role": "user", "content": "Hello there." },
{ "role": "assistant", "content": "Hi, I'm Claude. How can I help you?" },
{ "role": "user", "content": "Can you explain LLMs in plain English?" }
]
Example with a partially-filled response from Claude:
[
{
"role": "user",
"content": "What's the Greek name for Sun? (A) Sol (B) Helios (C) Sun"
},
{ "role": "assistant", "content": "The best answer is (" }
]
Each input message content may be either a single string or an array of
content blocks, where each block has a specific type. Using a string for
content is shorthand for an array of one content block of type "text". The
following input messages are equivalent:
{ "role": "user", "content": "Hello, Claude" }
{ "role": "user", "content": [{ "type": "text", "text": "Hello, Claude" }] }
See input examples.
Note that if you want to include a
system prompt,
you can use the top-level system parameter — there is no "system" role for
input messages in the Messages API.
There is a limit of 100,000 messages in a single request.
80 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 80 required :messages, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::BetaMessageParam] } |
#model ⇒ Symbol, ...
The model that will complete your prompt.
See models for additional details and options.
89 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 89 required :model, union: -> { Anthropic::Model } |
#output_config ⇒ Anthropic::Models::Beta::BetaOutputConfig?
Configuration options for the model's output, such as the output format.
118 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 118 optional :output_config, -> { Anthropic::Beta::BetaOutputConfig } |
#output_format ⇒ Anthropic::Models::Beta::BetaJSONOutputFormat?
Deprecated: Use output_config.format instead. See
structured outputs
A schema to specify Claude's output format in responses. This parameter will be removed in a future release.
130 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 130 optional :output_format, -> { Anthropic::Beta::BetaJSONOutputFormat }, nil?: true |
#speed ⇒ Symbol, ...
The inference speed mode for this request. "fast" enables high
output-tokens-per-second inference.
137 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 137 optional :speed, enum: -> { Anthropic::Beta::MessageCountTokensParams::Speed }, nil?: true |
#system_ ⇒ String, ...
System prompt.
A system prompt is a way of providing context and instructions to Claude, such as specifying a particular goal or role. See our guide to system prompts.
147 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 147 optional :system_, union: -> { Anthropic::Beta::MessageCountTokensParams::System }, api_name: :system |
#thinking ⇒ Anthropic::Models::Beta::BetaThinkingConfigEnabled, ...
Configuration for enabling Claude's extended thinking.
When enabled, responses include thinking content blocks showing Claude's
thinking process before the final answer. Requires a minimum budget of 1,024
tokens and counts towards your max_tokens limit.
See extended thinking for details.
161 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 161 optional :thinking, union: -> { Anthropic::Beta::BetaThinkingConfigParam } |
#tool_choice ⇒ Anthropic::Models::Beta::BetaToolChoiceAuto, ...
How the model should use the provided tools. The model can use a specific tool, any available tool, decide by itself, or not use tools at all.
168 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 168 optional :tool_choice, union: -> { Anthropic::Beta::BetaToolChoice } |
#tools ⇒ Array<Anthropic::Models::Beta::BetaTool, Anthropic::Models::Beta::BetaToolBash20241022, Anthropic::Models::Beta::BetaToolBash20250124, Anthropic::Models::Beta::BetaCodeExecutionTool20250522, Anthropic::Models::Beta::BetaCodeExecutionTool20250825, Anthropic::Models::Beta::BetaCodeExecutionTool20260120, Anthropic::Models::Beta::BetaCodeExecutionTool20260521, Anthropic::Models::Beta::BetaToolComputerUse20241022, Anthropic::Models::Beta::BetaMemoryTool20250818, Anthropic::Models::Beta::BetaToolComputerUse20250124, Anthropic::Models::Beta::BetaToolTextEditor20241022, Anthropic::Models::Beta::BetaToolComputerUse20251124, Anthropic::Models::Beta::BetaToolTextEditor20250124, Anthropic::Models::Beta::BetaToolTextEditor20250429, Anthropic::Models::Beta::BetaToolTextEditor20250728, Anthropic::Models::Beta::BetaWebSearchTool20250305, Anthropic::Models::Beta::BetaWebFetchTool20250910, Anthropic::Models::Beta::BetaWebSearchTool20260209, Anthropic::Models::Beta::BetaWebFetchTool20260209, Anthropic::Models::Beta::BetaWebFetchTool20260309, Anthropic::Models::Beta::BetaWebSearchTool20260318, Anthropic::Models::Beta::BetaWebFetchTool20260318, Anthropic::Models::Beta::BetaAdvisorTool20260301, Anthropic::Models::Beta::BetaToolSearchToolBm25_20251119, Anthropic::Models::Beta::BetaToolSearchToolRegex20251119, Anthropic::Models::Beta::BetaMCPToolset>?
Definitions of tools that the model may use.
If you include tools in your API request, the model may return tool_use
content blocks that represent the model's use of those tools. You can then run
those tools using the tool input generated by the model and then optionally
return results back to the model using tool_result content blocks.
There are two types of tools: client tools and server tools. The behavior described below applies to client tools. For server tools, see their individual documentation as each has its own behavior (e.g., the web search tool).
Each tool definition includes:
name: Name of the tool.description: Optional, but strongly-recommended description of the tool.input_schema: JSON schema for the toolinputshape that the model will produce intool_useoutput content blocks.
For example, if you defined tools as:
[
{
"name": "get_stock_price",
"description": "Get the current stock price for a given ticker symbol.",
"input_schema": {
"type": "object",
"properties": {
"ticker": {
"type": "string",
"description": "The stock ticker symbol, e.g. AAPL for Apple Inc."
}
},
"required": ["ticker"]
}
}
]
And then asked the model "What's the S&P 500 at today?", the model might produce
tool_use content blocks in the response like this:
[
{
"type": "tool_use",
"id": "toolu_01D7FLrfh4GYq7yT1ULFeyMV",
"name": "get_stock_price",
"input": { "ticker": "^GSPC" }
}
]
You might then run your get_stock_price tool with {"ticker": "^GSPC"} as an
input, and return the following back to the model in a subsequent user
message:
[
{
"type": "tool_result",
"tool_use_id": "toolu_01D7FLrfh4GYq7yT1ULFeyMV",
"content": "259.75 USD"
}
]
Tools can be used for workflows that include running client-side tools and functions, or more generally whenever you want the model to produce a particular JSON structure of output.
See our guide for more details.
250 251 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 250 optional :tools, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::MessageCountTokensParams::Tool] } |
#user_profile_id ⇒ String?
The user profile ID to attribute this request to. Use when acting on behalf of a
party other than your organization. Requires the user-profiles beta header.
264 |
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 264 optional :user_profile_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/message_count_tokens_params.rb', line 308
|
Instance Method Details
#to_hash ⇒ {
103 |
# File 'sig/anthropic/models/beta/message_count_tokens_params.rbs', line 103
def to_hash: -> {
|