Module: Anthropic::Models::Beta::Organization::BetaAPIKey::Principal

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/organization/beta_api_key.rb,
sig/anthropic/models/beta/organization/beta_api_key.rbs

Overview

The principal the API key acts as (a User or a Service Account), or null if the API key is not bound to a principal.

See Also:

  • Anthropic::Models::Beta::Organization::BetaAPIKey#principal

Defined Under Namespace

Modules: Type

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Organization::BetaAPIKeyUserActor, Anthropic::Models::Beta::Organization::BetaAPIKeyServiceAccountActor

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :user_id ID of the User the API key acts as.

    @option args [String] :service_account_id ID of the Service Account the API key acts as.

Returns:

Raises:

  • (ArgumentError)


155
156
157
158
159
160
161
162
163
164
# File 'lib/anthropic/models/beta/organization/beta_api_key.rb', line 155

def self.new(type:, **args)
  case type.to_sym
  when :user_actor
    Anthropic::Beta::Organization::BetaAPIKeyUserActor.new(**args)
  when :service_account_actor
    Anthropic::Beta::Organization::BetaAPIKeyServiceAccountActor.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/organization/beta_api_key.rb', line 135

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Organization::BetaAPIKey::principal]

Returns:

  • (::Array[Anthropic::Models::Beta::Organization::BetaAPIKey::principal])


89
# File 'sig/anthropic/models/beta/organization/beta_api_key.rbs', line 89

def self?.variants: -> ::Array[Anthropic::Models::Beta::Organization::BetaAPIKey::principal]