Class: Anthropic::Models::Beta::Organization::BetaDataResidency

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/beta_data_residency.rb,
sig/anthropic/models/beta/organization/beta_data_residency.rbs

Defined Under Namespace

Modules: AllowedInferenceGeos

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed_inference_geos:, default_inference_geo:, workspace_geo:) ⇒ Object

Parameters:

  • allowed_inference_geos (Array<String>, Symbol, :unrestricted)

    Permitted inference geo values. 'unrestricted' means all geos are allowed.

  • default_inference_geo (String)

    Default inference geo applied when requests omit the parameter.

  • workspace_geo (String)

    Geographic region for workspace data storage. Immutable after creation.



# File 'lib/anthropic/models/beta/organization/beta_data_residency.rb', line 27

Instance Attribute Details

#allowed_inference_geosArray<String>, ...

Permitted inference geo values. 'unrestricted' means all geos are allowed.

Parameters:

  • value (Anthropic::Models::Beta::Organization::BetaDataResidency::allowed_inference_geos)

Returns:

  • (Array<String>, Symbol, :unrestricted)


12
13
# File 'lib/anthropic/models/beta/organization/beta_data_residency.rb', line 12

required :allowed_inference_geos,
union: -> { Anthropic::Beta::Organization::BetaDataResidency::AllowedInferenceGeos }

#default_inference_geoString

Default inference geo applied when requests omit the parameter.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/anthropic/models/beta/organization/beta_data_residency.rb', line 19

required :default_inference_geo, String

#workspace_geoString

Geographic region for workspace data storage. Immutable after creation.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/anthropic/models/beta/organization/beta_data_residency.rb', line 25

required :workspace_geo, String

Instance Method Details

#to_hash{

Returns:

  • ({)


25
# File 'sig/anthropic/models/beta/organization/beta_data_residency.rbs', line 25

def to_hash: -> {