Class: Anthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/beta_data_residency_create_config.rb,
sig/anthropic/models/beta/organization/beta_data_residency_create_config.rbs

Defined Under Namespace

Modules: AllowedInferenceGeos, DefaultInferenceGeo, WorkspaceGeo

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed_inference_geos: nil, default_inference_geo: nil, workspace_geo: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig for more details.

Parameters:



# File 'lib/anthropic/models/beta/organization/beta_data_residency_create_config.rb', line 41

Instance Attribute Details

#allowed_inference_geosArray<Symbol, Anthropic::Models::Beta::Organization::BetaAllowedInferenceGeo>, ...

Permitted inference geo values. Defaults to 'unrestricted' if omitted, which allows all geos. Use the string 'unrestricted' to allow all geos, or a list of specific geos.

Parameters:

  • value (Anthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig::allowed_inference_geos, nil)

Returns:



14
15
16
17
18
# File 'lib/anthropic/models/beta/organization/beta_data_residency_create_config.rb', line 14

optional :allowed_inference_geos,
union: -> {
  Anthropic::Beta::Organization::BetaDataResidencyCreateConfig::AllowedInferenceGeos
},
nil?: true

#default_inference_geoSymbol, ...

Default inference geo applied when requests omit the parameter. Defaults to 'global' if omitted. Must be a member of allowed_inference_geos unless allowed_inference_geos is "unrestricted".

Parameters:

  • value (Anthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig::default_inference_geo, nil)

Returns:



26
27
28
29
30
# File 'lib/anthropic/models/beta/organization/beta_data_residency_create_config.rb', line 26

optional :default_inference_geo,
enum: -> {
  Anthropic::Beta::Organization::BetaDataResidencyCreateConfig::DefaultInferenceGeo
},
nil?: true

#workspace_geoSymbol, ...

Geographic region for workspace data storage. Immutable after creation. Defaults to 'us' if omitted.

Parameters:

  • value (Anthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig::workspace_geo, nil)

Returns:



37
38
39
# File 'lib/anthropic/models/beta/organization/beta_data_residency_create_config.rb', line 37

optional :workspace_geo,
enum: -> { Anthropic::Beta::Organization::BetaDataResidencyCreateConfig::WorkspaceGeo },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/organization/beta_data_residency_create_config.rb', line 85

Instance Method Details

#to_hash{

Returns:

  • ({)


25
# File 'sig/anthropic/models/beta/organization/beta_data_residency_create_config.rbs', line 25

def to_hash: -> {