Class: Anthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig
- Defined in:
- lib/anthropic/models/beta/organization/beta_data_residency_update_config.rb,
sig/anthropic/models/beta/organization/beta_data_residency_update_config.rbs
Defined Under Namespace
Modules: AllowedInferenceGeos, DefaultInferenceGeo
Instance Attribute Summary collapse
-
#allowed_inference_geos ⇒ Array<Symbol, Anthropic::Models::Beta::Organization::BetaAllowedInferenceGeo>, ...
Permitted inference geo values.
-
#default_inference_geo ⇒ Symbol, ...
Default inference geo applied when requests omit the parameter.
Instance Method Summary collapse
-
#initialize(allowed_inference_geos: nil, default_inference_geo: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaDataResidencyUpdateConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allowed_inference_geos: nil, default_inference_geo: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig for more details.
|
|
# File 'lib/anthropic/models/beta/organization/beta_data_residency_update_config.rb', line 30
|
Instance Attribute Details
#allowed_inference_geos ⇒ Array<Symbol, Anthropic::Models::Beta::Organization::BetaAllowedInferenceGeo>, ...
Permitted inference geo values. Use 'unrestricted' to allow all geos, or a list of specific geos.
13 14 15 16 17 |
# File 'lib/anthropic/models/beta/organization/beta_data_residency_update_config.rb', line 13 optional :allowed_inference_geos, union: -> { Anthropic::Beta::Organization::BetaDataResidencyUpdateConfig::AllowedInferenceGeos }, nil?: true |
#default_inference_geo ⇒ Symbol, ...
Default inference geo applied when requests omit the parameter. Must be a member
of allowed_inference_geos unless allowed_inference_geos is "unrestricted".
24 25 26 27 28 |
# File 'lib/anthropic/models/beta/organization/beta_data_residency_update_config.rb', line 24 optional :default_inference_geo, enum: -> { Anthropic::Beta::Organization::BetaDataResidencyUpdateConfig::DefaultInferenceGeo }, nil?: true |
Instance Method Details
#to_hash ⇒ {
21 |
# File 'sig/anthropic/models/beta/organization/beta_data_residency_update_config.rbs', line 21
def to_hash: -> {
|