Class: Anthropic::Models::Beta::Organization::BetaOrganizationInvite

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/beta_organization_invite.rb,
sig/anthropic/models/beta/organization/beta_organization_invite.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Invites#create

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, accepted_at:, email:, expires_at:, invited_at:, rbac_group_ids:, role:, status:, type: :invite) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaOrganizationInvite for more details.

Parameters:

  • id (String)

    ID of the Invite.

  • accepted_at (Time, nil)

    RFC 3339 datetime string indicating when the Invite was accepted, or null.

  • email (String)

    Email of the User being invited.

  • expires_at (Time)

    RFC 3339 datetime string indicating when the Invite expires.

  • invited_at (Time)

    RFC 3339 datetime string indicating when the Invite was created.

  • rbac_group_ids (Array<String>)

    RBAC group IDs recorded on the Invite (Claude Enterprise organizations), to be a

  • role (Symbol, Anthropic::Models::Beta::BetaOrganizationRole)

    Organization role of the User.

  • status (Symbol, Anthropic::Models::Beta::Organization::BetaOrganizationInvite::Status)

    Status of the Invite.

  • type (Symbol, :invite) (defaults to: :invite)

    Object type.



# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 66

Instance Attribute Details

#accepted_atTime?

RFC 3339 datetime string indicating when the Invite was accepted, or null.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


19
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 19

required :accepted_at, Time, nil?: true

#emailString

Email of the User being invited.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 25

required :email, String

#expires_atTime

RFC 3339 datetime string indicating when the Invite expires.

Parameters:

  • value (Time)

Returns:

  • (Time)


31
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 31

required :expires_at, Time

#idString

ID of the Invite.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 13

required :id, String

#invited_atTime

RFC 3339 datetime string indicating when the Invite was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


37
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 37

required :invited_at, Time

#rbac_group_idsArray<String>

RBAC group IDs recorded on the Invite (Claude Enterprise organizations), to be assigned to the User when the Invite is accepted. [] when none.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


44
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 44

required :rbac_group_ids, Anthropic::Internal::Type::ArrayOf[String]

#roleSymbol, Anthropic::Models::Beta::BetaOrganizationRole

Organization role of the User.

Parameters:

  • value (Anthropic::Models::Beta::beta_organization_role)

Returns:



50
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 50

required :role, enum: -> { Anthropic::Beta::BetaOrganizationRole }

#statusSymbol, Anthropic::Models::Beta::Organization::BetaOrganizationInvite::Status

Status of the Invite.

Parameters:

  • value (Anthropic::Models::Beta::Organization::BetaOrganizationInvite::status)

Returns:



56
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 56

required :status, enum: -> { Anthropic::Beta::Organization::BetaOrganizationInvite::Status }

#typeSymbol, :invite

Object type.

For Invites, this is always "invite".

Parameters:

  • value (:invite)

Returns:

  • (Symbol, :invite)


64
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 64

required :type, const: :invite

Instance Method Details

#to_hash{

Returns:

  • ({)


49
# File 'sig/anthropic/models/beta/organization/beta_organization_invite.rbs', line 49

def to_hash: -> {