Class: Anthropic::Models::Beta::Organization::BetaOrganizationRateLimit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb,
sig/anthropic/models/beta/organization/beta_organization_rate_limit.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::RateLimits#list

Defined Under Namespace

Modules: Group, GroupType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, group:, group_type:, limits:, models:, type: :rate_limit) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaOrganizationRateLimit for more details.

`group_

Parameters:



# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 55

Instance Attribute Details

#group ⇒ Anthropic::Models::Beta::Organization::BetaOrganizationRateLimitModelGroup, ...

The rate-limit group this entry's limits apply to. Its type equals group_type.



21
# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 21

required :group, union: -> { Anthropic::Beta::Organization::BetaOrganizationRateLimit::Group }

#group_type ⇒ Symbol, Anthropic::Models::Beta::Organization::BetaOrganizationRateLimit::GroupType

Deprecated.

Use group.type instead. group_type is still returned and always equals

group.type.

Deprecated: use group.type instead. The kind of rate-limit group this entry represents. model_group entries apply to a family of models (listed in models); other values apply to an API-surface category and have models set to null. Always equal to group.type.

Parameters:

  • value (Anthropic::Models::Beta::Organization::BetaOrganizationRateLimit::group_type)

Returns:



33
# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 33

required :group_type, enum: -> { Anthropic::Beta::Organization::BetaOrganizationRateLimit::GroupType }

#id ⇒ String

Identifier of this rate-limit entry. It is stable within the organization and differs between organizations; the group's own identifier is group.id.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 14

required :id, String

#limits ⇒ Array<Anthropic::Models::Beta::Organization::BetaOrganizationRateLimitValue>

The limiter values that apply to this group.

Parameters:

  • value (::Array[Anthropic::Beta::Organization::BetaOrganizationRateLimitValue])

Returns:



39
40
# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 39

required :limits,
-> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::Organization::BetaOrganizationRateLimitValue] }

#models ⇒ Array<String>?

Model names this entry's limits apply to, including aliases. null when group_type is not "model_group".

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


47
# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 47

required :models, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#type ⇒ Symbol, :rate_limit

Object type. Always rate_limit for organization rate-limit entries.

Parameters:

  • value (:rate_limit)

Returns:

  • (Symbol, :rate_limit)


53
# File 'lib/anthropic/models/beta/organization/beta_organization_rate_limit.rb', line 53

required :type, const: :rate_limit

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


37
# File 'sig/anthropic/models/beta/organization/beta_organization_rate_limit.rbs', line 37

def to_hash: -> {