Module: Anthropic::Models::Beta::Organization::BetaServiceAccount::OrganizationRole

Extended by:
Internal::Type::Enum
Defined in:
lib/anthropic/models/beta/organization/beta_service_account.rb,
sig/anthropic/models/beta/organization/beta_service_account.rbs

Overview

Org-level role. A federation rule may only be created or retargeted to grant org:admin scope when this is admin. A rule granting org:admin whose target is later demoted to developer is rejected at token exchange. Rules granting org:admin are managed in the Console.

See Also:

  • Anthropic::Models::Beta::Organization::BetaServiceAccount#organization_role

Constant Summary collapse

ADMIN =

Returns:

  • (:admin)
:admin
DEVELOPER =

Returns:

  • (:developer)
:developer

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 121

Instance Method Details

#self?.values::Array[Anthropic::Models::Beta::Organization::BetaServiceAccount::organization_role]

Returns:

  • (::Array[Anthropic::Models::Beta::Organization::BetaServiceAccount::organization_role])


79
# File 'sig/anthropic/models/beta/organization/beta_service_account.rbs', line 79

def self?.values: -> ::Array[Anthropic::Models::Beta::Organization::BetaServiceAccount::organization_role]