Module: Anthropic::Models::Beta::Organization::ExternalKeyCreateParams::ProviderConfig
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/organization/external_key_create_params.rb,
sig/anthropic/models/beta/organization/external_key_create_params.rbs
Overview
KMS provider identity and auth coordinates.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Organization::BetaAWSExternalKeyConfig, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::Organization::BetaAWSExternalKeyConfig, Anthropic::Models::Beta::Organization::BetaGCPExternalKeyConfig, Anthropic::Models::Beta::Organization::BetaAzureExternalKeyConfigParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Organization::BetaAWSExternalKeyConfig, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::ExternalKeyCreateParams::ProviderConfig for more details.
94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/anthropic/models/beta/organization/external_key_create_params.rb', line 94 def self.new(type:, **args) case type.to_sym when :aws Anthropic::Beta::Organization::BetaAWSExternalKeyConfig.new(**args) when :gcp Anthropic::Beta::Organization::BetaGCPExternalKeyConfig.new(**args) when :azure Anthropic::Beta::Organization::BetaAzureExternalKeyConfigParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/organization/external_key_create_params.rb', line 60
|
.variants ⇒ Array(Anthropic::Models::Beta::Organization::BetaAWSExternalKeyConfig, Anthropic::Models::Beta::Organization::BetaGCPExternalKeyConfig, Anthropic::Models::Beta::Organization::BetaAzureExternalKeyConfigParam)
|
|
# File 'lib/anthropic/models/beta/organization/external_key_create_params.rb', line 64
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Organization::ExternalKeyCreateParams::provider_config]
61 |
# File 'sig/anthropic/models/beta/organization/external_key_create_params.rbs', line 61
def self?.variants: -> ::Array[Anthropic::Models::Beta::Organization::ExternalKeyCreateParams::provider_config]
|