Module: Anthropic::Models::Beta::Organization::Federation::BetaFederationIssuer::JWKS

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/organization/federation/beta_federation_issuer.rb,
sig/anthropic/models/beta/organization/federation/beta_federation_issuer.rbs

Overview

How signing keys are obtained for signature verification.

See Also:

  • Anthropic::Models::Beta::Organization::Federation::BetaFederationIssuer#jwks

Defined Under Namespace

Modules: Type

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Organization::Federation::BetaJWKSDiscovery, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String, nil] :ca_cert_pem Optional custom CA (PEM) for TLS verification of the JWKS fetch.

    @option args [String, nil] :discovery_base Set when the discovery URL differs from issuer_url.

    @option args [String] :url JWKS endpoint.

    @option args [Array<HashSymbol=>Object>] :keys Inline JWK objects.

Returns:

Raises:

  • (ArgumentError)


201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_issuer.rb', line 201

def self.new(type:, **args)
  case type.to_sym
  when :discovery
    Anthropic::Beta::Organization::Federation::BetaJWKSDiscovery.new(**args)
  when :explicit_url
    Anthropic::Beta::Organization::Federation::BetaJWKSExplicitURL.new(**args)
  when :inline
    Anthropic::Beta::Organization::Federation::BetaJWKSInline.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/organization/federation/beta_federation_issuer.rb', line 177

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Organization::Federation::BetaFederationIssuer::jwks]

Returns:

  • (::Array[Anthropic::Models::Beta::Organization::Federation::BetaFederationIssuer::jwks])


112
# File 'sig/anthropic/models/beta/organization/federation/beta_federation_issuer.rbs', line 112

def self?.variants: -> ::Array[Anthropic::Models::Beta::Organization::Federation::BetaFederationIssuer::jwks]