Class: Anthropic::Models::Beta::Organization::Federation::BetaFederationRuleWorkspace

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb,
sig/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(created_at:, created_by_actor_id:, federation_rule_id:, workspace_id:, workspace_name:, type: :federation_rule_workspace) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::Federation::BetaFederationRuleWorkspace for more details.

Parameters:

  • created_at (Time)

    When this workspace was enabled for the rule.

  • created_by_actor_id (String, nil)

    Tagged ID (user_... or svac_...) of the actor that enabled this workspace fo

  • federation_rule_id (String)

    Tagged ID of the federation rule.

  • workspace_id (String)

    Tagged ID of the workspace this rule is enabled for.

  • workspace_name (String, nil)

    Workspace display name. Populated when listing; null in the enable response.

  • type (Symbol, :federation_rule_workspace) (defaults to: :federation_rule_workspace)


# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 45

Instance Attribute Details

#created_atTime

When this workspace was enabled for the rule.

Parameters:

  • value (Time)

Returns:

  • (Time)


13
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 13

required :created_at, Time

#created_by_actor_idString?

Tagged ID (user_... or svac_...) of the actor that enabled this workspace for the rule, if known.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


20
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 20

required :created_by_actor_id, String, nil?: true

#federation_rule_idString

Tagged ID of the federation rule.

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 26

required :federation_rule_id, String

#typeSymbol, :federation_rule_workspace

Parameters:

  • value (:federation_rule_workspace)

Returns:

  • (Symbol, :federation_rule_workspace)


31
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 31

required :type, const: :federation_rule_workspace

#workspace_idString

Tagged ID of the workspace this rule is enabled for.

Parameters:

  • value (String)

Returns:

  • (String)


37
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 37

required :workspace_id, String

#workspace_nameString?

Workspace display name. Populated when listing; null in the enable response.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


43
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 43

required :workspace_name, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rbs', line 38

def to_hash: -> {