Class: Anthropic::Models::Beta::Organization::Federation::BetaServiceAccountTarget

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/federation/beta_service_account_target.rb,
sig/anthropic/models/beta/organization/federation/beta_service_account_target.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(service_account_id:, service_account_name: nil, type: :service_account) ⇒ Object

Bind to a fixed service account by ID.

Parameters:

  • service_account_id (String)

    Tagged ID of the service account to mint tokens for.

  • service_account_name (String, nil) (defaults to: nil)

    Service account's display name at read time. Ignored on writes.

  • type (Symbol, :service_account) (defaults to: :service_account)


# File 'lib/anthropic/models/beta/organization/federation/beta_service_account_target.rb', line 26

Instance Attribute Details

#service_account_idString

Tagged ID of the service account to mint tokens for.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/anthropic/models/beta/organization/federation/beta_service_account_target.rb', line 13

required :service_account_id, String

#service_account_nameString?

Service account's display name at read time. Ignored on writes.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


24
# File 'lib/anthropic/models/beta/organization/federation/beta_service_account_target.rb', line 24

optional :service_account_name, String, nil?: true

#typeSymbol, :service_account

Parameters:

  • value (:service_account)

Returns:

  • (Symbol, :service_account)


18
# File 'lib/anthropic/models/beta/organization/federation/beta_service_account_target.rb', line 18

required :type, const: :service_account

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/anthropic/models/beta/organization/federation/beta_service_account_target.rbs', line 26

def to_hash: -> {