Module: Anthropic::Models::Beta::Organization::Federation::IssuerCreateParams::JWKS
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/organization/federation/issuer_create_params.rb,
sig/anthropic/models/beta/organization/federation/issuer_create_params.rbs
Overview
How signing keys are obtained. Defaults to OIDC discovery.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Organization::Federation::BetaJWKSDiscovery, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::Organization::Federation::BetaJWKSDiscovery, Anthropic::Models::Beta::Organization::Federation::BetaJWKSExplicitURL, Anthropic::Models::Beta::Organization::Federation::BetaJWKSInline)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Organization::Federation::BetaJWKSDiscovery, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/anthropic/models/beta/organization/federation/issuer_create_params.rb', line 119 def self.new(type:, **args) case type.to_sym when :discovery Anthropic::Beta::Organization::Federation::BetaJWKSDiscovery.new(**args) when :explicit_url Anthropic::Beta::Organization::Federation::BetaJWKSExplicitURL.new(**args) when :inline Anthropic::Beta::Organization::Federation::BetaJWKSInline.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/organization/federation/issuer_create_params.rb', line 95
|
.variants ⇒ Array(Anthropic::Models::Beta::Organization::Federation::BetaJWKSDiscovery, Anthropic::Models::Beta::Organization::Federation::BetaJWKSExplicitURL, Anthropic::Models::Beta::Organization::Federation::BetaJWKSInline)
|
|
# File 'lib/anthropic/models/beta/organization/federation/issuer_create_params.rb', line 99
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Organization::Federation::IssuerCreateParams::jwks]
81 |
# File 'sig/anthropic/models/beta/organization/federation/issuer_create_params.rbs', line 81
def self?.variants: -> ::Array[Anthropic::Models::Beta::Organization::Federation::IssuerCreateParams::jwks]
|