Class: Anthropic::Models::Beta::Organization::Federation::RuleCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/organization/federation/rule_create_params.rb,
sig/anthropic/models/beta/organization/federation/rule_create_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Federation::Rules#create

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(issuer_id:, match:, name:, oauth_scope:, target:, applies_to_all_workspaces: nil, attributes: nil, description: nil, token_lifetime_seconds: nil, workspace_id: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::Federation::RuleCreateParams for more details.

Parameters:

  • issuer_id (String)

    Tagged ID of the federation issuer.

  • match (Anthropic::Models::Beta::Organization::Federation::BetaFederationRuleMatch)

    Conditions the verified JWT must satisfy for this rule to apply. At least one of

  • name (String)

    Slug identifier (lowercase, digits, hyphens). Unique within the organization; a

  • oauth_scope (String)

    Space-separated OAuth scopes. OAuth callers may only set workspace:developer o

  • target (Anthropic::Models::Beta::Organization::Federation::BetaServiceAccountTarget)

    Identity that tokens minted via this rule act as. Currently always a `service_ac

  • applies_to_all_workspaces (Boolean) (defaults to: nil)

    When true, enable this rule for every workspace in the org (including workspaces

  • attributes (Hash{Symbol=>String}, nil) (defaults to: nil)

    CEL expressions {name: expr} extracting named values from claims. Not yet supp

  • description (String, nil) (defaults to: nil)

    Optional free-text description.

  • token_lifetime_seconds (Integer) (defaults to: nil)

    Lifetime in seconds for access tokens minted via this rule (60-86400). Defaults

  • workspace_id (String, nil) (defaults to: nil)

    Tagged ID of the workspace to enable this rule for. Required unless `appliesto

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 91

Instance Attribute Details

#applies_to_all_workspacesBoolean?

When true, enable this rule for every workspace in the org (including workspaces created later).

Parameters:

Returns:



54
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 54

optional :applies_to_all_workspaces, Anthropic::Internal::Type::Boolean

#attributesHash{Symbol=>String}?

CEL expressions {name: expr} extracting named values from claims. Not yet supported; any non-empty value is rejected with 400.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


61
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 61

optional :attributes, Anthropic::Internal::Type::HashOf[String], nil?: true

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



89
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 89

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#descriptionString?

Optional free-text description.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


67
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 67

optional :description, String, nil?: true

#issuer_idString

Tagged ID of the federation issuer.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 17

required :issuer_id, String

#matchAnthropic::Models::Beta::Organization::Federation::BetaFederationRuleMatch

Conditions the verified JWT must satisfy for this rule to apply. At least one of subject_prefix (other than a wildcard-only value like *), claims, or condition is required; audience alone is not sufficient.

Parameters:

  • value (Anthropic::Beta::Organization::Federation::BetaFederationRuleMatch)

Returns:



25
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 25

required :match, -> { Anthropic::Beta::Organization::Federation::BetaFederationRuleMatch }

#nameString

Slug identifier (lowercase, digits, hyphens). Unique within the organization; a duplicate name returns 409.

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 32

required :name, String

#oauth_scopeString

Space-separated OAuth scopes. OAuth callers may only set workspace:developer or workspace:inference; other scopes (such as org:admin) require a Console session.

Parameters:

  • value (String)

Returns:

  • (String)


40
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 40

required :oauth_scope, String

#targetAnthropic::Models::Beta::Organization::Federation::BetaServiceAccountTarget

Identity that tokens minted via this rule act as. Currently always a service_account target.

Parameters:

  • value (Anthropic::Beta::Organization::Federation::BetaServiceAccountTarget)

Returns:



47
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 47

required :target, -> { Anthropic::Beta::Organization::Federation::BetaServiceAccountTarget }

#token_lifetime_secondsInteger?

Lifetime in seconds for access tokens minted via this rule (60-86400). Defaults to 3600 (1h). Minted tokens are capped at max(60, min(this value, 2 × remaining assertion validity)) seconds.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


75
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 75

optional :token_lifetime_seconds, Integer

#workspace_idString?

Tagged ID of the workspace to enable this rule for. Required unless applies_to_all_workspaces is true. Additional workspaces can be added via the /federation_rules/{federation_rule_id}/workspaces sub-resource.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


83
# File 'lib/anthropic/models/beta/organization/federation/rule_create_params.rb', line 83

optional :workspace_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


71
# File 'sig/anthropic/models/beta/organization/federation/rule_create_params.rbs', line 71

def to_hash: -> {