Class: Anthropic::Models::Beta::Organization::Federation::Rules::WorkspaceAddParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::Federation::Rules::WorkspaceAddParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/organization/federation/rules/workspace_add_params.rb,
sig/anthropic/models/beta/organization/federation/rules/workspace_add_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#federation_rule_id ⇒ String
ID of the federation rule.
-
#workspace_id ⇒ String
Tagged ID of the workspace to enable this rule for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(federation_rule_id:, workspace_id:, betas: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(federation_rule_id:, workspace_id:, betas: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_add_params.rb', line 32
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
30 |
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_add_params.rb', line 30 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#federation_rule_id ⇒ String
ID of the federation rule.
18 |
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_add_params.rb', line 18 required :federation_rule_id, String |
#workspace_id ⇒ String
Tagged ID of the workspace to enable this rule for.
24 |
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_add_params.rb', line 24 required :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
36 |
# File 'sig/anthropic/models/beta/organization/federation/rules/workspace_add_params.rbs', line 36
def to_hash: -> {
|