Module: Anthropic::Models::Beta::Organization::InviteListParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/anthropic/models/beta/organization/invite_list_params.rb,
sig/anthropic/models/beta/organization/invite_list_params.rbs

Constant Summary collapse

ACCEPTED =

Returns:

  • (:accepted)
:accepted
EXPIRED =

Returns:

  • (:expired)
:expired
PENDING =

Returns:

  • (:pending)
:pending

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 86

Instance Method Details

#initialize(after_id: nil, before_id: nil, email: nil, limit: nil, roles: nil, statuses: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::InviteListParams for more details.

Parameters:

  • after_id (String) (defaults to: nil)

    ID of the object to use as a cursor for pagination. When provided, returns the p

  • before_id (String) (defaults to: nil)

    ID of the object to use as a cursor for pagination. When provided, returns the p

  • email (String) (defaults to: nil)

    Filter by the email address the Invite was sent to. Matches the same way as the

  • limit (Integer) (defaults to: nil)

    Number of items to return per page.

  • roles (Array<String>) (defaults to: nil)

    Filter to items whose role equals one of the supplied values. Repeatable; valu

  • statuses (Array<Symbol, Anthropic::Models::Beta::Organization::InviteListParams::Status>) (defaults to: nil)

    Filter by Invite status. Repeatable; values are OR'ed together. Omit to return `

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


79
80
81
82
83
84
85
86
87
88
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 79

module Status
  extend Anthropic::Internal::Type::Enum

  ACCEPTED = :accepted
  EXPIRED = :expired
  PENDING = :pending

  # @!method self.values
  #   @return [Array<Symbol>]
end

#self?.values::Array[Anthropic::Models::Beta::Organization::InviteListParams::status]

Returns:

  • (::Array[Anthropic::Models::Beta::Organization::InviteListParams::status])


75
# File 'sig/anthropic/models/beta/organization/invite_list_params.rbs', line 75

def self?.values: -> ::Array[Anthropic::Models::Beta::Organization::InviteListParams::status]