Class: Anthropic::Models::Beta::Organization::WorkspaceCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/organization/workspace_create_params.rb,
sig/anthropic/models/beta/organization/workspace_create_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Workspaces#create

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, data_residency: nil, display_color: nil, external_key_id: nil, tags: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::WorkspaceCreateParams for more details.

Parameters:

  • name (String)

    Name of the Workspace.

  • data_residency (Anthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig, nil) (defaults to: nil)

    Data residency configuration for the workspace. If omitted, defaults to `workspa

  • display_color (String, nil) (defaults to: nil)

    Hex color code representing the Workspace in the Anthropic Console.

  • external_key_id (String, nil) (defaults to: nil)

    ID of the customer-managed encryption key (CMEK) configuration to use for this

  • tags (Hash{Symbol=>String}, nil) (defaults to: nil)

    User-defined tags as string key-value pairs. Keys may not begin with anthropic

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 61

Instance Attribute Details

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



59
# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 59

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#data_residencyAnthropic::Models::Beta::Organization::BetaDataResidencyCreateConfig?

Data residency configuration for the workspace. If omitted, defaults to workspace_geo: "us", allowed_inference_geos: "unrestricted", and default_inference_geo: "global".

Parameters:

  • value (Anthropic::Beta::Organization::BetaDataResidencyCreateConfig, nil)

Returns:



24
25
26
27
28
# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 24

optional :data_residency,
-> {
  Anthropic::Beta::Organization::BetaDataResidencyCreateConfig
},
nil?: true

#display_colorString?

Hex color code representing the Workspace in the Anthropic Console.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


34
# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 34

optional :display_color, String, nil?: true

#external_key_idString?

ID of the customer-managed encryption key (CMEK) configuration to use for this Workspace. Setting this field requires CMEK to be enabled for your organization. When set, data stored for this Workspace is encrypted with the referenced key. Create key configurations with the External Keys API. This field is write-once: once a key is attached to a Workspace it cannot be detached or replaced. To rotate key material, rotate the underlying key on your cloud KMS; the external_key_id stays the same.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 46

optional :external_key_id, String, nil?: true

#nameString

Name of the Workspace.

Parameters:

  • value (String)

Returns:

  • (String)


16
# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 16

required :name, String

#tagsHash{Symbol=>String}?

User-defined tags as string key-value pairs. Keys may not begin with anthropic.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


53
# File 'lib/anthropic/models/beta/organization/workspace_create_params.rb', line 53

optional :tags, Anthropic::Internal::Type::HashOf[String], nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


46
# File 'sig/anthropic/models/beta/organization/workspace_create_params.rbs', line 46

def to_hash: -> {