Class: Anthropic::Models::Beta::Organization::WorkspaceUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::WorkspaceUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/organization/workspace_update_params.rb,
sig/anthropic/models/beta/organization/workspace_update_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#data_residency ⇒ Anthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig?
Data residency configuration for the workspace.
-
#display_color ⇒ String?
Hex color code representing the Workspace in the Anthropic Console.
-
#external_key_id ⇒ String?
ID of the customer-managed encryption key (CMEK) configuration to use for this Workspace.
-
#name ⇒ String?
Name of the Workspace.
-
#tags ⇒ Hash{Symbol=>String, nil}?
User-defined tags as string key-value pairs.
- #workspace_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(workspace_id:, data_residency: nil, display_color: nil, external_key_id: nil, name: nil, tags: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WorkspaceUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(workspace_id:, data_residency: nil, display_color: nil, external_key_id: nil, name: nil, tags: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::WorkspaceUpdateParams for more details.
|
|
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 62
|
Instance Attribute Details
#data_residency ⇒ Anthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig?
Data residency configuration for the workspace.
21 22 23 24 25 |
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 21 optional :data_residency, -> { Anthropic::Beta::Organization::BetaDataResidencyUpdateConfig }, nil?: true |
#display_color ⇒ String?
Hex color code representing the Workspace in the Anthropic Console.
31 |
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 31 optional :display_color, String |
#external_key_id ⇒ String?
ID of the customer-managed encryption key (CMEK) configuration to use for this
Workspace. Setting this field requires CMEK to be enabled for your organization.
When set, data stored for this Workspace is encrypted with the referenced key.
Create key configurations with the External Keys API. On Claude Platform on AWS
the value is the AWS KMS key ARN, and the key must be a single-Region key in the
same AWS account and Region as the Workspace. On that platform the key is
validated against this Workspace when it is attached, so a key-policy problem is
reported as an error on this request. This field is write-once: once a key is
attached to a Workspace it cannot be detached or replaced. To rotate key
material, rotate the underlying key on your cloud KMS; the external_key_id
stays the same.
47 |
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 47 optional :external_key_id, String |
#name ⇒ String?
Name of the Workspace.
53 |
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 53 optional :name, String |
#tags ⇒ Hash{Symbol=>String, nil}?
User-defined tags as string key-value pairs. Keys may not begin with
anthropic.
60 |
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 60 optional :tags, Anthropic::Internal::Type::HashOf[String, nil?: true], nil?: true |
#workspace_id ⇒ String
15 |
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 15 required :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/anthropic/models/beta/organization/workspace_update_params.rbs', line 48
def to_hash: -> {
|