Class: Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb,
sig/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Workspaces::RateLimits#list

Defined Under Namespace

Modules: GroupType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(group_type:, limits:, models:, rate_limit_id:, workspace_id:, type: :workspace_rate_limit) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit for more details.

`group_

Parameters:



# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 52

Instance Attribute Details

#group_typeSymbol, Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit::GroupType

The kind of rate-limit group this entry represents. model_group entries apply to a family of models (listed in models); other values apply to an API-surface category and have models set to null.

Parameters:

  • value (Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit::group_type)

Returns:



16
17
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 16

required :group_type,
enum: -> { Anthropic::Beta::Organization::Workspaces::BetaWorkspaceRateLimit::GroupType }

#limitsArray<Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue>

The limiter values overridden for this group in this workspace. Limiter types without a workspace override are omitted and inherit the organization value.

Parameters:

  • value (::Array[Anthropic::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue])

Returns:



24
25
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 24

required :limits,
-> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue] }

#modelsArray<String>?

Model names this entry's limits apply to, including aliases. null when group_type is not "model_group".

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


32
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 32

required :models, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#rate_limit_idString

The id of the RateLimit group this override applies to.

Parameters:

  • value (String)

Returns:

  • (String)


38
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 38

required :rate_limit_id, String

#typeSymbol, :workspace_rate_limit

Object type. Always workspace_rate_limit for workspace rate-limit entries.

Parameters:

  • value (:workspace_rate_limit)

Returns:

  • (Symbol, :workspace_rate_limit)


44
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 44

required :type, const: :workspace_rate_limit

#workspace_idString

ID of the Workspace this override applies to.

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 50

required :workspace_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rbs', line 38

def to_hash: -> {