Class: Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue
- Defined in:
- lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rb,
sig/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rbs
Instance Attribute Summary collapse
-
#org_limit ⇒ Integer?
The organization-level value for the same limiter type, for reference.
-
#type ⇒ String
The limiter type (for example,
requests_per_minuteorinput_tokens_per_minute). -
#value ⇒ Integer
The workspace-level override value for this limiter type.
Instance Method Summary collapse
-
#initialize(org_limit:, type:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaWorkspaceRateLimitValue for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(org_limit:, type:, value:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue for more details.
|
|
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rb', line 29
|
Instance Attribute Details
#org_limit ⇒ Integer?
The organization-level value for the same limiter type, for reference. null
when the organization has no limit configured for this limiter type.
14 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rb', line 14 required :org_limit, Integer, nil?: true |
#type ⇒ String
The limiter type (for example, requests_per_minute or
input_tokens_per_minute).
21 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rb', line 21 required :type, String |
#value ⇒ Integer
The workspace-level override value for this limiter type.
27 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rb', line 27 required :value, Integer |
Instance Method Details
#to_hash ⇒ {
22 |
# File 'sig/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit_value.rbs', line 22
def to_hash: -> {
|