Module: Anthropic::Models::Beta::SessionCreateParams::Agent

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/session_create_params.rb,
sig/anthropic/models/beta/session_create_params.rbs

Overview

Agent identifier. Accepts the agent ID string, which pins the latest version for the session, or an agent object with both id and version specified.

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::SessionCreateParams::agent]

Returns:

  • (::Array[Anthropic::Models::Beta::SessionCreateParams::agent])


73
# File 'sig/anthropic/models/beta/session_create_params.rbs', line 73

def self?.variants: -> ::Array[Anthropic::Models::Beta::SessionCreateParams::agent]