Module: Anthropic::Models::Beta::SessionCreateParams::Resource
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/session_create_params.rb,
sig/anthropic/models/beta/session_create_params.rbs
Overview
Union of resources that can be mounted into a session.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceParams, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceParams, Anthropic::Models::Beta::BetaManagedAgentsFileResourceParams, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceParams, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::SessionCreateParams::Resource for more details.
205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/anthropic/models/beta/session_create_params.rb', line 205 def self.new(type:, **args) case type.to_sym when :github_repository Anthropic::Beta::BetaManagedAgentsGitHubRepositoryResourceParams.new(**args) when :file Anthropic::Beta::BetaManagedAgentsFileResourceParams.new(**args) when :memory_store Anthropic::Beta::BetaManagedAgentsMemoryStoreResourceParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceParams, Anthropic::Models::Beta::BetaManagedAgentsFileResourceParams, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam)
|
|
# File 'lib/anthropic/models/beta/session_create_params.rb', line 173
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::SessionCreateParams::resource]
134 |
# File 'sig/anthropic/models/beta/session_create_params.rbs', line 134
def self?.variants: -> ::Array[Anthropic::Models::Beta::SessionCreateParams::resource]
|