Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#context ⇒ String?
Additional context about the document for the model.
-
#source ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, ...
Union type for document source variants.
-
#title ⇒ String?
The title of the document.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(source:, type:, context: nil, title: nil) ⇒ Object
constructor
Document content, either specified directly as base64 data, as text, or as a reference via a URL.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(source:, type:, context: nil, title: nil) ⇒ Object
Document content, either specified directly as base64 data, as text, or as a reference via a URL.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 31
|
Instance Attribute Details
#context ⇒ String?
Additional context about the document for the model.
23 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 23 optional :context, String, nil?: true |
#source ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, ...
Union type for document source variants.
12 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 12 required :source, union: -> { Anthropic::Beta::Sessions::BetaManagedAgentsDocumentBlock::Source } |
#title ⇒ String?
The title of the document.
29 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 29 optional :title, String, nil?: true |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::Type
17 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 17 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsDocumentBlock::Type } |
Class Method Details
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource)
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 63
|