Module: Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_document_block.rbs
Overview
Union type for document source variants.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource)
Instance Method Summary collapse
- #self?.variants ⇒ ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::source]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 95 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Beta::Sessions::BetaManagedAgentsBase64DocumentSource.new(**args) when :text Anthropic::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource.new(**args) when :url Anthropic::Beta::Sessions::BetaManagedAgentsURLDocumentSource.new(**args) when :file Anthropic::Beta::Sessions::BetaManagedAgentsFileDocumentSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 71
|
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource)
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 75
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::source]
58 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_document_block.rbs', line 58
def self?.variants: -> ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::source]
|