Module: Anthropic::Models::Beta::Sessions::BetaManagedAgentsMCPConnectionFailedError::RetryStatus

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_mcp_connection_failed_error.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_mcp_connection_failed_error.rbs

Overview

What the client should do next in response to this error.

See Also:

  • Anthropic::Models::Beta::Sessions::BetaManagedAgentsMCPConnectionFailedError#retry_status

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsRetryStatusRetrying, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.



72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_mcp_connection_failed_error.rb', line 72

def self.new(type:, **args)
  case type.to_sym
  when :retrying
    Anthropic::Beta::Sessions::BetaManagedAgentsRetryStatusRetrying.new(**args)
  when :exhausted
    Anthropic::Beta::Sessions::BetaManagedAgentsRetryStatusExhausted.new(**args)
  when :terminal
    Anthropic::Beta::Sessions::BetaManagedAgentsRetryStatusTerminal.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsMCPConnectionFailedError::retry_status]

Returns:

  • (::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsMCPConnectionFailedError::retry_status])


44
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_mcp_connection_failed_error.rbs', line 44

def self?.variants: -> ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsMCPConnectionFailedError::retry_status]