Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsModelOverloadedError
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsModelOverloadedError
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_model_overloaded_error.rb
Defined Under Namespace
Modules: RetryStatus, Type
Instance Attribute Summary collapse
-
#message ⇒ String
Human-readable error description.
-
#retry_status ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsRetryStatusRetrying, ...
What the client should do next in response to this error.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsModelOverloadedError::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(message:, retry_status:, type:) ⇒ Object
constructor
The model is currently overloaded.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(message:, retry_status:, type:) ⇒ Object
The model is currently overloaded. Emitted after automatic retries are exhausted.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_model_overloaded_error.rb', line 26
|
Instance Attribute Details
#message ⇒ String
Human-readable error description.
12 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_model_overloaded_error.rb', line 12 required :message, String |
#retry_status ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsRetryStatusRetrying, ...
What the client should do next in response to this error.
18 19 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_model_overloaded_error.rb', line 18 required :retry_status, union: -> { Anthropic::Beta::Sessions::BetaManagedAgentsModelOverloadedError::RetryStatus } |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsModelOverloadedError::Type
24 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_model_overloaded_error.rb', line 24 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsModelOverloadedError::Type } |
Class Method Details
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsRetryStatusRetrying, Anthropic::Models::Beta::Sessions::BetaManagedAgentsRetryStatusExhausted, Anthropic::Models::Beta::Sessions::BetaManagedAgentsRetryStatusTerminal)
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_model_overloaded_error.rb', line 53
|