Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#citations ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultCitations
Citation settings for a search result.
-
#content ⇒ Array<Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultContent>
Array of text content blocks from the search result.
-
#source ⇒ String
The URL source of the search result.
-
#title ⇒ String
The title of the search result.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock::Type
Instance Method Summary collapse
-
#initialize(citations:, content:, source:, title:, type:) ⇒ Object
constructor
A block containing a web search result.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(citations:, content:, source:, title:, type:) ⇒ Object
A block containing a web search result.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb', line 38
|
Instance Attribute Details
#citations ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultCitations
Citation settings for a search result.
12 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb', line 12 required :citations, -> { Anthropic::Beta::Sessions::BetaManagedAgentsSearchResultCitations } |
#content ⇒ Array<Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultContent>
Array of text content blocks from the search result.
18 19 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb', line 18 required :content, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::Sessions::BetaManagedAgentsSearchResultContent] } |
#source ⇒ String
The URL source of the search result.
25 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb', line 25 required :source, String |
#title ⇒ String
The title of the search result.
31 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb', line 31 required :title, String |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock::Type
36 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_search_result_block.rb', line 36 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSearchResultBlock::Type } |