Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionRefusalStopDetails
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionRefusalStopDetails
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rbs
Defined Under Namespace
Modules: Category
Instance Attribute Summary collapse
-
#category ⇒ Symbol, ...
The policy category that triggered the refusal, or
nullwhen there is no named category. -
#explanation ⇒ String?
Human-readable explanation of the refusal, or
nullwhen none is available. - #type ⇒ Symbol, :refusal
Instance Method Summary collapse
-
#initialize(category:, explanation:, type: :refusal) ⇒ Object
constructor
Structured information about a refusal.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(category:, explanation:, type: :refusal) ⇒ Object
Structured information about a refusal.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionRefusalStopDetails for more details.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rb', line 31
|
Instance Attribute Details
#category ⇒ Symbol, ...
The policy category that triggered the refusal, or null when there is no named
category. New values can be added over time.
13 14 15 16 17 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rb', line 13 required :category, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionRefusalStopDetails::Category }, nil?: true |
#explanation ⇒ String?
Human-readable explanation of the refusal, or null when none is available. The
wording can change, so do not parse it.
24 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rb', line 24 required :explanation, String, nil?: true |
#type ⇒ Symbol, :refusal
29 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rb', line 29 required :type, const: :refusal |
Instance Method Details
#to_hash ⇒ {
25 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_session_refusal_stop_details.rbs', line 25
def to_hash: -> {
|