Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionRequiresAction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_session_requires_action.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(event_ids:, type:) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionRequiresAction for more details.

The agent is idle waiting on one or more blocking user-input events (tool confirmation, custom tool result, etc.). Resolving all of them transitions the session back to running.

Parameters:



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_requires_action.rb', line 20

Instance Attribute Details

#event_idsArray<String>

The ids of events the agent is blocked on. Resolving fewer than all re-emits ‘session.status_idle` with the remainder.

Returns:

  • (Array<String>)


13
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_requires_action.rb', line 13

required :event_ids, Anthropic::Internal::Type::ArrayOf[String]

#typeSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionRequiresAction::Type



18
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_requires_action.rb', line 18

required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionRequiresAction::Type }