Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionStatusIdleEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_session_status_idle_event.rb

Defined Under Namespace

Modules: StopReason, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, processed_at:, stop_reason:, type:) ⇒ Object

Indicates the agent has paused and is awaiting user input.

Parameters:



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_status_idle_event.rb', line 32

Instance Attribute Details

#idString

Unique identifier for this event.

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_status_idle_event.rb', line 12

required :id, String

#processed_atTime

A timestamp in RFC 3339 format

Returns:

  • (Time)


18
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_status_idle_event.rb', line 18

required :processed_at, Time

#stop_reasonAnthropic::Models::Beta::Sessions::BetaManagedAgentsSessionEndTurn, ...

The agent completed its turn naturally and is ready for the next user message.



24
25
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_status_idle_event.rb', line 24

required :stop_reason,
union: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionStatusIdleEvent::StopReason }

#typeSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionStatusIdleEvent::Type



30
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_status_idle_event.rb', line 30

required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionStatusIdleEvent::Type }