Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#agent ⇒ Anthropic::Models::Beta::BetaManagedAgentsSessionThreadAgent, Anthropic::Models::Beta::BetaManagedAgentsAdvisor
The resolved agent a session thread runs: a saved-agent snapshot, the platform advisor entry, or an inline-defined (ephemeral) agent snapshot.
-
#archived_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#id ⇒ String
Unique identifier for this thread.
-
#parent_thread_id ⇒ String?
Parent thread that spawned this thread.
-
#session_id ⇒ String
The session this thread belongs to.
-
#stats ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats?
Timing statistics for a session thread.
-
#status ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatus
SessionThreadStatus enum.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread::Type
-
#updated_at ⇒ Time
A timestamp in RFC 3339 format.
-
#usage ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadUsage?
Cumulative token usage for a session thread across all turns.
Instance Method Summary collapse
-
#initialize(id:, agent:, archived_at:, created_at:, parent_thread_id:, session_id:, stats:, status:, type:, updated_at:, usage:) ⇒ Object
constructor
An execution thread within a
session. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, agent:, archived_at:, created_at:, parent_thread_id:, session_id:, stats:, status:, type:, updated_at:, usage:) ⇒ Object
An execution thread within a session. Each session has one primary thread plus
zero or more child threads spawned by the coordinator.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread for more details.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 75
|
Instance Attribute Details
#agent ⇒ Anthropic::Models::Beta::BetaManagedAgentsSessionThreadAgent, Anthropic::Models::Beta::BetaManagedAgentsAdvisor
The resolved agent a session thread runs: a saved-agent snapshot, the platform advisor entry, or an inline-defined (ephemeral) agent snapshot.
20 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 20 required :agent, union: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThread::Agent } |
#archived_at ⇒ Time?
A timestamp in RFC 3339 format
26 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 26 required :archived_at, Time, nil?: true |
#created_at ⇒ Time
A timestamp in RFC 3339 format
32 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 32 required :created_at, Time |
#id ⇒ String
Unique identifier for this thread.
13 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 13 required :id, String |
#parent_thread_id ⇒ String?
Parent thread that spawned this thread. Null for the primary thread.
38 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 38 required :parent_thread_id, String, nil?: true |
#session_id ⇒ String
The session this thread belongs to.
44 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 44 required :session_id, String |
#stats ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats?
Timing statistics for a session thread.
50 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 50 required :stats, -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStats }, nil?: true |
#status ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatus
SessionThreadStatus enum
56 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 56 required :status, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStatus } |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread::Type
61 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 61 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThread::Type } |
#updated_at ⇒ Time
A timestamp in RFC 3339 format
67 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 67 required :updated_at, Time |
#usage ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadUsage?
Cumulative token usage for a session thread across all turns.
73 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 73 required :usage, -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadUsage }, nil?: true |
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rbs', line 57
def to_hash: -> {
|