Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(active_seconds: nil, duration_seconds: nil, startup_seconds: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats for more details.

Timing statistics for a session thread.

Parameters:

  • active_seconds (Float) (defaults to: nil)

    Cumulative time in seconds the thread spent actively running. Excludes idle time

  • duration_seconds (Float) (defaults to: nil)

    Elapsed time since thread creation in seconds. For archived threads, frozen at t

  • startup_seconds (Float) (defaults to: nil)

    Time in seconds for the thread to begin running. Zero for child threads, which s



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 29

Instance Attribute Details

#active_secondsFloat?

Cumulative time in seconds the thread spent actively running. Excludes idle time.

Returns:

  • (Float, nil)


13
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 13

optional :active_seconds, Float

#duration_secondsFloat?

Elapsed time since thread creation in seconds. For archived threads, frozen at the final update.

Returns:

  • (Float, nil)


20
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 20

optional :duration_seconds, Float

#startup_secondsFloat?

Time in seconds for the thread to begin running. Zero for child threads, which start immediately.

Returns:

  • (Float, nil)


27
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 27

optional :startup_seconds, Float