Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatusIdleEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb

Defined Under Namespace

Modules: StopReason, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, agent_name:, processed_at:, session_thread_id:, stop_reason:, type:) ⇒ Object

A session thread has yielded and is awaiting input. Emitted on the thread’s own stream and cross-posted to the primary stream for child threads.

Parameters:



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 45

Instance Attribute Details

#agent_nameString

Name of the agent the thread runs.

Returns:

  • (String)


18
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 18

required :agent_name, String

#idString

Unique identifier for this event.

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 12

required :id, String

#processed_atTime

A timestamp in RFC 3339 format

Returns:

  • (Time)


24
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 24

required :processed_at, Time

#session_thread_idString

Public sthr_ ID of the thread that went idle.

Returns:

  • (String)


30
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 30

required :session_thread_id, String

#stop_reasonAnthropic::Models::Beta::Sessions::BetaManagedAgentsSessionEndTurn, ...

The agent completed its turn naturally and is ready for the next user message.



36
37
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 36

required :stop_reason,
union: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStatusIdleEvent::StopReason }

#typeSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatusIdleEvent::Type



42
43
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_idle_event.rb', line 42

required :type,
enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStatusIdleEvent::Type }