Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatusTerminatedEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatusTerminatedEvent
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#agent_name ⇒ String
Name of the agent the thread runs.
-
#id ⇒ String
Unique identifier for this event.
-
#processed_at ⇒ Time
A timestamp in RFC 3339 format.
-
#session_thread_id ⇒ String
Public sthr_ ID of the thread that terminated.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatusTerminatedEvent::Type
Instance Method Summary collapse
-
#initialize(id:, agent_name:, processed_at:, session_thread_id:, type:) ⇒ Object
constructor
A session thread has terminated and will accept no further input.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, agent_name:, processed_at:, session_thread_id:, type:) ⇒ Object
A session thread has terminated and will accept no further input. Emitted on the thread’s own stream and cross-posted to the primary stream for child threads.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb', line 38
|
Instance Attribute Details
#agent_name ⇒ String
Name of the agent the thread runs.
18 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb', line 18 required :agent_name, String |
#id ⇒ String
Unique identifier for this event.
12 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb', line 12 required :id, String |
#processed_at ⇒ Time
A timestamp in RFC 3339 format
24 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb', line 24 required :processed_at, Time |
#session_thread_id ⇒ String
Public sthr_ ID of the thread that terminated.
30 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb', line 30 required :session_thread_id, String |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatusTerminatedEvent::Type
35 36 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_status_terminated_event.rb', line 35 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStatusTerminatedEvent::Type } |