Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionUsageSnapshot

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rbs

Constant Summary collapse

Anthropic =

Returns:

  • (:BetaMonetaryAmount)

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(active_seconds: nil, cache_creation: nil, cache_read_input_tokens: nil, input_tokens: nil, list_cost: nil, output_tokens: nil, server_tool_use: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionUsageSnapshot for more details.

Point-in-time snapshot of a session's cumulative usage.

Parameters:

  • active_seconds (Float) (defaults to: nil)

    Cumulative time in seconds during which the session had at least one thread in r

  • cache_creation (Anthropic::Models::Beta::BetaManagedAgentsCacheCreationUsage) (defaults to: nil)

    Prompt-cache creation token usage broken down by cache lifetime.

  • cache_read_input_tokens (Integer) (defaults to: nil)

    Total tokens read from prompt cache.

  • input_tokens (Integer) (defaults to: nil)

    Total input tokens consumed across all turns.

  • list_cost (Anthropic::Models::BetaMonetaryAmount) (defaults to: nil)

    A monetary amount in a specific currency.

  • output_tokens (Integer) (defaults to: nil)

    Total output tokens generated across all turns.

  • server_tool_use (Anthropic::Models::Beta::BetaManagedAgentsServerToolUsage) (defaults to: nil)

    Cumulative count of server-executed tool invocations, broken down by tool.



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 52

Instance Attribute Details

#active_secondsFloat?

Cumulative time in seconds during which the session had at least one thread in running status. Overlapping activity from concurrent threads is counted once. This is the duration the session's runtime cost is priced on.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


14
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 14

optional :active_seconds, Float

#cache_creationAnthropic::Models::Beta::BetaManagedAgentsCacheCreationUsage?

Prompt-cache creation token usage broken down by cache lifetime.



20
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 20

optional :cache_creation, -> { Anthropic::Beta::BetaManagedAgentsCacheCreationUsage }

#cache_read_input_tokensInteger?

Total tokens read from prompt cache.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 26

optional :cache_read_input_tokens, Integer

#input_tokensInteger?

Total input tokens consumed across all turns.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 32

optional :input_tokens, Integer

#list_costAnthropic::Models::BetaMonetaryAmount?

A monetary amount in a specific currency.



38
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 38

optional :list_cost, -> { Anthropic::BetaMonetaryAmount }

#output_tokensInteger?

Total output tokens generated across all turns.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


44
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 44

optional :output_tokens, Integer

#server_tool_useAnthropic::Models::Beta::BetaManagedAgentsServerToolUsage?

Cumulative count of server-executed tool invocations, broken down by tool.



50
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rb', line 50

optional :server_tool_use, -> { Anthropic::Beta::BetaManagedAgentsServerToolUsage }

Instance Method Details

#to_hash{

Returns:

  • ({)


61
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_session_usage_snapshot.rbs', line 61

def to_hash: -> {