Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb

Defined Under Namespace

Modules: Content, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, custom_tool_use_id:, type:, content: nil, is_error: nil, processed_at: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEvent for more details.

Event sent by the client providing the result of a custom tool execution.

Parameters:



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 47

Instance Attribute Details

#contentArray<Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsImageBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock>?

The result content returned by the tool.



32
33
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 32

optional :content,
-> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEvent::Content] }

#custom_tool_use_idString

The id of the ‘agent.custom_tool_use` event this result corresponds to, which can be found in the last `session.status_idle` [event’s](platform.claude.com/docs/en/api/beta/sessions/events/list#beta_managed_agents_session_requires_action.event_ids) ‘stop_reason.event_ids` field.

Returns:

  • (String)


21
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 21

required :custom_tool_use_id, String

#idString

Unique identifier for this event.

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 12

required :id, String

#is_errorBoolean?

Whether the tool execution resulted in an error.

Returns:



39
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 39

optional :is_error, Anthropic::Internal::Type::Boolean, nil?: true

#processed_atTime?

A timestamp in RFC 3339 format

Returns:

  • (Time, nil)


45
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 45

optional :processed_at, Time, nil?: true

#typeSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEvent::Type



26
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 26

required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEvent::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event.rb', line 72