Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#content ⇒ Array<Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsImageBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock>?
The result content returned by the tool.
-
#custom_tool_use_id ⇒ String
The id of the
agent.custom_tool_useevent this result corresponds to, which can be found in the lastsession.status_idleevent'sstop_reason.event_idsfield. -
#is_error ⇒ Boolean?
Whether the tool execution resulted in an error.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(custom_tool_use_id:, type:, content: nil, is_error: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsUserCustomToolResultEventParams for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(custom_tool_use_id:, type:, content: nil, is_error: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams for more details.
Parameters for providing the result of a custom tool execution.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 36
|
Instance Attribute Details
#content ⇒ Array<Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsImageBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock>?
The result content returned by the tool.
27 28 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 27 optional :content, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::Content] } |
#custom_tool_use_id ⇒ String
The id of the agent.custom_tool_use event this result corresponds to, which
can be found in the last session.status_idle
event's
stop_reason.event_ids field.
15 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 15 required :custom_tool_use_id, String |
#is_error ⇒ Boolean?
Whether the tool execution resulted in an error.
34 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 34 optional :is_error, Anthropic::Internal::Type::Boolean, nil?: true |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::Type
20 21 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 20 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 57
|
Instance Method Details
#to_hash ⇒ {
33 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rbs', line 33
def to_hash: -> {
|