Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolConfirmationEventParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb

Defined Under Namespace

Modules: Result, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(result:, tool_use_id:, type:, deny_message: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolConfirmationEventParams for more details.

Parameters for confirming or denying a tool execution request.

Parameters:



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb', line 37

Instance Attribute Details

#deny_messageString?

Optional message providing context for a ‘deny’ decision. Only allowed when result is ‘deny’.

Returns:

  • (String, nil)


35
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb', line 35

optional :deny_message, String, nil?: true

#resultSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolConfirmationEventParams::Result

UserToolConfirmationResult enum



12
13
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb', line 12

required :result,
enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsUserToolConfirmationEventParams::Result }

#tool_use_idString

The id of the ‘agent.tool_use` or `agent.mcp_tool_use` event this result corresponds to, which can be found in the last `session.status_idle` [event’s](platform.claude.com/docs/en/api/beta/sessions/events/list#beta_managed_agents_session_requires_action.event_ids) ‘stop_reason.event_ids` field.

Returns:

  • (String)


22
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb', line 22

required :tool_use_id, String

#typeSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolConfirmationEventParams::Type



27
28
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb', line 27

required :type,
enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsUserToolConfirmationEventParams::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_confirmation_event_params.rb', line 61