Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolResultEventParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_result_event_params.rb

Defined Under Namespace

Modules: Content, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(tool_use_id:, type:, content: nil, is_error: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolResultEventParams for more details.

Parameters for providing the result of an agent-toolset tool execution. Only valid on ‘self_hosted` environments, where sandbox-routed tools are executed by the client rather than the server.

Parameters:



# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_result_event_params.rb', line 35

Instance Attribute Details

#is_errorBoolean?

Whether the tool execution resulted in an error.

Returns:



33
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_result_event_params.rb', line 33

optional :is_error, Anthropic::Internal::Type::Boolean, nil?: true

#tool_use_idString

The id of the ‘agent.tool_use` event this result corresponds to, which can be found in the last `session.status_idle` [event’s](platform.claude.com/docs/en/api/beta/sessions/events/list#beta_managed_agents_session_requires_action.event_ids) ‘stop_reason.event_ids` field.

Returns:

  • (String)


15
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_result_event_params.rb', line 15

required :tool_use_id, String

#typeSymbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserToolResultEventParams::Type



20
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_result_event_params.rb', line 20

required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsUserToolResultEventParams::Type }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_tool_result_event_params.rb', line 58