Class: Anthropic::Models::Beta::Sessions::ResourceListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/sessions/resource_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(session_id:, limit: nil, page: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::ResourceListParams for more details.

Parameters:

  • session_id (String)
  • limit (Integer) (defaults to: nil)

    Maximum number of resources to return per page (max 1000). If omitted, returns a

  • page (String) (defaults to: nil)

    Opaque cursor from a previous response’s next_page field.

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/sessions/resource_list_params.rb', line 36

Instance Attribute Details

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



34
# File 'lib/anthropic/models/beta/sessions/resource_list_params.rb', line 34

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#limitInteger?

Maximum number of resources to return per page (max 1000). If omitted, returns all resources.

Returns:

  • (Integer, nil)


22
# File 'lib/anthropic/models/beta/sessions/resource_list_params.rb', line 22

optional :limit, Integer

#pageString?

Opaque cursor from a previous response’s next_page field.

Returns:

  • (String, nil)


28
# File 'lib/anthropic/models/beta/sessions/resource_list_params.rb', line 28

optional :page, String

#session_idString

Returns:

  • (String)


15
# File 'lib/anthropic/models/beta/sessions/resource_list_params.rb', line 15

required :session_id, String