Class: Anthropic::Models::Beta::Skills::BetaSkillVersion

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/skills/beta_skill_version.rb,
sig/anthropic/models/beta/skills/beta_skill_version.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Skills::Versions#create

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, description:, name:, skill_id:, type: :skill_version) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Skills::BetaSkillVersion for more details.

Parameters:

  • id (String)

    Unique identifier for this Skill Version. The id addresses the version in

  • created_at (Time)

    ISO 8601 timestamp of when the skill was created.

  • description (String)

    Description of the skill version.

  • name (String)

    The Skill's immutable kebab-case slug, set at creation from the first

  • skill_id (String)

    Unique identifier for the skill.

  • type (Symbol, :skill_version) (defaults to: :skill_version)

    Object type.



# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 55

Instance Attribute Details

#created_atTime

ISO 8601 timestamp of when the skill was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


20
# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 20

required :created_at, Time

#descriptionString

Description of the skill version.

This is extracted from the SKILL.md file in the skill upload.

Parameters:

  • value (String)

Returns:

  • (String)


28
# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 28

required :description, String

#idString

Unique identifier for this Skill Version. The id addresses the version in paths and pins it in references.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 14

required :id, String

#nameString

The Skill's immutable kebab-case slug, set at creation from the first upload's SKILL.md frontmatter name (or its enclosing directory). Every later upload must resolve to the same value. Also the top-level directory of the Skill's mounted files and the base name of a downloaded archive.

Parameters:

  • value (String)

Returns:

  • (String)


37
# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 37

required :name, String

#skill_idString

Unique identifier for the skill.

The format and length of IDs may change over time.

Parameters:

  • value (String)

Returns:

  • (String)


45
# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 45

required :skill_id, String

#typeSymbol, :skill_version

Object type.

For Skill Versions, this is always "skill_version".

Parameters:

  • value (:skill_version)

Returns:

  • (Symbol, :skill_version)


53
# File 'lib/anthropic/models/beta/skills/beta_skill_version.rb', line 53

required :type, const: :skill_version

Instance Method Details

#to_hash{

Returns:

  • ({)


37
# File 'sig/anthropic/models/beta/skills/beta_skill_version.rbs', line 37

def to_hash: -> {