Class: Anthropic::Models::Beta::Tunnels::BetaTunnelCertificate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb,
sig/anthropic/models/beta/tunnels/beta_tunnel_certificate.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Tunnels::Certificates#create

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_at:, created_at:, expires_at:, fingerprint:, tunnel_id:, type: :tunnel_certificate) ⇒ Object

A CA certificate attached to a tunnel.

Parameters:

  • id (String)

    Unique identifier for the certificate, prefixed with tcrt_.

  • archived_at (Time, nil)

    A timestamp in RFC 3339 format

  • created_at (Time)

    A timestamp in RFC 3339 format

  • expires_at (Time, nil)

    A timestamp in RFC 3339 format

  • fingerprint (String)

    Lowercase hex SHA-256 fingerprint of the certificate's DER encoding.

  • tunnel_id (String)

    ID of the tunnel the certificate is registered against.

  • type (Symbol, :tunnel_certificate) (defaults to: :tunnel_certificate)


# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 50

Instance Attribute Details

#archived_atTime?

A timestamp in RFC 3339 format

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


19
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 19

required :archived_at, Time, nil?: true

#created_atTime

A timestamp in RFC 3339 format

Parameters:

  • value (Time)

Returns:

  • (Time)


25
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 25

required :created_at, Time

#expires_atTime?

A timestamp in RFC 3339 format

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


31
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 31

required :expires_at, Time, nil?: true

#fingerprintString

Lowercase hex SHA-256 fingerprint of the certificate's DER encoding.

Parameters:

  • value (String)

Returns:

  • (String)


37
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 37

required :fingerprint, String

#idString

Unique identifier for the certificate, prefixed with tcrt_.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 13

required :id, String

#tunnel_idString

ID of the tunnel the certificate is registered against.

Parameters:

  • value (String)

Returns:

  • (String)


43
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 43

required :tunnel_id, String

#typeSymbol, :tunnel_certificate

Parameters:

  • value (:tunnel_certificate)

Returns:

  • (Symbol, :tunnel_certificate)


48
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 48

required :type, const: :tunnel_certificate

Instance Method Details

#to_hash{

Returns:

  • ({)


41
# File 'sig/anthropic/models/beta/tunnels/beta_tunnel_certificate.rbs', line 41

def to_hash: -> {