Class: Anthropic::Models::Beta::UserProfileCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/user_profile_create_params.rb,
sig/anthropic/models/beta/user_profile_create_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::UserProfiles#create

Defined Under Namespace

Modules: AccessType

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_type: nil, external_id: nil, external_user_details: nil, external_user_onboarded_at: nil, metadata: nil, name: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::UserProfileCreateParams for more details.

Parameters:

  • access_type (Symbol, Anthropic::Models::Beta::UserProfileCreateParams::AccessType) (defaults to: nil)

    How the platform uses the API on behalf of the entity this profile represents. `

  • external_id (String, nil) (defaults to: nil)

    Platform's own identifier for this user. Not enforced unique. Maximum 255 charac

  • external_user_details (Anthropic::Models::Beta::BetaUserProfileExternalUserDetailsParams) (defaults to: nil)

    Details about the entity this profile represents, as the platform states them. E

  • external_user_onboarded_at (Time) (defaults to: nil)

    A timestamp in RFC 3339 format

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Free-form key-value data to attach to this user profile. Maximum 16 keys, with k

  • name (String, nil) (defaults to: nil)

    Optional for all profiles. Real-world name of the entity this profile represents

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 67

Instance Attribute Details

#access_typeSymbol, ...

How the platform uses the API on behalf of the entity this profile represents. application: the platform sells a product that uses the API behind the scenes, and the profile represents an individual end-user of that product. passthrough: the platform resells raw inference, and the profile identifies the resold-to company.



19
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 19

optional :access_type, enum: -> { Anthropic::Beta::UserProfileCreateParams::AccessType }

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



65
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 65

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#external_idString?

Platform's own identifier for this user. Not enforced unique. Maximum 255 characters. Accepted under the user-profiles-2026-03-24 and user-profiles-2026-08-18 beta headers; under user-profiles-2026-09-04 send external_user_details.reference_id instead.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 28

optional :external_id, String, nil?: true

#external_user_detailsAnthropic::Models::Beta::BetaUserProfileExternalUserDetailsParams?

Details about the entity this profile represents, as the platform states them. Every field is optional. Accepted under the user-profiles-2026-09-04 beta header only.



36
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 36

optional :external_user_details, -> { Anthropic::Beta::BetaUserProfileExternalUserDetailsParams }

#external_user_onboarded_atTime?

A timestamp in RFC 3339 format

Parameters:

  • (Time)

Returns:

  • (Time, nil)


42
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 42

optional :external_user_onboarded_at, Time

#metadataHash{Symbol=>String}?

Free-form key-value data to attach to this user profile. Maximum 16 keys, with keys up to 64 characters and values up to 512 characters. Values must be non-empty strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


50
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 50

optional :metadata, Anthropic::Internal::Type::HashOf[String]

#nameString?

Optional for all profiles. Real-world name of the entity this profile represents (company or individual); for a company the platform resells Claude access to (access_type passthrough), that company's name where known. Maximum 255 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


59
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 59

optional :name, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


61
# File 'sig/anthropic/models/beta/user_profile_create_params.rbs', line 61

def to_hash: -> {