Module: Anthropic::Models::Beta::UserProfileCreateParams::AccessType

Extended by:
Internal::Type::Enum
Defined in:
lib/anthropic/models/beta/user_profile_create_params.rb,
sig/anthropic/models/beta/user_profile_create_params.rbs

Overview

How the platform uses the API on behalf of the entity this profile represents. application: the platform sells a product that uses the API behind the scenes, and the profile represents an individual end-user of that product. passthrough: the platform resells raw inference, and the profile identifies the resold-to company.

Constant Summary collapse

APPLICATION =

Returns:

  • (:application)
:application
PASSTHROUGH =

Returns:

  • (:passthrough)
:passthrough

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 98


Instance Method Details

#self?.values::Array[Anthropic::Models::Beta::UserProfileCreateParams::access_type]

Returns:

  • (::Array[Anthropic::Models::Beta::UserProfileCreateParams::access_type])


80
# File 'sig/anthropic/models/beta/user_profile_create_params.rbs', line 80

def self?.values: -> ::Array[Anthropic::Models::Beta::UserProfileCreateParams::access_type]