Module: Anthropic::Models::Beta::Vaults::BetaManagedAgentsCredential::Auth
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/vaults/beta_managed_agents_credential.rb,
sig/anthropic/models/beta/vaults/beta_managed_agents_credential.rbs
Overview
Authentication details for a credential.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthAuthResponse, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthAuthResponse, Anthropic::Models::Beta::Vaults::BetaManagedAgentsStaticBearerAuthResponse, Anthropic::Models::Beta::Vaults::BetaManagedAgentsEnvironmentVariableAuthResponse)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthAuthResponse, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_credential.rb', line 137 def self.new(type:, **args) case type.to_sym when :mcp_oauth Anthropic::Beta::Vaults::BetaManagedAgentsMCPOAuthAuthResponse.new(**args) when :static_bearer Anthropic::Beta::Vaults::BetaManagedAgentsStaticBearerAuthResponse.new(**args) when :environment_variable Anthropic::Beta::Vaults::BetaManagedAgentsEnvironmentVariableAuthResponse.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_credential.rb', line 109
|
.variants ⇒ Array(Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthAuthResponse, Anthropic::Models::Beta::Vaults::BetaManagedAgentsStaticBearerAuthResponse, Anthropic::Models::Beta::Vaults::BetaManagedAgentsEnvironmentVariableAuthResponse)
|
|
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_credential.rb', line 113
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsCredential::auth]
81 |
# File 'sig/anthropic/models/beta/vaults/beta_managed_agents_credential.rbs', line 81
def self?.variants: -> ::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsCredential::auth]
|