Class: Anthropic::Models::Beta::Vaults::BetaManagedAgentsLimitedCredentialNetworkingResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Vaults::BetaManagedAgentsLimitedCredentialNetworkingResponse
- Defined in:
- lib/anthropic/models/beta/vaults/beta_managed_agents_limited_credential_networking_response.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#allowed_hosts ⇒ Array<String>
Hostnames on which the secret will be substituted.
- #type ⇒ Symbol, Anthropic::Models::Beta::Vaults::BetaManagedAgentsLimitedCredentialNetworkingResponse::Type
Instance Method Summary collapse
-
#initialize(allowed_hosts:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsLimitedCredentialNetworkingResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allowed_hosts:, type:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Vaults::BetaManagedAgentsLimitedCredentialNetworkingResponse for more details.
The secret is substituted only on requests to the listed hosts.
|
|
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_limited_credential_networking_response.rb', line 22
|
Instance Attribute Details
#allowed_hosts ⇒ Array<String>
Hostnames on which the secret will be substituted. An entry matches the request host exactly; a ‘*.`-prefixed entry matches any subdomain of the named domain but not the domain itself.
14 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_limited_credential_networking_response.rb', line 14 required :allowed_hosts, Anthropic::Internal::Type::ArrayOf[String] |
#type ⇒ Symbol, Anthropic::Models::Beta::Vaults::BetaManagedAgentsLimitedCredentialNetworkingResponse::Type
19 20 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_limited_credential_networking_response.rb', line 19 required :type, enum: -> { Anthropic::Beta::Vaults::BetaManagedAgentsLimitedCredentialNetworkingResponse::Type } |