Class: Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams
- Defined in:
- lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb
Defined Under Namespace
Modules: TokenEndpointAuth
Instance Attribute Summary collapse
-
#client_id ⇒ String
OAuth client ID.
-
#refresh_token ⇒ String
OAuth refresh token.
-
#resource ⇒ String?
OAuth resource indicator.
-
#scope ⇒ String?
OAuth scope for the refresh request.
-
#token_endpoint ⇒ String
Token endpoint URL used to refresh the access token.
-
#token_endpoint_auth ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthNoneParam, ...
Token endpoint requires no client authentication.
Instance Method Summary collapse
-
#initialize(client_id:, refresh_token:, token_endpoint:, token_endpoint_auth:, resource: nil, scope: nil) ⇒ Object
constructor
OAuth refresh token parameters for creating a credential with refresh support.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(client_id:, refresh_token:, token_endpoint:, token_endpoint_auth:, resource: nil, scope: nil) ⇒ Object
OAuth refresh token parameters for creating a credential with refresh support.
|
|
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 45
|
Instance Attribute Details
#client_id ⇒ String
OAuth client ID.
12 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 12 required :client_id, String |
#refresh_token ⇒ String
OAuth refresh token.
18 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 18 required :refresh_token, String |
#resource ⇒ String?
OAuth resource indicator.
37 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 37 optional :resource, String, nil?: true |
#scope ⇒ String?
OAuth scope for the refresh request.
43 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 43 optional :scope, String, nil?: true |
#token_endpoint ⇒ String
Token endpoint URL used to refresh the access token.
24 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 24 required :token_endpoint, String |
#token_endpoint_auth ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthNoneParam, ...
Token endpoint requires no client authentication.
30 31 |
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 30 required :token_endpoint_auth, union: -> { Anthropic::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams::TokenEndpointAuth } |