Module: Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams::TokenEndpointAuth

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb,
sig/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rbs

Overview

Token endpoint requires no client authentication.

See Also:

  • Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams#token_endpoint_auth

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthNoneParam, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :client_secret OAuth client secret.

Returns:

Raises:

  • (ArgumentError)


91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rb', line 91

def self.new(type:, **args)
  case type.to_sym
  when :none
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthNoneParam.new(**args)
  when :client_secret_basic
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthBasicParam.new(**args)
  when :client_secret_post
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthPostParam.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams::token_endpoint_auth]

Returns:

  • (::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams::token_endpoint_auth])


54
# File 'sig/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_params.rbs', line 54

def self?.variants: -> ::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshParams::token_endpoint_auth]