Module: Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshResponse::TokenEndpointAuth

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_response.rb,
sig/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_response.rbs

Overview

Token endpoint requires no client authentication.

See Also:

  • Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshResponse#token_endpoint_auth

Defined Under Namespace

Modules: Type

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthNoneResponse, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.



94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_response.rb', line 94

def self.new(type:, **args)
  case type.to_sym
  when :none
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthNoneResponse.new(**args)
  when :client_secret_basic
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthBasicResponse.new(**args)
  when :client_secret_post
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthPostResponse.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_response.rb', line 78

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshResponse::token_endpoint_auth]

Returns:

  • (::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshResponse::token_endpoint_auth])


61
# File 'sig/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_response.rbs', line 61

def self?.variants: -> ::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshResponse::token_endpoint_auth]