Module: Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshUpdateParams::TokenEndpointAuth

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_update_params.rb,
sig/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_update_params.rbs

Overview

Updated HTTP Basic authentication parameters for the token endpoint.

See Also:

  • Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshUpdateParams#token_endpoint_auth

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthBasicUpdateParam, Anthropic::Models::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthPostUpdateParam

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String, nil] :client_secret Updated OAuth client secret.

Returns:

Raises:

  • (ArgumentError)


66
67
68
69
70
71
72
73
74
75
# File 'lib/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_update_params.rb', line 66

def self.new(type:, **args)
  case type.to_sym
  when :client_secret_basic
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthBasicUpdateParam.new(**args)
  when :client_secret_post
    Anthropic::Beta::Vaults::BetaManagedAgentsTokenEndpointAuthPostUpdateParam.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshUpdateParams::token_endpoint_auth]

Returns:

  • (::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshUpdateParams::token_endpoint_auth])


42
# File 'sig/anthropic/models/beta/vaults/beta_managed_agents_mcp_oauth_refresh_update_params.rbs', line 42

def self?.variants: -> ::Array[Anthropic::Models::Beta::Vaults::BetaManagedAgentsMCPOAuthRefreshUpdateParams::token_endpoint_auth]