Class: Anthropic::Models::BrowserStateChangeDownloadCompleted

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/browser_state_change_download_completed.rb,
sig/anthropic/models/browser_state_change_download_completed.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(download_id:, url:, path: nil, size_bytes: nil, type: :download_completed) ⇒ Object

A file download that finished during this call, reported with the same download_id as its download_started — or without a prior download_started, when the download finished during the call that started it (at most one state change per download_id per result).

Some parameter documentations has been truncated, see Anthropic::Models::BrowserStateChangeDownloadCompleted for more details.

Parameters:

  • download_id (String)

    The caller-assigned identifier for this download, stable across the state change

  • url (String)

    The final post-redirect URL the download was served from.

  • path (String, nil) (defaults to: nil)

    Where the executor saved the file, on the executor's filesystem. Only included w

  • size_bytes (Integer, nil) (defaults to: nil)

    The completed download's size.

  • type (Symbol, :download_completed) (defaults to: :download_completed)


# File 'lib/anthropic/models/browser_state_change_download_completed.rb', line 37

Instance Attribute Details

#download_idString

The caller-assigned identifier for this download, stable across the state changes reporting it.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/anthropic/models/browser_state_change_download_completed.rb', line 11

required :download_id, String

#pathString?

Where the executor saved the file, on the executor's filesystem. Only included when another tool in the same environment can read the file at that path.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


29
# File 'lib/anthropic/models/browser_state_change_download_completed.rb', line 29

optional :path, String, nil?: true

#size_bytesInteger?

The completed download's size.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


35
# File 'lib/anthropic/models/browser_state_change_download_completed.rb', line 35

optional :size_bytes, Integer, nil?: true

#typeSymbol, :download_completed

Parameters:

  • value (:download_completed)

Returns:

  • (Symbol, :download_completed)


16
# File 'lib/anthropic/models/browser_state_change_download_completed.rb', line 16

required :type, const: :download_completed

#urlString

The final post-redirect URL the download was served from.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/anthropic/models/browser_state_change_download_completed.rb', line 22

required :url, String

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/anthropic/models/browser_state_change_download_completed.rbs', line 31

def to_hash: -> {