Class: Anthropic::Models::BrowserStateChangeDownloadFailed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/browser_state_change_download_failed.rb,
sig/anthropic/models/browser_state_change_download_failed.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(download_id:, url:, error: nil, type: :download_failed) ⇒ Object

A file download that failed — or was cancelled — during this call.

Some parameter documentations has been truncated, see Anthropic::Models::BrowserStateChangeDownloadFailed for more details.

Parameters:

  • download_id (String)

    The caller-assigned identifier for this download, stable across the state change

  • url (String)

    The final post-redirect URL the download was served from.

  • error (String, nil) (defaults to: nil)

    The failure or cancellation detail, when known.

  • type (Symbol, :download_failed) (defaults to: :download_failed)


# File 'lib/anthropic/models/browser_state_change_download_failed.rb', line 30

Instance Attribute Details

#download_idString

The caller-assigned identifier for this download, stable across the state changes reporting it.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/anthropic/models/browser_state_change_download_failed.rb', line 11

required :download_id, String

#errorString?

The failure or cancellation detail, when known.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/anthropic/models/browser_state_change_download_failed.rb', line 28

optional :error, String, nil?: true

#typeSymbol, :download_failed

Parameters:

  • value (:download_failed)

Returns:

  • (Symbol, :download_failed)


16
# File 'lib/anthropic/models/browser_state_change_download_failed.rb', line 16

required :type, const: :download_failed

#urlString

The final post-redirect URL the download was served from.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/anthropic/models/browser_state_change_download_failed.rb', line 22

required :url, String

Instance Method Details

#to_hash{

Returns:

  • ({)


27
# File 'sig/anthropic/models/browser_state_change_download_failed.rbs', line 27

def to_hash: -> {