Class: Anthropic::Models::BrowserStateChangeDownloadStarted

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/browser_state_change_download_started.rb,
sig/anthropic/models/browser_state_change_download_started.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(download_id:, url:, type: :download_started) ⇒ Object

A file download that started during this call.

Some parameter documentations has been truncated, see Anthropic::Models::BrowserStateChangeDownloadStarted for more details.

Parameters:

  • download_id (String)

    The caller-assigned identifier for this download, stable across the state change

  • url (String)

    The final post-redirect URL the download was served from.

  • type (Symbol, :download_started) (defaults to: :download_started)


# File 'lib/anthropic/models/browser_state_change_download_started.rb', line 24

Instance Attribute Details

#download_idString

The caller-assigned identifier for this download, stable across the state changes reporting it.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/anthropic/models/browser_state_change_download_started.rb', line 11

required :download_id, String

#typeSymbol, :download_started

Parameters:

  • value (:download_started)

Returns:

  • (Symbol, :download_started)


16
# File 'lib/anthropic/models/browser_state_change_download_started.rb', line 16

required :type, const: :download_started

#urlString

The final post-redirect URL the download was served from.

Parameters:

  • value (String)

Returns:

  • (String)


22
# File 'lib/anthropic/models/browser_state_change_download_started.rb', line 22

required :url, String

Instance Method Details

#to_hash{

Returns:

  • ({)


19
# File 'sig/anthropic/models/browser_state_change_download_started.rbs', line 19

def to_hash: -> {