Class: Anthropic::Models::CitationContentBlockLocationParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::CitationContentBlockLocationParam
- Defined in:
- lib/anthropic/models/citation_content_block_location_param.rb
Instance Attribute Summary collapse
-
#cited_text ⇒ String
The full text of the cited block range, concatenated.
- #document_index ⇒ Integer
- #document_title ⇒ String?
-
#end_block_index ⇒ Integer
Exclusive 0-based end index of the cited block range in the source’s ‘content` array.
-
#start_block_index ⇒ Integer
0-based index of the first cited block in the source’s ‘content` array.
- #type ⇒ Symbol, :content_block_location
Instance Method Summary collapse
-
#initialize(cited_text:, document_index:, document_title:, end_block_index:, start_block_index:, type: :content_block_location) ⇒ Object
constructor
Some parameter documentations has been truncated, see CitationContentBlockLocationParam for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cited_text:, document_index:, document_title:, end_block_index:, start_block_index:, type: :content_block_location) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::CitationContentBlockLocationParam for more details.
|
|
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 48
|
Instance Attribute Details
#cited_text ⇒ String
The full text of the cited block range, concatenated.
Always equals the contents of ‘content` joined together. The text block is the minimal citable unit; this field is never a substring of a single block. Not counted toward output tokens, and not counted toward input tokens when sent back in subsequent turns.
15 |
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 15 required :cited_text, String |
#document_index ⇒ Integer
20 |
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 20 required :document_index, Integer |
#document_title ⇒ String?
25 |
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 25 required :document_title, String, nil?: true |
#end_block_index ⇒ Integer
Exclusive 0-based end index of the cited block range in the source’s ‘content` array.
Always greater than ‘start_block_index`; a single-block citation has `end_block_index = start_block_index + 1`.
35 |
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 35 required :end_block_index, Integer |
#start_block_index ⇒ Integer
0-based index of the first cited block in the source’s ‘content` array.
41 |
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 41 required :start_block_index, Integer |
#type ⇒ Symbol, :content_block_location
46 |
# File 'lib/anthropic/models/citation_content_block_location_param.rb', line 46 required :type, const: :content_block_location |