Module: Anthropic::Models::CitationsDelta::Citation
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/citations_delta.rb,
sig/anthropic/models/citations_delta.rbs
Overview
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::CitationCharLocation, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::CitationCharLocation, Anthropic::Models::CitationPageLocation, Anthropic::Models::CitationContentBlockLocation, Anthropic::Models::CitationsWebSearchResultLocation, Anthropic::Models::CitationsSearchResultLocation)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::CitationCharLocation, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::CitationsDelta::Citation for more details.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/anthropic/models/citations_delta.rb', line 81 def self.new(type:, **args) case type.to_sym when :char_location Anthropic::CitationCharLocation.new(**args) when :page_location Anthropic::CitationPageLocation.new(**args) when :content_block_location Anthropic::CitationContentBlockLocation.new(**args) when :web_search_result_location Anthropic::CitationsWebSearchResultLocation.new(**args) when :search_result_location Anthropic::CitationsSearchResultLocation.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::CitationCharLocation, Anthropic::Models::CitationPageLocation, Anthropic::Models::CitationContentBlockLocation, Anthropic::Models::CitationsWebSearchResultLocation, Anthropic::Models::CitationsSearchResultLocation)
|
|
# File 'lib/anthropic/models/citations_delta.rb', line 36
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::CitationsDelta::citation]
34 |
# File 'sig/anthropic/models/citations_delta.rbs', line 34
def self?.variants: -> ::Array[Anthropic::Models::CitationsDelta::citation]
|