Class: Anthropic::Models::Container
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Container
- Defined in:
- lib/anthropic/models/container.rb,
sig/anthropic/models/container.rbs
Instance Attribute Summary collapse
-
#expires_at ⇒ Time
The time at which the container will expire.
-
#id ⇒ String
Identifier for the container used in this request.
-
#skills ⇒ Array<Anthropic::Models::ContainerSkill>?
Skills loaded in the container.
Instance Method Summary collapse
-
#initialize(id:, expires_at:, skills:) ⇒ Object
constructor
Information about the container used in the request (for the code execution tool).
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, expires_at:, skills:) ⇒ Object
Information about the container used in the request (for the code execution tool)
|
|
# File 'lib/anthropic/models/container.rb', line 24
|
Instance Attribute Details
#expires_at ⇒ Time
The time at which the container will expire.
16 |
# File 'lib/anthropic/models/container.rb', line 16 required :expires_at, Time |
#id ⇒ String
Identifier for the container used in this request
10 |
# File 'lib/anthropic/models/container.rb', line 10 required :id, String |
#skills ⇒ Array<Anthropic::Models::ContainerSkill>?
Skills loaded in the container
22 |
# File 'lib/anthropic/models/container.rb', line 22 required :skills, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::ContainerSkill] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
23 |
# File 'sig/anthropic/models/container.rbs', line 23
def to_hash: -> {
|