Class: Anthropic::Models::Diagnostics
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Diagnostics
- Defined in:
- lib/anthropic/models/diagnostics.rb,
sig/anthropic/models/diagnostics.rbs
Instance Attribute Summary collapse
-
#cache_miss_reason ⇒ Anthropic::Models::CacheMissModelChanged, ...
Explains why the prompt cache could not fully reuse the prefix from the request identified by
diagnostics.previous_message_id.
Instance Method Summary collapse
-
#initialize(cache_miss_reason:) ⇒ Object
constructor
Request-level diagnostics: why the prompt cache could not fully reuse the prefix of the request named by
diagnostics.previous_message_id. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cache_miss_reason:) ⇒ Object
Request-level diagnostics: why the prompt cache could not fully reuse the prefix
of the request named by diagnostics.previous_message_id.
Some parameter documentations has been truncated, see Anthropic::Models::Diagnostics for more details.
|
|
# File 'lib/anthropic/models/diagnostics.rb', line 15
|
Instance Attribute Details
#cache_miss_reason ⇒ Anthropic::Models::CacheMissModelChanged, ...
Explains why the prompt cache could not fully reuse the prefix from the request
identified by diagnostics.previous_message_id. null means diagnosis is still
pending — the response was serialized before the background comparison
completed.
13 |
# File 'lib/anthropic/models/diagnostics.rb', line 13 required :cache_miss_reason, union: -> { Anthropic::CacheMissReason }, nil?: true |
Instance Method Details
#to_hash ⇒ {
13 |
# File 'sig/anthropic/models/diagnostics.rbs', line 13
def to_hash: -> {
|