Module: Anthropic::Models::DocumentBlock::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/document_block.rb,
sig/anthropic/models/document_block.rbs
Overview
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
73 74 75 76 77 78 79 80 81 82 |
# File 'lib/anthropic/models/document_block.rb', line 73 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Base64PDFSource.new(**args) when :text Anthropic::PlainTextSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/document_block.rb', line 53
|
.variants ⇒ Array(Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource)
|
|
# File 'lib/anthropic/models/document_block.rb', line 57
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::DocumentBlock::source]
50 |
# File 'sig/anthropic/models/document_block.rbs', line 50
def self?.variants: -> ::Array[Anthropic::Models::DocumentBlock::source]
|