Class: Anthropic::Models::FileListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/file_list_params.rb,
sig/anthropic/models/file_list_params.rbs

Overview

See Also:

  • Anthropic::Resources::Files#list

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ids: nil, limit: nil, page: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::FileListParams for more details.

Parameters:

  • ids (Array<String>, nil) (defaults to: nil)

    Restrict the result set to Files whose id is in this list. At most 100 entries

  • limit (Integer) (defaults to: nil)

    Number of items to return per page.

  • page (String, nil) (defaults to: nil)

    Opaque page cursor returned in a prior list response's next_page. Prefixed `pa

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/file_list_params.rb', line 35

Instance Attribute Details

#idsArray<String>?

Restrict the result set to Files whose id is in this list. At most 100 entries (after de-duplication). Mutually exclusive with page and limit. When supplied, the response is always a single page (next_page is null). IDs that do not resolve to a visible File — including deleted Files — are silently omitted.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


18
# File 'lib/anthropic/models/file_list_params.rb', line 18

optional :ids, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#limitInteger?

Number of items to return per page.

Defaults to 20. Ranges from 1 to 1000.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/anthropic/models/file_list_params.rb', line 26

optional :limit, Integer

#pageString?

Opaque page cursor returned in a prior list response's next_page. Prefixed page_.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


33
# File 'lib/anthropic/models/file_list_params.rb', line 33

optional :page, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


26
# File 'sig/anthropic/models/file_list_params.rbs', line 26

def to_hash: -> {