Module: Anthropic::Models::ImageBlockParam::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/image_block_param.rb,
sig/anthropic/models/image_block_param.rbs
Overview
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Base64ImageSource, Anthropic::Models::URLImageSource
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Base64ImageSource, Anthropic::Models::URLImageSource)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Base64ImageSource, Anthropic::Models::URLImageSource
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/anthropic/models/image_block_param.rb', line 57 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Base64ImageSource.new(**args) when :url Anthropic::URLImageSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Base64ImageSource, Anthropic::Models::URLImageSource)
|
|
# File 'lib/anthropic/models/image_block_param.rb', line 39
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::ImageBlockParam::source]
34 |
# File 'sig/anthropic/models/image_block_param.rbs', line 34
def self?.variants: -> ::Array[Anthropic::Models::ImageBlockParam::source]
|