Module: Anthropic::Models::Messages::BatchCreateParams::Request::Params::System

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/messages/batch_create_params.rb,
sig/anthropic/models/messages/batch_create_params.rbs

Overview

System prompt.

A system prompt is a way of providing context and instructions to Claude, such as specifying a particular goal or role. See our guide to system prompts.

See Also:

  • Anthropic::Models::Messages::BatchCreateParams::Request::Params#system_

Constant Summary collapse

TextBlockParamArray =
Anthropic::Internal::Type::ArrayOf[-> { Anthropic::TextBlockParam }]

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Array<Anthropic::Models::TextBlockParam>)

Returns:



# File 'lib/anthropic/models/messages/batch_create_params.rb', line 472

Instance Method Details

#self?.variants::Array[Anthropic::Models::Messages::BatchCreateParams::Request::Params::system_]

Returns:

  • (::Array[Anthropic::Models::Messages::BatchCreateParams::Request::Params::system_])


207
# File 'sig/anthropic/models/messages/batch_create_params.rbs', line 207

def self?.variants: -> ::Array[Anthropic::Models::Messages::BatchCreateParams::Request::Params::system_]