Class: Anthropic::Models::Messages::MessageBatchRequestCounts
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Messages::MessageBatchRequestCounts
- Defined in:
- lib/anthropic/models/messages/message_batch_request_counts.rb,
sig/anthropic/models/messages/message_batch_request_counts.rbs
Instance Attribute Summary collapse
-
#canceled ⇒ Integer
Number of requests in the Message Batch that have been canceled.
-
#errored ⇒ Integer
Number of requests in the Message Batch that encountered an error.
-
#expired ⇒ Integer
Number of requests in the Message Batch that have expired.
-
#processing ⇒ Integer
Number of requests in the Message Batch that are processing.
-
#succeeded ⇒ Integer
Number of requests in the Message Batch that have completed successfully.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
26 |
# File 'sig/anthropic/models/messages/message_batch_request_counts.rbs', line 26
def initialize: (
|
Instance Attribute Details
#canceled ⇒ Integer
Number of requests in the Message Batch that have been canceled.
This is zero until processing of the entire Message Batch has ended.
13 |
# File 'lib/anthropic/models/messages/message_batch_request_counts.rb', line 13 required :canceled, Integer |
#errored ⇒ Integer
Number of requests in the Message Batch that encountered an error.
This is zero until processing of the entire Message Batch has ended.
21 |
# File 'lib/anthropic/models/messages/message_batch_request_counts.rb', line 21 required :errored, Integer |
#expired ⇒ Integer
Number of requests in the Message Batch that have expired.
This is zero until processing of the entire Message Batch has ended.
29 |
# File 'lib/anthropic/models/messages/message_batch_request_counts.rb', line 29 required :expired, Integer |
#processing ⇒ Integer
Number of requests in the Message Batch that are processing.
35 |
# File 'lib/anthropic/models/messages/message_batch_request_counts.rb', line 35 required :processing, Integer |
#succeeded ⇒ Integer
Number of requests in the Message Batch that have completed successfully.
This is zero until processing of the entire Message Batch has ended.
43 |
# File 'lib/anthropic/models/messages/message_batch_request_counts.rb', line 43 required :succeeded, Integer |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/anthropic/models/messages/message_batch_request_counts.rbs', line 34
def to_hash: -> {
|