Class: Anthropic::Models::Metadata

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/metadata.rb,
sig/anthropic/models/metadata.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(user_id: nil) ⇒ Metadata

Some parameter documentations has been truncated, see Anthropic::Models::Metadata for more details.

Parameters:

  • user_id (String, nil) (defaults to: nil)

    An external identifier for the user who is associated with the request.

  • user_id: (String, nil) (defaults to: nil)


# File 'lib/anthropic/models/metadata.rb', line 16

Instance Attribute Details

#user_idString?

An external identifier for the user who is associated with the request.

This should be a uuid, hash value, or other opaque identifier. Anthropic may use this id to help detect abuse. Do not include any identifying information such as name, email address, or phone number.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


14
# File 'lib/anthropic/models/metadata.rb', line 14

optional :user_id, String, nil?: true

Instance Method Details

#to_hash{ user_id: String? }

Returns:

  • ({ user_id: String? })


10
# File 'sig/anthropic/models/metadata.rbs', line 10

def to_hash: -> { user_id: String? }