Class: Anthropic::Models::MidConversationSystemBlockParam

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/mid_conversation_system_block_param.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, cache_control: nil, type: :mid_conv_system) ⇒ Object

System instructions that appear mid-conversation.

Use this block to provide or update system-level instructions at a specific point in the conversation, rather than only via the top-level ‘system` parameter.

Parameters:



# File 'lib/anthropic/models/mid_conversation_system_block_param.rb', line 23

Instance Attribute Details

#cache_controlAnthropic::Models::CacheControlEphemeral?

Create a cache control breakpoint at this content block.



21
# File 'lib/anthropic/models/mid_conversation_system_block_param.rb', line 21

optional :cache_control, -> { Anthropic::CacheControlEphemeral }, nil?: true

#contentArray<Anthropic::Models::TextBlockParam>

System instruction text blocks.



10
# File 'lib/anthropic/models/mid_conversation_system_block_param.rb', line 10

required :content, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::TextBlockParam] }

#typeSymbol, :mid_conv_system

Returns:

  • (Symbol, :mid_conv_system)


15
# File 'lib/anthropic/models/mid_conversation_system_block_param.rb', line 15

required :type, const: :mid_conv_system