Class: Anthropic::Models::RedactedThinkingBlock

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/redacted_thinking_block.rb,
sig/anthropic/models/redacted_thinking_block.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data:, type: :redacted_thinking) ⇒ RedactedThinkingBlock

Some parameter documentations has been truncated, see Anthropic::Models::RedactedThinkingBlock for more details.

Parameters:

  • data (String)

    The contents of this redacted thinking block, returned when portions of the mode

  • type (Symbol, :redacted_thinking) (defaults to: :redacted_thinking)
  • data: (String)
  • type: (:redacted_thinking) (defaults to: :redacted_thinking)


# File 'lib/anthropic/models/redacted_thinking_block.rb', line 26

Instance Attribute Details

#dataString

The contents of this redacted thinking block, returned when portions of the model's thinking were safety-redacted. This field is opaque and encrypted, with no readable content.

Pass redacted_thinking blocks back to the API unchanged when continuing a multi-turn conversation.

See extended thinking for details.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/anthropic/models/redacted_thinking_block.rb', line 19

required :data, String

#typeSymbol, :redacted_thinking

Parameters:

  • value (:redacted_thinking)

Returns:

  • (Symbol, :redacted_thinking)


24
# File 'lib/anthropic/models/redacted_thinking_block.rb', line 24

required :type, const: :redacted_thinking

Instance Method Details

#to_hash{ data: String, type: :redacted_thinking }

Returns:

  • ({ data: String, type: :redacted_thinking })


12
# File 'sig/anthropic/models/redacted_thinking_block.rbs', line 12

def to_hash: -> { data: String, type: :redacted_thinking }