Class: Anthropic::Models::RedactedThinkingBlockParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::RedactedThinkingBlockParam
- Defined in:
- lib/anthropic/models/redacted_thinking_block_param.rb,
sig/anthropic/models/redacted_thinking_block_param.rbs
Instance Attribute Summary collapse
-
#data ⇒ String
The
datavalue of this redacted thinking block, exactly as returned by the API in a previous response. - #type ⇒ Symbol, :redacted_thinking
Instance Method Summary collapse
-
#initialize(data:, type: :redacted_thinking) ⇒ RedactedThinkingBlockParam
constructor
Some parameter documentations has been truncated, see RedactedThinkingBlockParam for more details.
- #to_hash ⇒ { data: String, type: :redacted_thinking }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:, type: :redacted_thinking) ⇒ RedactedThinkingBlockParam
Some parameter documentations has been truncated, see Anthropic::Models::RedactedThinkingBlockParam for more details.
|
|
# File 'lib/anthropic/models/redacted_thinking_block_param.rb', line 18
|
Instance Attribute Details
#data ⇒ String
The data value of this redacted thinking block, exactly as returned by the API
in a previous response. Opaque and encrypted; pass it back unchanged.
11 |
# File 'lib/anthropic/models/redacted_thinking_block_param.rb', line 11 required :data, String |
#type ⇒ Symbol, :redacted_thinking
16 |
# File 'lib/anthropic/models/redacted_thinking_block_param.rb', line 16 required :type, const: :redacted_thinking |
Instance Method Details
#to_hash ⇒ { data: String, type: :redacted_thinking }
13 |
# File 'sig/anthropic/models/redacted_thinking_block_param.rbs', line 13
def to_hash: -> { data: String, type: :redacted_thinking }
|