Class: Anthropic::Models::SignatureDelta

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/signature_delta.rb,
sig/anthropic/models/signature_delta.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(signature:, type: :signature_delta) ⇒ SignatureDelta

Some parameter documentations has been truncated, see Anthropic::Models::SignatureDelta for more details.

Parameters:

  • signature (String)

    The signature for this thinking block: an opaque value used to verify that the

  • type (Symbol, :signature_delta) (defaults to: :signature_delta)
  • signature: (String)
  • type: (:signature_delta) (defaults to: :signature_delta)


# File 'lib/anthropic/models/signature_delta.rb', line 19

Instance Attribute Details

#signatureString

The signature for this thinking block: an opaque value used to verify that the block was generated by Claude when it is passed back to the API. Delivered in a signature_delta event just before the block's content_block_stop event.

Parameters:

  • value (String)

Returns:

  • (String)


12
# File 'lib/anthropic/models/signature_delta.rb', line 12

required :signature, String

#typeSymbol, :signature_delta

Parameters:

  • value (:signature_delta)

Returns:

  • (Symbol, :signature_delta)


17
# File 'lib/anthropic/models/signature_delta.rb', line 17

required :type, const: :signature_delta

Instance Method Details

#to_hash{ signature: String, type: :signature_delta }

Returns:

  • ({ signature: String, type: :signature_delta })


12
# File 'sig/anthropic/models/signature_delta.rbs', line 12

def to_hash: -> { signature: String, type: :signature_delta }