Class: Anthropic::Models::SkillListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::SkillListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/skill_list_params.rb,
sig/anthropic/models/skill_list_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#limit ⇒ Integer?
Number of results to return per page.
-
#page ⇒ String?
Pagination token for fetching a specific page of results.
-
#source ⇒ String?
Filter skills by source.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(limit: nil, page: nil, source: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SkillListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(limit: nil, page: nil, source: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::SkillListParams for more details.
|
|
# File 'lib/anthropic/models/skill_list_params.rb', line 38
|
Instance Attribute Details
#limit ⇒ Integer?
Number of results to return per page.
Ranges from 1 to 1000. Defaults to 20.
16 |
# File 'lib/anthropic/models/skill_list_params.rb', line 16 optional :limit, Integer |
#page ⇒ String?
Pagination token for fetching a specific page of results.
Pass the value from a previous response's next_page field to get the next page
of results.
25 |
# File 'lib/anthropic/models/skill_list_params.rb', line 25 optional :page, String, nil?: true |
#source ⇒ String?
Filter skills by source.
If provided, only skills from the specified source will be returned:
"custom": only return user-created skills"anthropic": only return Anthropic-created skills
36 |
# File 'lib/anthropic/models/skill_list_params.rb', line 36 optional :source, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/anthropic/models/skill_list_params.rbs', line 26
def to_hash: -> {
|