Module: Anthropic::Models::TextCitation
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/text_citation.rb,
sig/anthropic/models/text_citation.rbs
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::CitationCharLocation, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::CitationCharLocation, Anthropic::Models::CitationPageLocation, Anthropic::Models::CitationContentBlockLocation, Anthropic::Models::CitationsWebSearchResultLocation, Anthropic::Models::CitationsSearchResultLocation)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::CitationCharLocation, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::TextCitation for more details.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/anthropic/models/text_citation.rb', line 65 def self.new(type:, **args) case type.to_sym when :char_location Anthropic::CitationCharLocation.new(**args) when :page_location Anthropic::CitationPageLocation.new(**args) when :content_block_location Anthropic::CitationContentBlockLocation.new(**args) when :web_search_result_location Anthropic::CitationsWebSearchResultLocation.new(**args) when :search_result_location Anthropic::CitationsSearchResultLocation.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::CitationCharLocation, Anthropic::Models::CitationPageLocation, Anthropic::Models::CitationContentBlockLocation, Anthropic::Models::CitationsWebSearchResultLocation, Anthropic::Models::CitationsSearchResultLocation)
|
|
# File 'lib/anthropic/models/text_citation.rb', line 20
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::text_citation]
13 |
# File 'sig/anthropic/models/text_citation.rbs', line 13
def self?.variants: -> ::Array[Anthropic::Models::text_citation]
|