Module: Anthropic::Models::TextCitationParam
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/text_citation_param.rb,
sig/anthropic/models/text_citation_param.rbs
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::CitationCharLocationParam, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::CitationCharLocationParam, Anthropic::Models::CitationPageLocationParam, Anthropic::Models::CitationContentBlockLocationParam, Anthropic::Models::CitationWebSearchResultLocationParam, Anthropic::Models::CitationSearchResultLocationParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::CitationCharLocationParam, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::TextCitationParam for more details.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/anthropic/models/text_citation_param.rb', line 63 def self.new(type:, **args) case type.to_sym when :char_location Anthropic::CitationCharLocationParam.new(**args) when :page_location Anthropic::CitationPageLocationParam.new(**args) when :content_block_location Anthropic::CitationContentBlockLocationParam.new(**args) when :web_search_result_location Anthropic::CitationWebSearchResultLocationParam.new(**args) when :search_result_location Anthropic::CitationSearchResultLocationParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::CitationCharLocationParam, Anthropic::Models::CitationPageLocationParam, Anthropic::Models::CitationContentBlockLocationParam, Anthropic::Models::CitationWebSearchResultLocationParam, Anthropic::Models::CitationSearchResultLocationParam)
|
|
# File 'lib/anthropic/models/text_citation_param.rb', line 20
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::text_citation_param]
13 |
# File 'sig/anthropic/models/text_citation_param.rbs', line 13
def self?.variants: -> ::Array[Anthropic::Models::text_citation_param]
|