Class: Anthropic::Models::ThinkingBlock

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/thinking_block.rb,
sig/anthropic/models/thinking_block.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(signature:, thinking:, type: :thinking) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::ThinkingBlock for more details.

Parameters:

  • signature (String)

    A value used to verify that this thinking block was generated by Claude when it

  • thinking (String)

    The text of Claude's thinking process for this block.

  • type (Symbol, :thinking) (defaults to: :thinking)


# File 'lib/anthropic/models/thinking_block.rb', line 32

Instance Attribute Details

#signatureString

A value used to verify that this thinking block was generated by Claude when it is passed back to the API.

This is an opaque field and should not be interpreted or parsed. When passing thinking blocks back to the API (required when using tools with extended thinking), pass them back exactly as received, with this field intact.

See extended thinking for details.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/anthropic/models/thinking_block.rb', line 19

required :signature, String

#thinkingString

The text of Claude's thinking process for this block.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/anthropic/models/thinking_block.rb', line 25

required :thinking, String

#typeSymbol, :thinking

Parameters:

  • value (:thinking)

Returns:

  • (Symbol, :thinking)


30
# File 'lib/anthropic/models/thinking_block.rb', line 30

required :type, const: :thinking

Instance Method Details

#to_hash{ signature: String, thinking: String, type: :thinking }

Returns:

  • ({ signature: String, thinking: String, type: :thinking })


19
# File 'sig/anthropic/models/thinking_block.rbs', line 19

def to_hash: -> { signature: String, thinking: String, type: :thinking }