Module: Anthropic::Models::ToolResultBlockParam::Content::Content
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/tool_result_block_param.rb,
sig/anthropic/models/tool_result_block_param.rbs
Overview
Tool reference block that can be included in tool_result content.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam, Anthropic::Models::SearchResultBlockParam, Anthropic::Models::DocumentBlockParam, Anthropic::Models::ToolReferenceBlockParam, Anthropic::Models::BrowserStateBlockParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::ToolResultBlockParam::Content::Content for more details.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/anthropic/models/tool_result_block_param.rb', line 122 def self.new(type:, **args) case type.to_sym when :text Anthropic::TextBlockParam.new(**args) when :image Anthropic::ImageBlockParam.new(**args) when :search_result Anthropic::SearchResultBlockParam.new(**args) when :document Anthropic::DocumentBlockParam.new(**args) when :tool_reference Anthropic::ToolReferenceBlockParam.new(**args) when :browser_state Anthropic::BrowserStateBlockParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam, Anthropic::Models::SearchResultBlockParam, Anthropic::Models::DocumentBlockParam, Anthropic::Models::ToolReferenceBlockParam, Anthropic::Models::BrowserStateBlockParam)
|
|
# File 'lib/anthropic/models/tool_result_block_param.rb', line 85
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::ToolResultBlockParam::Content::content]
68 |
# File 'sig/anthropic/models/tool_result_block_param.rbs', line 68
def self?.variants: -> ::Array[Anthropic::Models::ToolResultBlockParam::Content::content]
|