Module: Anthropic::Models::ToolUseBlock::Caller

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/tool_use_block.rb,
sig/anthropic/models/tool_use_block.rbs

Overview

Tool invocation directly from the model.

See Also:

  • Anthropic::Models::ToolUseBlock#caller_

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::DirectCaller, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :tool_id

Returns:

Raises:

  • (ArgumentError)


86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/anthropic/models/tool_use_block.rb', line 86

def self.new(type:, **args)
  case type.to_sym
  when :direct
    Anthropic::DirectCaller.new(**args)
  when :code_execution_20250825
    Anthropic::ServerToolCaller.new(**args)
  when :code_execution_20260120
    Anthropic::ServerToolCaller20260120.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::ToolUseBlock::caller_]

Returns:

  • (::Array[Anthropic::Models::ToolUseBlock::caller_])


47
# File 'sig/anthropic/models/tool_use_block.rbs', line 47

def self?.variants: -> ::Array[Anthropic::Models::ToolUseBlock::caller_]