Class: Anthropic::Models::WebFetchTool20260318

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/web_fetch_tool_20260318.rb,
sig/anthropic/models/web_fetch_tool_20260318.rbs

Defined Under Namespace

Modules: AllowedCaller, ResponseInclusion

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(allowed_callers: nil, allowed_domains: nil, blocked_domains: nil, cache_control: nil, citations: nil, defer_loading: nil, max_content_tokens: nil, max_uses: nil, response_inclusion: nil, strict: nil, use_cache: nil, name: :web_fetch, type: :web_fetch_20260318) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::WebFetchTool20260318 for more details.

Parameters:

  • allowed_callers (Array<Symbol, Anthropic::Models::WebFetchTool20260318::AllowedCaller>) (defaults to: nil)
  • allowed_domains (Array<String>, nil) (defaults to: nil)

    List of domains to allow fetching from

  • blocked_domains (Array<String>, nil) (defaults to: nil)

    List of domains to block fetching from

  • cache_control (Anthropic::Models::CacheControlEphemeral, nil) (defaults to: nil)

    Create a cache control breakpoint at this content block.

  • citations (Anthropic::Models::CitationsConfigParam, nil) (defaults to: nil)

    Citations configuration for fetched documents. Citations are disabled by default

  • defer_loading (Boolean) (defaults to: nil)

    If true, tool will not be included in initial system prompt. Only loaded when re

  • max_content_tokens (Integer, nil) (defaults to: nil)

    Maximum number of tokens used by including web page text content in the context.

  • max_uses (Integer, nil) (defaults to: nil)

    Maximum number of times the tool can be used in the API request.

  • response_inclusion (Symbol, Anthropic::Models::WebFetchTool20260318::ResponseInclusion) (defaults to: nil)

    How this tool's result blocks appear in the API response when the result was con

  • strict (Boolean) (defaults to: nil)

    When true, guarantees schema validation on tool names and inputs

  • use_cache (Boolean) (defaults to: nil)

    Whether to use cached content. Set to false to bypass the cache and fetch fresh

  • name (Symbol, :web_fetch) (defaults to: :web_fetch)

    Name of the tool.

  • type (Symbol, :web_fetch_20260318) (defaults to: :web_fetch_20260318)


# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 95

Instance Attribute Details

#allowed_callersArray<Symbol, Anthropic::Models::WebFetchTool20260318::AllowedCaller>?



22
23
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 22

optional :allowed_callers,
-> { Anthropic::Internal::Type::ArrayOf[enum: Anthropic::WebFetchTool20260318::AllowedCaller] }

#allowed_domainsArray<String>?

List of domains to allow fetching from

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


29
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 29

optional :allowed_domains, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#blocked_domainsArray<String>?

List of domains to block fetching from

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


35
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 35

optional :blocked_domains, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#cache_controlAnthropic::Models::CacheControlEphemeral?

Create a cache control breakpoint at this content block.



41
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 41

optional :cache_control, -> { Anthropic::CacheControlEphemeral }, nil?: true

#citationsAnthropic::Models::CitationsConfigParam?

Citations configuration for fetched documents. Citations are disabled by default.



48
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 48

optional :citations, -> { Anthropic::CitationsConfigParam }, nil?: true

#defer_loadingBoolean?

If true, tool will not be included in initial system prompt. Only loaded when returned via tool_reference from tool search.

Parameters:

Returns:



55
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 55

optional :defer_loading, Anthropic::Internal::Type::Boolean

#max_content_tokensInteger?

Maximum number of tokens used by including web page text content in the context. The limit is approximate and does not apply to binary content such as PDFs.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


62
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 62

optional :max_content_tokens, Integer, nil?: true

#max_usesInteger?

Maximum number of times the tool can be used in the API request.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


68
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 68

optional :max_uses, Integer, nil?: true

#nameSymbol, :web_fetch

Name of the tool.

This is how the tool will be called by the model and in tool_use blocks.

Parameters:

  • value (:web_fetch)

Returns:

  • (Symbol, :web_fetch)


12
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 12

required :name, const: :web_fetch

#response_inclusionSymbol, ...

How this tool's result blocks appear in the API response when the result was consumed by a completed code_execution call in the same turn. 'full' returns the complete content (default). 'excluded' drops the nested server_tool_use and result block pair entirely. Results from direct calls, or from code_execution calls that paused before completing, are always returned in full so they can be sent back on the next turn.



79
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 79

optional :response_inclusion, enum: -> { Anthropic::WebFetchTool20260318::ResponseInclusion }

#strictBoolean?

When true, guarantees schema validation on tool names and inputs

Parameters:

Returns:



85
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 85

optional :strict, Anthropic::Internal::Type::Boolean

#typeSymbol, :web_fetch_20260318

Parameters:

  • value (:web_fetch_20260318)

Returns:

  • (Symbol, :web_fetch_20260318)


17
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 17

required :type, const: :web_fetch_20260318

#use_cacheBoolean?

Whether to use cached content. Set to false to bypass the cache and fetch fresh content. Only set to false when the user explicitly requests fresh content or when fetching rapidly-changing sources.

Parameters:

Returns:



93
# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 93

optional :use_cache, Anthropic::Internal::Type::Boolean

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/web_fetch_tool_20260318.rb', line 140

Instance Method Details

#to_hash{

Returns:

  • ({)


77
# File 'sig/anthropic/models/web_fetch_tool_20260318.rbs', line 77

def to_hash: -> {