Class: Anthropic::Models::WebFetchURLSources

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/web_fetch_url_sources.rb,
sig/anthropic/models/web_fetch_url_sources.rbs

Defined Under Namespace

Modules: ClientToolResults, ServerToolResults, UserInput

Constant Summary collapse

Anthropic =

Returns:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(client_tool_results: nil, server_tool_results: nil, user_input: nil) ⇒ Object

Which sources contribute to the set of URLs web fetch may fetch.

Each key is a tagged variant: user_input is all or none; the two tool filters are all, none, only (only the named tools' results) or except (every result but the named tools'). A named tool must be declared in this request's tools[].

Some parameter documentations has been truncated, see Anthropic::Models::WebFetchURLSources for more details.

Parameters:

  • (defaults to: nil)

    Which client tools' results contribute fetchable URLs: "all", "none", or an only

  • (defaults to: nil)

    Which server tools' results contribute fetchable URLs: "all", "none", or an only

  • (defaults to: nil)

    Whether URLs in user messages are fetchable: "all" or "none".



# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 27

Instance Attribute Details

#client_tool_resultsAnthropic::Models::WebFetchURLSourceAll, ...

Which client tools' results contribute fetchable URLs: "all", "none", or an only or except list of client tool names from tools.

Returns:



11
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 11

optional :client_tool_results, union: -> { Anthropic::WebFetchURLSources::ClientToolResults }

#server_tool_resultsAnthropic::Models::WebFetchURLSourceAll, ...

Which server tools' results contribute fetchable URLs: "all", "none", or an only or except list of server tool names from tools; only web_search and web_fetch results ever contribute.

Returns:



19
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 19

optional :server_tool_results, union: -> { Anthropic::WebFetchURLSources::ServerToolResults }

#user_inputAnthropic::Models::WebFetchURLSourceAll, ...

Whether URLs in user messages are fetchable: "all" or "none".

Returns:



25
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 25

optional :user_input, union: -> { Anthropic::WebFetchURLSources::UserInput }

Instance Method Details

#to_hash{

Returns:



35
# File 'sig/anthropic/models/web_fetch_url_sources.rbs', line 35

def to_hash: -> {