Module: Anthropic::Models::WebFetchURLSources::ClientToolResults
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/web_fetch_url_sources.rb,
sig/anthropic/models/web_fetch_url_sources.rbs
Overview
Which client tools' results contribute fetchable URLs: "all", "none", or an only or except list of client tool names from tools.
Defined Under Namespace
Modules: Type
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::WebFetchURLSourceAll, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .values ⇒ Array<Symbol>
- .variants ⇒ Array(Anthropic::Models::WebFetchURLSourceAll, Anthropic::Models::WebFetchURLSourceNone, Anthropic::Models::WebFetchURLSourceOnly, Anthropic::Models::WebFetchURLSourceExcept)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::WebFetchURLSourceAll, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 95 def self.new(type:, **args) case type.to_sym when :all Anthropic::WebFetchURLSourceAll.new(**args) when :none Anthropic::WebFetchURLSourceNone.new(**args) when :only Anthropic::WebFetchURLSourceOnly.new(**args) when :except Anthropic::WebFetchURLSourceExcept.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 77
|
.variants ⇒ Array(Anthropic::Models::WebFetchURLSourceAll, Anthropic::Models::WebFetchURLSourceNone, Anthropic::Models::WebFetchURLSourceOnly, Anthropic::Models::WebFetchURLSourceExcept)
|
|
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 81
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::WebFetchURLSources::client_tool_results]
63 |
# File 'sig/anthropic/models/web_fetch_url_sources.rbs', line 63 def self?.variants: -> ::Array[Anthropic::Models::WebFetchURLSources::client_tool_results] |