Module: Anthropic::Models::WebFetchURLSources::ServerToolResults

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/web_fetch_url_sources.rb,
sig/anthropic/models/web_fetch_url_sources.rbs

Overview

Which server tools' results contribute fetchable URLs: "all", "none", or an only or except list of server tool names from tools; only web_search and web_fetch results ever contribute.

See Also:

  • Anthropic::Models::WebFetchURLSources#server_tool_results

Defined Under Namespace

Modules: Type

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::WebFetchURLSourceAll, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 163

def self.new(type:, **args)
  case type.to_sym
  when :all
    Anthropic::WebFetchURLSourceAll.new(**args)
  when :none
    Anthropic::WebFetchURLSourceNone.new(**args)
  when :only
    Anthropic::WebFetchURLSourceOnly.new(**args)
  when :except
    Anthropic::WebFetchURLSourceExcept.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 145


.variantsArray(Anthropic::Models::WebFetchURLSourceAll, Anthropic::Models::WebFetchURLSourceNone, Anthropic::Models::WebFetchURLSourceOnly, Anthropic::Models::WebFetchURLSourceExcept)



# File 'lib/anthropic/models/web_fetch_url_sources.rb', line 149


Instance Method Details

#self?.variants::Array[Anthropic::Models::WebFetchURLSources::server_tool_results]

Returns:

  • (::Array[Anthropic::Models::WebFetchURLSources::server_tool_results])


105
# File 'sig/anthropic/models/web_fetch_url_sources.rbs', line 105

def self?.variants: -> ::Array[Anthropic::Models::WebFetchURLSources::server_tool_results]