Class: Anthropic::Resources::Beta::Sessions::Threads

Inherits:
Object
  • Object
show all
Defined in:
lib/anthropic/resources/beta/sessions/threads.rb,
lib/anthropic/resources/beta/sessions/threads/events.rb,
sig/anthropic/resources/beta/sessions/threads.rbs,
sig/anthropic/resources/beta/sessions/threads/events.rbs

Defined Under Namespace

Classes: Events

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Threads

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Threads.

Parameters:



124
125
126
127
# File 'lib/anthropic/resources/beta/sessions/threads.rb', line 124

def initialize(client:)
  @client = client
  @events = Anthropic::Resources::Beta::Sessions::Threads::Events.new(client: client)
end

Instance Attribute Details

#eventsAnthropic::Resources::Beta::Sessions::Threads::Events (readonly)



9
10
11
# File 'lib/anthropic/resources/beta/sessions/threads.rb', line 9

def events
  @events
end

Instance Method Details

#archive(thread_id, session_id:, betas: nil, workspace_id: nil, request_options: {}) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread

Archive Session Thread

Some parameter documentations has been truncated, see Models::Beta::Sessions::ThreadArchiveParams for more details.

Parameters:

  • thread_id (String)

    Path param: Path parameter thread_id

  • session_id (String)

    Path param: Path parameter session_id

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>)

    Header param: Optional header to specify the beta version(s) you want to use.

  • workspace_id (String)

    Header param: Optional header to select the Workspace for this request. The valu

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/anthropic/resources/beta/sessions/threads.rb', line 106

def archive(thread_id, params)
  parsed, options = Anthropic::Beta::Sessions::ThreadArchiveParams.dump_request(params)
  session_id =
    parsed.delete(:session_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :post,
    path: ["v1/sessions/%1$s/threads/%2$s/archive?beta=true", session_id, thread_id],
    headers: parsed.transform_keys(betas: "anthropic-beta", workspace_id: "anthropic-workspace-id"),
    model: Anthropic::Beta::Sessions::BetaManagedAgentsSessionThread,
    options: {extra_headers: {"anthropic-beta" => "managed-agents-2026-04-01"}, **options}
  )
end

#list(session_id, limit: nil, page: nil, betas: nil, workspace_id: nil, request_options: {}) ⇒ Anthropic::Internal::PageCursor<Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread>

List Session Threads

Some parameter documentations has been truncated, see Models::Beta::Sessions::ThreadListParams for more details.

Parameters:

  • session_id (String)

    Path param: Path parameter session_id

  • limit (Integer)

    Query param: Maximum results per page. Defaults to 1000.

  • page (String)

    Query param: Opaque pagination cursor from a previous response's next_page. Fo

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>)

    Header param: Optional header to specify the beta version(s) you want to use.

  • workspace_id (String)

    Header param: Optional header to select the Workspace for this request. The valu

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/anthropic/resources/beta/sessions/threads.rb', line 68

def list(session_id, params = {})
  query_params = [:limit, :page]
  parsed, options = Anthropic::Beta::Sessions::ThreadListParams.dump_request(params)
  query = Anthropic::Internal::Util.encode_query_params(parsed.slice(*query_params))
  @client.request(
    method: :get,
    path: ["v1/sessions/%1$s/threads?beta=true", session_id],
    query: query,
    headers: parsed.except(*query_params).transform_keys(
      betas: "anthropic-beta",
      workspace_id: "anthropic-workspace-id"
    ),
    page: Anthropic::Internal::PageCursor,
    model: Anthropic::Beta::Sessions::BetaManagedAgentsSessionThread,
    options: {extra_headers: {"anthropic-beta" => "managed-agents-2026-04-01"}, **options}
  )
end

#retrieve(thread_id, session_id:, betas: nil, workspace_id: nil, request_options: {}) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread

Get Session Thread

Some parameter documentations has been truncated, see Models::Beta::Sessions::ThreadRetrieveParams for more details.

Parameters:

  • thread_id (String)

    Path param: Path parameter thread_id

  • session_id (String)

    Path param: Path parameter session_id

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>)

    Header param: Optional header to specify the beta version(s) you want to use.

  • workspace_id (String)

    Header param: Optional header to select the Workspace for this request. The valu

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



31
32
33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/anthropic/resources/beta/sessions/threads.rb', line 31

def retrieve(thread_id, params)
  parsed, options = Anthropic::Beta::Sessions::ThreadRetrieveParams.dump_request(params)
  session_id =
    parsed.delete(:session_id) do
      raise ArgumentError.new("missing required path argument #{_1}")
    end
  @client.request(
    method: :get,
    path: ["v1/sessions/%1$s/threads/%2$s?beta=true", session_id, thread_id],
    headers: parsed.transform_keys(betas: "anthropic-beta", workspace_id: "anthropic-workspace-id"),
    model: Anthropic::Beta::Sessions::BetaManagedAgentsSessionThread,
    options: {extra_headers: {"anthropic-beta" => "managed-agents-2026-04-01"}, **options}
  )
end