Class: Anthropic::Models::Beta::BetaAdvisorTool20260301

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_advisor_tool_20260301.rb

Defined Under Namespace

Modules: AllowedCaller

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(model:, allowed_callers: nil, cache_control: nil, caching: nil, defer_loading: nil, max_uses: nil, strict: nil, name: :advisor, type: :advisor_20260301) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaAdvisorTool20260301 for more details.

Parameters:



# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 67

Instance Attribute Details

#allowed_callersArray<Symbol, Anthropic::Models::Beta::BetaAdvisorTool20260301::AllowedCaller>?



31
32
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 31

optional :allowed_callers,
-> { Anthropic::Internal::Type::ArrayOf[enum: Anthropic::Beta::BetaAdvisorTool20260301::AllowedCaller] }

#cache_controlAnthropic::Models::Beta::BetaCacheControlEphemeral?

Create a cache control breakpoint at this content block.



38
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 38

optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true

#cachingAnthropic::Models::Beta::BetaCacheControlEphemeral?

Caching for the advisor’s own prompt. When set, each advisor call writes a cache entry at the given TTL so subsequent calls in the same conversation read the stable prefix. When omitted, the advisor prompt is not cached.



46
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 46

optional :caching, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true

#defer_loadingBoolean?

If true, tool will not be included in initial system prompt. Only loaded when returned via tool_reference from tool search.

Returns:



53
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 53

optional :defer_loading, Anthropic::Internal::Type::Boolean

#max_usesInteger?

Maximum number of times the tool can be used in the API request.

Returns:

  • (Integer, nil)


59
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 59

optional :max_uses, Integer, nil?: true

#modelSymbol, ...

The model that will complete your prompt.nnSee [models](docs.anthropic.com/en/docs/models-overview) for additional details and options.

Returns:



13
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 13

required :model, union: -> { Anthropic::Model }

#nameSymbol, :advisor

Name of the tool.

This is how the tool will be called by the model and in ‘tool_use` blocks.

Returns:

  • (Symbol, :advisor)


21
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 21

required :name, const: :advisor

#strictBoolean?

When true, guarantees schema validation on tool names and inputs

Returns:



65
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 65

optional :strict, Anthropic::Internal::Type::Boolean

#typeSymbol, :advisor_20260301

Returns:

  • (Symbol, :advisor_20260301)


26
# File 'lib/anthropic/models/beta/beta_advisor_tool_20260301.rb', line 26

required :type, const: :advisor_20260301