Class: Anthropic::Models::Beta::BetaBrowserStateBlockParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaBrowserStateBlockParam
- Defined in:
- lib/anthropic/models/beta/beta_browser_state_block_param.rb,
sig/anthropic/models/beta/beta_browser_state_block_param.rbs
Instance Attribute Summary collapse
-
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
-
#state_changes ⇒ Array<Anthropic::Models::Beta::BetaBrowserStateChangeTabOpened, Anthropic::Models::Beta::BetaBrowserStateChangeDownloadStarted, Anthropic::Models::Beta::BetaBrowserStateChangeDownloadCompleted, Anthropic::Models::Beta::BetaBrowserStateChangeDownloadFailed>?
Tabs opened and download state changes during this call.
-
#tabs ⇒ Array<Anthropic::Models::Beta::BetaBrowserStateTabEntry>
All tabs open in the browser after this call — the full inventory, not a delta.
- #type ⇒ Symbol, :browser_state
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/anthropic/models/beta/beta_browser_state_block_param.rbs', line 23
def initialize: (
|
Instance Attribute Details
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
23 |
# File 'lib/anthropic/models/beta/beta_browser_state_block_param.rb', line 23 optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true |
#state_changes ⇒ Array<Anthropic::Models::Beta::BetaBrowserStateChangeTabOpened, Anthropic::Models::Beta::BetaBrowserStateChangeDownloadStarted, Anthropic::Models::Beta::BetaBrowserStateChangeDownloadCompleted, Anthropic::Models::Beta::BetaBrowserStateChangeDownloadFailed>?
Tabs opened and download state changes during this call. "Nothing to report" is expressed by omitting the field, never by an empty list.
30 31 32 |
# File 'lib/anthropic/models/beta/beta_browser_state_block_param.rb', line 30 optional :state_changes, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaBrowserStateChange] }, nil?: true |
#tabs ⇒ Array<Anthropic::Models::Beta::BetaBrowserStateTabEntry>
All tabs open in the browser after this call — the full inventory, not a delta.
May be empty. Whenever non-empty, exactly one entry carries active: true.
12 |
# File 'lib/anthropic/models/beta/beta_browser_state_block_param.rb', line 12 required :tabs, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::BetaBrowserStateTabEntry] } |
#type ⇒ Symbol, :browser_state
17 |
# File 'lib/anthropic/models/beta/beta_browser_state_block_param.rb', line 17 required :type, const: :browser_state |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/anthropic/models/beta/beta_browser_state_block_param.rbs', line 30
def to_hash: -> {
|