Module: Anthropic::Models::Beta::BetaCloudConfig::Networking
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_cloud_config.rb,
sig/anthropic/models/beta/beta_cloud_config.rbs
Overview
Network configuration policy.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaUnrestrictedNetwork, Anthropic::Models::Beta::BetaLimitedNetwork
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaUnrestrictedNetwork, Anthropic::Models::Beta::BetaLimitedNetwork)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaUnrestrictedNetwork, Anthropic::Models::Beta::BetaLimitedNetwork
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaCloudConfig::Networking for more details.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/anthropic/models/beta/beta_cloud_config.rb', line 69 def self.new(type:, **args) case type.to_sym when :unrestricted Anthropic::Beta::BetaUnrestrictedNetwork.new(**args) when :limited Anthropic::Beta::BetaLimitedNetwork.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaUnrestrictedNetwork, Anthropic::Models::Beta::BetaLimitedNetwork)
|
|
# File 'lib/anthropic/models/beta/beta_cloud_config.rb', line 48
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaCloudConfig::networking]
39 |
# File 'sig/anthropic/models/beta/beta_cloud_config.rbs', line 39
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaCloudConfig::networking]
|