Class: Anthropic::Models::Beta::BetaCloudConfigParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaCloudConfigParams
- Defined in:
- lib/anthropic/models/beta/beta_cloud_config_params.rb
Defined Under Namespace
Modules: Networking
Instance Attribute Summary collapse
-
#networking ⇒ Anthropic::Models::Beta::BetaUnrestrictedNetwork, ...
Network configuration policy.
-
#packages ⇒ Anthropic::Models::Beta::BetaPackagesParams?
Specify packages (and optionally their versions) available in this environment.
-
#type ⇒ Symbol, :cloud
Environment type.
Instance Method Summary collapse
-
#initialize(networking: nil, packages: nil, type: :cloud) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaCloudConfigParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(networking: nil, packages: nil, type: :cloud) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaCloudConfigParams for more details.
Request params for ‘cloud` environment configuration.
Fields default to null; on update, omitted fields preserve the existing value.
|
|
# File 'lib/anthropic/models/beta/beta_cloud_config_params.rb', line 29
|
Instance Attribute Details
#networking ⇒ Anthropic::Models::Beta::BetaUnrestrictedNetwork, ...
Network configuration policy. Omit on update to preserve the existing value.
17 |
# File 'lib/anthropic/models/beta/beta_cloud_config_params.rb', line 17 optional :networking, union: -> { Anthropic::Beta::BetaCloudConfigParams::Networking }, nil?: true |
#packages ⇒ Anthropic::Models::Beta::BetaPackagesParams?
Specify packages (and optionally their versions) available in this environment.
When versioning, use the version semantics relevant for the package manager, e.g. for ‘pip` use `package==1.0.0`. You are responsible for validating the package and version exist. Unversioned installs the latest.
27 |
# File 'lib/anthropic/models/beta/beta_cloud_config_params.rb', line 27 optional :packages, -> { Anthropic::Beta::BetaPackagesParams }, nil?: true |
#type ⇒ Symbol, :cloud
Environment type
11 |
# File 'lib/anthropic/models/beta/beta_cloud_config_params.rb', line 11 required :type, const: :cloud |