Class: Anthropic::Models::Beta::BetaCompactionBlockParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaCompactionBlockParam
- Defined in:
- lib/anthropic/models/beta/beta_compaction_block_param.rb,
sig/anthropic/models/beta/beta_compaction_block_param.rbs
Instance Attribute Summary collapse
-
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
-
#content ⇒ String?
Summary of previously compacted content, or null if compaction failed.
-
#encrypted_content ⇒ String?
Opaque metadata from prior compaction, to be round-tripped verbatim.
- #type ⇒ Symbol, :compaction
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
23 |
# File 'sig/anthropic/models/beta/beta_compaction_block_param.rbs', line 23
def initialize: (
|
Instance Attribute Details
#cache_control ⇒ Anthropic::Models::Beta::BetaCacheControlEphemeral?
Create a cache control breakpoint at this content block.
16 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 16 optional :cache_control, -> { Anthropic::Beta::BetaCacheControlEphemeral }, nil?: true |
#content ⇒ String?
Summary of previously compacted content, or null if compaction failed
22 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 22 optional :content, String, nil?: true |
#encrypted_content ⇒ String?
Opaque metadata from prior compaction, to be round-tripped verbatim
28 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 28 optional :encrypted_content, String, nil?: true |
#type ⇒ Symbol, :compaction
10 |
# File 'lib/anthropic/models/beta/beta_compaction_block_param.rb', line 10 required :type, const: :compaction |
Instance Method Details
#to_hash ⇒ {
30 |
# File 'sig/anthropic/models/beta/beta_compaction_block_param.rbs', line 30
def to_hash: -> {
|