Module: Anthropic::Models::Beta::BetaContentBlockSourceContent
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_content_block_source_content.rb
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaImageBlockParam
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaImageBlockParam)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaImageBlockParam
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/anthropic/models/beta/beta_content_block_source_content.rb', line 35 def self.new(type:, **args) case type.to_sym when :text Anthropic::Beta::BetaTextBlockParam.new(**args) when :image Anthropic::Beta::BetaImageBlockParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaTextBlockParam, Anthropic::Models::Beta::BetaImageBlockParam)
|
|
# File 'lib/anthropic/models/beta/beta_content_block_source_content.rb', line 15
|