Module: Anthropic::Models::Beta::BetaDiagnostics::CacheMissReason

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/beta_diagnostics.rb

Overview

Explains why the prompt cache could not fully reuse the prefix from the request identified by ‘diagnostics.previous_message_id`. `null` means diagnosis is still pending — the response was serialized before the background comparison completed.

See Also:

Method Summary

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info