Module: Anthropic::Models::Beta::BetaDreamInput
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_dream_input.rb
Overview
An input memory store the dream reads from. The dream never mutates this store unless it is also the destination: with output_behavior "update_existing" the job consolidates this store in place.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaDreamMemoryStoreInput, Anthropic::Models::Beta::BetaDreamSessionsInput
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaDreamMemoryStoreInput, Anthropic::Models::Beta::BetaDreamSessionsInput)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaDreamMemoryStoreInput, Anthropic::Models::Beta::BetaDreamSessionsInput
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/anthropic/models/beta/beta_dream_input.rb', line 36 def self.new(type:, **args) case type.to_sym when :memory_store Anthropic::Beta::BetaDreamMemoryStoreInput.new(**args) when :sessions Anthropic::Beta::BetaDreamSessionsInput.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaDreamMemoryStoreInput, Anthropic::Models::Beta::BetaDreamSessionsInput)
|
|
# File 'lib/anthropic/models/beta/beta_dream_input.rb', line 20
|