Class: Anthropic::Models::Beta::BetaEnvironment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaEnvironment
- Defined in:
- lib/anthropic/models/beta/beta_environment.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#archived_at ⇒ String?
RFC 3339 timestamp when environment was archived, or null if not archived.
-
#config ⇒ Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig
Environment configuration (either Anthropic Cloud or self-hosted).
-
#created_at ⇒ String
RFC 3339 timestamp when environment was created.
-
#description ⇒ String
User-provided description for the environment.
-
#id ⇒ String
Environment identifier (e.g., ‘env_…’).
-
#metadata ⇒ Hash{Symbol=>String}
User-provided metadata key-value pairs.
-
#name ⇒ String
Human-readable name for the environment.
-
#scope ⇒ Symbol, ...
The visibility scope for this environment.
-
#type ⇒ Symbol, :environment
The type of object (always ‘environment’).
-
#updated_at ⇒ String
RFC 3339 timestamp when environment was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived_at:, config:, created_at:, description:, metadata:, name:, updated_at:, scope: nil, type: :environment) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaEnvironment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, config:, created_at:, description:, metadata:, name:, updated_at:, scope: nil, type: :environment) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaEnvironment for more details.
Unified Environment resource for both cloud and self-hosted environments.
|
|
# File 'lib/anthropic/models/beta/beta_environment.rb', line 69
|
Instance Attribute Details
#archived_at ⇒ String?
RFC 3339 timestamp when environment was archived, or null if not archived
18 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 18 required :archived_at, String, nil?: true |
#config ⇒ Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig
Environment configuration (either Anthropic Cloud or self-hosted)
24 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 24 required :config, union: -> { Anthropic::Beta::BetaEnvironment::Config } |
#created_at ⇒ String
RFC 3339 timestamp when environment was created
30 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 30 required :created_at, String |
#description ⇒ String
User-provided description for the environment
36 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 36 required :description, String |
#id ⇒ String
Environment identifier (e.g., ‘env_…’)
12 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
User-provided metadata key-value pairs
42 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 42 required :metadata, Anthropic::Internal::Type::HashOf[String] |
#name ⇒ String
Human-readable name for the environment
48 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 48 required :name, String |
#scope ⇒ Symbol, ...
The visibility scope for this environment. ‘organization’ means visible to all accounts. ‘account’ means visible only to the owning account.
67 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 67 optional :scope, enum: -> { Anthropic::Beta::BetaEnvironment::Scope } |
#type ⇒ Symbol, :environment
The type of object (always ‘environment’)
54 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 54 required :type, const: :environment |
#updated_at ⇒ String
RFC 3339 timestamp when environment was last updated
60 |
# File 'lib/anthropic/models/beta/beta_environment.rb', line 60 required :updated_at, String |
Class Method Details
.variants ⇒ Array(Anthropic::Models::Beta::BetaCloudConfig, Anthropic::Models::Beta::BetaSelfHostedConfig)
|
|
# File 'lib/anthropic/models/beta/beta_environment.rb', line 109
|