Module: Anthropic::Models::Beta::BetaFallbacksParam
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_fallbacks_param.rb
Overview
Opt-in server-side retry on one or more substitute models when the requested model declines for policy reasons. Tried in order: if the first entry also declines, the second is tried, and so on. The string "default" requests the requested model's server-defined default fallback configuration.
Constant Summary collapse
- BetaFallbackParamArray =
Anthropic::Internal::Type::ArrayOf[-> { Anthropic::Beta::BetaFallbackParam }]
Class Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Array<Anthropic::Models::Beta::BetaFallbackParam>, Symbol, :default)
|
|
# File 'lib/anthropic/models/beta/beta_fallbacks_param.rb', line 17
|