Class: Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb

Defined Under Namespace

Modules: Name, PermissionPolicy

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, enabled: nil, permission_policy: nil) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams for more details.

Configuration override for a specific tool within a toolset.

Parameters:



# File 'lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb', line 28

Instance Attribute Details

#enabledBoolean?

Whether this tool is enabled and available to Claude. Overrides the default_config setting.

Returns:



18
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb', line 18

optional :enabled, Anthropic::Internal::Type::Boolean, nil?: true

#nameSymbol, Anthropic::Models::Beta::BetaManagedAgentsAgentToolConfigParams::Name

Built-in agent tool identifier.



11
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb', line 11

required :name, enum: -> { Anthropic::Beta::BetaManagedAgentsAgentToolConfigParams::Name }

#permission_policyAnthropic::Models::Beta::BetaManagedAgentsAlwaysAllowPolicy, ...

Permission policy for tool execution.



24
25
26
# File 'lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb', line 24

optional :permission_policy,
union: -> { Anthropic::Beta::BetaManagedAgentsAgentToolConfigParams::PermissionPolicy },
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/anthropic/models/beta/beta_managed_agents_agent_tool_config_params.rb', line 56