Class: Anthropic::Models::Beta::BetaManagedAgentsDeployment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaManagedAgentsDeployment
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_deployment.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#agent ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentReference
A resolved agent reference with a concrete version.
-
#archived_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#description ⇒ String?
Description of what the deployment does.
-
#environment_id ⇒ String
ID of the ‘environment` where sessions run.
-
#id ⇒ String
Unique identifier for this deployment.
-
#initial_events ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserMessageEvent, Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserDefineOutcomeEvent, Anthropic::Models::Beta::BetaManagedAgentsDeploymentSystemMessageEvent>
Events sent to each session immediately after creation.
-
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata.
-
#name ⇒ String
Human-readable name.
-
#paused_reason ⇒ Anthropic::Models::Beta::BetaManagedAgentsManualDeploymentPausedReason, ...
Why a deployment is paused.
-
#resources ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsFileResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceConfig>
Resources attached to sessions created from this deployment.
-
#schedule ⇒ Anthropic::Models::Beta::BetaManagedAgentsSchedule?
5-field POSIX cron schedule with computed runtime timestamps.
-
#status ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsDeploymentStatus
Lifecycle status of a deployment.
- #type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsDeployment::Type
-
#updated_at ⇒ Time
A timestamp in RFC 3339 format.
-
#vault_ids ⇒ Array<String>
Vault IDs supplying stored credentials for sessions created from this deployment.
Instance Method Summary collapse
-
#initialize(id:, agent:, archived_at:, created_at:, description:, environment_id:, initial_events:, metadata:, name:, paused_reason:, resources:, schedule:, status:, type:, updated_at:, vault_ids:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsDeployment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, agent:, archived_at:, created_at:, description:, environment_id:, initial_events:, metadata:, name:, paused_reason:, resources:, schedule:, status:, type:, updated_at:, vault_ids:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsDeployment for more details.
A deployment is a configured instance of an agent — it binds the agent to everything needed to run it autonomously: an environment, credentials, initial events, and an optional schedule.
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 109
|
Instance Attribute Details
#agent ⇒ Anthropic::Models::Beta::BetaManagedAgentsAgentReference
A resolved agent reference with a concrete version.
18 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 18 required :agent, -> { Anthropic::Beta::BetaManagedAgentsAgentReference } |
#archived_at ⇒ Time?
A timestamp in RFC 3339 format
24 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 24 required :archived_at, Time, nil?: true |
#created_at ⇒ Time
A timestamp in RFC 3339 format
30 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 30 required :created_at, Time |
#description ⇒ String?
Description of what the deployment does.
36 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 36 required :description, String, nil?: true |
#environment_id ⇒ String
ID of the ‘environment` where sessions run.
42 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 42 required :environment_id, String |
#id ⇒ String
Unique identifier for this deployment.
12 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 12 required :id, String |
#initial_events ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserMessageEvent, Anthropic::Models::Beta::BetaManagedAgentsDeploymentUserDefineOutcomeEvent, Anthropic::Models::Beta::BetaManagedAgentsDeploymentSystemMessageEvent>
Events sent to each session immediately after creation.
48 49 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 48 required :initial_events, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaManagedAgentsDeploymentInitialEvent] } |
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata. Maximum 16 pairs.
55 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 55 required :metadata, Anthropic::Internal::Type::HashOf[String] |
#name ⇒ String
Human-readable name.
61 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 61 required :name, String |
#paused_reason ⇒ Anthropic::Models::Beta::BetaManagedAgentsManualDeploymentPausedReason, ...
Why a deployment is paused. Non-null exactly when ‘status` is `paused`.
67 68 69 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 67 required :paused_reason, union: -> { Anthropic::Beta::BetaManagedAgentsDeploymentPausedReason }, nil?: true |
#resources ⇒ Array<Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsFileResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceConfig>
Resources attached to sessions created from this deployment. Echoes the input minus write-only credentials.
76 77 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 76 required :resources, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaManagedAgentsSessionResourceConfig] } |
#schedule ⇒ Anthropic::Models::Beta::BetaManagedAgentsSchedule?
5-field POSIX cron schedule with computed runtime timestamps.
83 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 83 required :schedule, -> { Anthropic::Beta::BetaManagedAgentsSchedule }, nil?: true |
#status ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsDeploymentStatus
Lifecycle status of a deployment.
89 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 89 required :status, enum: -> { Anthropic::Beta::BetaManagedAgentsDeploymentStatus } |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsDeployment::Type
94 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 94 required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsDeployment::Type } |
#updated_at ⇒ Time
A timestamp in RFC 3339 format
100 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment.rb', line 100 required :updated_at, Time |