Module: Anthropic::Models::Beta::BetaManagedAgentsDeploymentPausedReason
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_deployment_paused_reason.rb
Overview
Why a deployment is paused. Non-null exactly when status is paused.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsManualDeploymentPausedReason, Anthropic::Models::Beta::BetaManagedAgentsErrorDeploymentPausedReason
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsManualDeploymentPausedReason, Anthropic::Models::Beta::BetaManagedAgentsErrorDeploymentPausedReason)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsManualDeploymentPausedReason, Anthropic::Models::Beta::BetaManagedAgentsErrorDeploymentPausedReason
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment_paused_reason.rb', line 32 def self.new(type:, **args) case type.to_sym when :manual Anthropic::Beta::BetaManagedAgentsManualDeploymentPausedReason.new(**args) when :error Anthropic::Beta::BetaManagedAgentsErrorDeploymentPausedReason.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsManualDeploymentPausedReason, Anthropic::Models::Beta::BetaManagedAgentsErrorDeploymentPausedReason)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_deployment_paused_reason.rb', line 18
|