Class: Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access ⇒ Symbol, ...
Access mode for an attached memory store.
-
#instructions ⇒ String?
Per-attachment guidance for the agent on how to use this store.
-
#memory_store_id ⇒ String
The memory store ID (memstore_…).
- #type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(memory_store_id:, type:, access: nil, instructions: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsMemoryStoreResourceParam for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(memory_store_id:, type:, access: nil, instructions: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam for more details.
Parameters for attaching a memory store to an agent session.
and
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb', line 34
|
Instance Attribute Details
#access ⇒ Symbol, ...
Access mode for an attached memory store.
23 24 25 |
# File 'lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb', line 23 optional :access, enum: -> { Anthropic::Beta::BetaManagedAgentsMemoryStoreResourceParam::Access }, nil?: true |
#instructions ⇒ String?
Per-attachment guidance for the agent on how to use this store. Rendered into the memory section of the system prompt. Max 4096 chars.
32 |
# File 'lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb', line 32 optional :instructions, String, nil?: true |
#memory_store_id ⇒ String
The memory store ID (memstore_…). Must belong to the caller’s organization and workspace.
12 |
# File 'lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb', line 12 required :memory_store_id, String |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam::Type
17 |
# File 'lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb', line 17 required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsMemoryStoreResourceParam::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_memory_store_resource_param.rb', line 56
|