Module: Anthropic::Models::Beta::BetaManagedAgentsModelConfig::Effort
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_model_config.rb,
sig/anthropic/models/beta/beta_managed_agents_model_config.rbs
Overview
How hard Claude works on each turn. Sets output_config.effort on every
Messages call the session makes.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsEffortLow, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsEffortLow, Anthropic::Models::Beta::BetaManagedAgentsEffortMedium, Anthropic::Models::Beta::BetaManagedAgentsEffortHigh, Anthropic::Models::Beta::BetaManagedAgentsEffortXhigh, Anthropic::Models::Beta::BetaManagedAgentsEffortMax)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsEffortLow, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/anthropic/models/beta/beta_managed_agents_model_config.rb', line 88 def self.new(type:, **args) case type.to_sym when :low Anthropic::Beta::BetaManagedAgentsEffortLow.new(**args) when :medium Anthropic::Beta::BetaManagedAgentsEffortMedium.new(**args) when :high Anthropic::Beta::BetaManagedAgentsEffortHigh.new(**args) when :xhigh Anthropic::Beta::BetaManagedAgentsEffortXhigh.new(**args) when :max Anthropic::Beta::BetaManagedAgentsEffortMax.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsEffortLow, Anthropic::Models::Beta::BetaManagedAgentsEffortMedium, Anthropic::Models::Beta::BetaManagedAgentsEffortHigh, Anthropic::Models::Beta::BetaManagedAgentsEffortXhigh, Anthropic::Models::Beta::BetaManagedAgentsEffortMax)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_model_config.rb', line 76
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsModelConfig::effort]
57 |
# File 'sig/anthropic/models/beta/beta_managed_agents_model_config.rbs', line 57
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsModelConfig::effort]
|