Class: Anthropic::Models::Beta::BetaManagedAgentsMultiagentCoordinatorParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaManagedAgentsMultiagentCoordinatorParams
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_multiagent_coordinator_params.rb,
sig/anthropic/models/beta/beta_managed_agents_multiagent_coordinator_params.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#agents ⇒ Array<String, Anthropic::Models::Beta::BetaManagedAgentsAgentParams, Anthropic::Models::Beta::BetaManagedAgentsMultiagentSelfParams>
Agents the coordinator may spawn as session threads.
- #type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsMultiagentCoordinatorParams::Type
Instance Method Summary collapse
-
#initialize(agents:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsMultiagentCoordinatorParams for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agents:, type:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsMultiagentCoordinatorParams for more details.
A coordinator topology: the session's primary thread orchestrates work by
spawning session threads, each running an agent drawn from the agents roster.
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_multiagent_coordinator_params.rb', line 24
|
Instance Attribute Details
#agents ⇒ Array<String, Anthropic::Models::Beta::BetaManagedAgentsAgentParams, Anthropic::Models::Beta::BetaManagedAgentsMultiagentSelfParams>
Agents the coordinator may spawn as session threads. 1–20 entries. Each entry is
an agent ID string, a versioned {"type":"agent","id","version"} reference, or
{"type":"self"} to allow recursive self-invocation. Entries must reference
distinct agents (after resolving self and string forms); at most one self.
Referenced agents must exist, must not be archived, and must not themselves have
multiagent set (depth limit 1).
16 17 |
# File 'lib/anthropic/models/beta/beta_managed_agents_multiagent_coordinator_params.rb', line 16 required :agents, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaManagedAgentsMultiagentRosterEntryParams] } |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaManagedAgentsMultiagentCoordinatorParams::Type
22 |
# File 'lib/anthropic/models/beta/beta_managed_agents_multiagent_coordinator_params.rb', line 22 required :type, enum: -> { Anthropic::Beta::BetaManagedAgentsMultiagentCoordinatorParams::Type } |
Instance Method Details
#to_hash ⇒ {
22 |
# File 'sig/anthropic/models/beta/beta_managed_agents_multiagent_coordinator_params.rbs', line 22
def to_hash: -> {
|