Module: Anthropic::Models::Beta::BetaManagedAgentsSessionResourceConfig
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_session_resource_config.rb
Overview
A configured session resource. Echoes the input minus write-only credentials.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsFileResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceConfig)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaManagedAgentsSessionResourceConfig for more details.
52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/anthropic/models/beta/beta_managed_agents_session_resource_config.rb', line 52 def self.new(type:, **args) case type.to_sym when :github_repository Anthropic::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig.new(**args) when :file Anthropic::Beta::BetaManagedAgentsFileResourceConfig.new(**args) when :memory_store Anthropic::Beta::BetaManagedAgentsMemoryStoreResourceConfig.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsFileResourceConfig, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceConfig)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_session_resource_config.rb', line 21
|