Module: Anthropic::Models::Beta::BetaManagedAgentsSkillParams
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_skill_params.rb
Overview
Skill to load in the session container.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkillParams, Anthropic::Models::Beta::BetaManagedAgentsCustomSkillParams
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkillParams, Anthropic::Models::Beta::BetaManagedAgentsCustomSkillParams)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkillParams, Anthropic::Models::Beta::BetaManagedAgentsCustomSkillParams
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/anthropic/models/beta/beta_managed_agents_skill_params.rb', line 34 def self.new(type:, **args) case type.to_sym when :anthropic Anthropic::Beta::BetaManagedAgentsAnthropicSkillParams.new(**args) when :custom Anthropic::Beta::BetaManagedAgentsCustomSkillParams.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaManagedAgentsAnthropicSkillParams, Anthropic::Models::Beta::BetaManagedAgentsCustomSkillParams)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_skill_params.rb', line 18
|