Module: Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent::Content
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb,
sig/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rbs
Overview
Content block in a tool result. Can be text, image, document, or
search_result.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsImageBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 129 def self.new(type:, **args) case type.to_sym when :text Anthropic::Beta::Sessions::BetaManagedAgentsTextBlock.new(**args) when :image Anthropic::Beta::Sessions::BetaManagedAgentsImageBlock.new(**args) when :document Anthropic::Beta::Sessions::BetaManagedAgentsDocumentBlock.new(**args) when :search_result Anthropic::Beta::Sessions::BetaManagedAgentsSearchResultBlock.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsImageBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultBlock)
|
|
# File 'lib/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rb', line 105
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent::content]
75 |
# File 'sig/anthropic/models/beta/beta_managed_agents_user_tool_result_event.rbs', line 75
def self?.variants: -> ::Array[Anthropic::Models::Beta::BetaManagedAgentsUserToolResultEvent::content]
|