Module: Anthropic::Models::Beta::BetaMemoryTool20250818Command
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_memory_tool_20250818_command.rb
Class Method Summary collapse
-
.new(command:, **args) ⇒ Anthropic::Models::Beta::BetaMemoryTool20250818ViewCommand, ...
Creates a new instance of the variant class whose
commandmatches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaMemoryTool20250818ViewCommand, Anthropic::Models::Beta::BetaMemoryTool20250818CreateCommand, Anthropic::Models::Beta::BetaMemoryTool20250818StrReplaceCommand, Anthropic::Models::Beta::BetaMemoryTool20250818InsertCommand, Anthropic::Models::Beta::BetaMemoryTool20250818DeleteCommand, Anthropic::Models::Beta::BetaMemoryTool20250818RenameCommand)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(command:, **args) ⇒ Anthropic::Models::Beta::BetaMemoryTool20250818ViewCommand, ...
Creates a new instance of the variant class whose command matches the given
value, passing the remaining arguments to its constructor.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/anthropic/models/beta/beta_memory_tool_20250818_command.rb', line 53 def self.new(command:, **args) case command.to_sym when :view Anthropic::Beta::BetaMemoryTool20250818ViewCommand.new(**args) when :create Anthropic::Beta::BetaMemoryTool20250818CreateCommand.new(**args) when :str_replace Anthropic::Beta::BetaMemoryTool20250818StrReplaceCommand.new(**args) when :insert Anthropic::Beta::BetaMemoryTool20250818InsertCommand.new(**args) when :delete Anthropic::Beta::BetaMemoryTool20250818DeleteCommand.new(**args) when :rename Anthropic::Beta::BetaMemoryTool20250818RenameCommand.new(**args) else raise ArgumentError, "unknown command: #{command}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaMemoryTool20250818ViewCommand, Anthropic::Models::Beta::BetaMemoryTool20250818CreateCommand, Anthropic::Models::Beta::BetaMemoryTool20250818StrReplaceCommand, Anthropic::Models::Beta::BetaMemoryTool20250818InsertCommand, Anthropic::Models::Beta::BetaMemoryTool20250818DeleteCommand, Anthropic::Models::Beta::BetaMemoryTool20250818RenameCommand)
|
|
# File 'lib/anthropic/models/beta/beta_memory_tool_20250818_command.rb', line 23
|