Class: Anthropic::Models::Beta::BetaModelInfo

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/beta_model_info.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Anthropic::Internal::Type::BaseModel

Instance Attribute Details

#allowed_fallback_modelsArray<String>?

Model IDs this model accepts as ‘fallbacks.model` on the Messages API. An empty list means the `fallbacks` parameter is not supported for this model as primary.

Returns:

  • (Array<String>, nil)


20
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 20

required :allowed_fallback_models, Anthropic::Internal::Type::ArrayOf[String], nil?: true

#capabilitiesAnthropic::Models::Beta::BetaModelCapabilities?

Model capability information.



26
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 26

required :capabilities, -> { Anthropic::Beta::BetaModelCapabilities }, nil?: true

#created_atTime

RFC 3339 datetime string representing the time at which the model was released. May be set to an epoch value if the release date is unknown.

Returns:

  • (Time)


33
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 33

required :created_at, Time

#display_nameString

A human-readable name for the model.

Returns:

  • (String)


39
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 39

required :display_name, String

#idString

Unique model identifier.

Returns:

  • (String)


12
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 12

required :id, String

#max_input_tokensInteger?

Maximum input context window size in tokens for this model.

Returns:

  • (Integer, nil)


45
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 45

required :max_input_tokens, Integer, nil?: true

#max_tokensInteger?

Maximum value for the ‘max_tokens` parameter when using this model.

Returns:

  • (Integer, nil)


51
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 51

required :max_tokens, Integer, nil?: true

#typeSymbol, :model

Object type.

For Models, this is always ‘“model”`.

Returns:

  • (Symbol, :model)


59
# File 'lib/anthropic/models/beta/beta_model_info.rb', line 59

required :type, const: :model