Module: Anthropic::Models::Beta::BetaOutputBehavior
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_output_behavior.rb
Overview
The default destination: the job creates a new output memory store as a clone of the memory_store input and writes the consolidated memories into it. The input store is never mutated.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaOutputBehaviorCreateNew, Anthropic::Models::Beta::BetaOutputBehaviorUpdateExisting
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaOutputBehaviorCreateNew, Anthropic::Models::Beta::BetaOutputBehaviorUpdateExisting)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaOutputBehaviorCreateNew, Anthropic::Models::Beta::BetaOutputBehaviorUpdateExisting
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/anthropic/models/beta/beta_output_behavior.rb', line 34 def self.new(type:, **args) case type.to_sym when :create_new Anthropic::Beta::BetaOutputBehaviorCreateNew.new(**args) when :update_existing Anthropic::Beta::BetaOutputBehaviorUpdateExisting.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaOutputBehaviorCreateNew, Anthropic::Models::Beta::BetaOutputBehaviorUpdateExisting)
|
|
# File 'lib/anthropic/models/beta/beta_output_behavior.rb', line 20
|