Class: Anthropic::Models::Beta::BetaOutputConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaOutputConfig
- Defined in:
- lib/anthropic/models/beta/beta_output_config.rb,
sig/anthropic/models/beta/beta_output_config.rbs
Defined Under Namespace
Modules: Effort
Instance Attribute Summary collapse
-
#effort ⇒ Symbol, ...
How much effort the model should put into its response.
-
#format_ ⇒ Anthropic::Models::Beta::BetaJSONOutputFormat?
A schema to specify Claude's output format in responses.
-
#task_budget ⇒ Anthropic::Models::Beta::BetaTokenTaskBudget?
Configuration for token budget tracking across contexts.
Instance Method Summary collapse
-
#initialize(effort: nil, format_: nil, task_budget: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaOutputConfig for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effort: nil, format_: nil, task_budget: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaOutputConfig for more details.
|
|
# File 'lib/anthropic/models/beta/beta_output_config.rb', line 29
|
Instance Attribute Details
#effort ⇒ Symbol, ...
How much effort the model should put into its response. Higher effort levels may result in more thorough analysis but take longer.
Valid values are low, medium, high, xhigh, or max.
14 |
# File 'lib/anthropic/models/beta/beta_output_config.rb', line 14 optional :effort, enum: -> { Anthropic::Beta::BetaOutputConfig::Effort }, nil?: true |
#format_ ⇒ Anthropic::Models::Beta::BetaJSONOutputFormat?
A schema to specify Claude's output format in responses. See structured outputs
21 |
# File 'lib/anthropic/models/beta/beta_output_config.rb', line 21 optional :format_, -> { Anthropic::Beta::BetaJSONOutputFormat }, api_name: :format, nil?: true |
#task_budget ⇒ Anthropic::Models::Beta::BetaTokenTaskBudget?
Configuration for token budget tracking across contexts.
27 |
# File 'lib/anthropic/models/beta/beta_output_config.rb', line 27 optional :task_budget, -> { Anthropic::Beta::BetaTokenTaskBudget }, nil?: true |
Instance Method Details
#to_hash ⇒ {
26 |
# File 'sig/anthropic/models/beta/beta_output_config.rbs', line 26
def to_hash: -> {
|