Module: Anthropic::Models::Beta::BetaTextCitationParam
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/beta_text_citation_param.rb
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCitationCharLocationParam, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::BetaCitationCharLocationParam, Anthropic::Models::Beta::BetaCitationPageLocationParam, Anthropic::Models::Beta::BetaCitationContentBlockLocationParam, Anthropic::Models::Beta::BetaCitationWebSearchResultLocationParam, Anthropic::Models::Beta::BetaCitationSearchResultLocationParam)
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::BetaCitationCharLocationParam, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaTextCitationParam for more details.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/anthropic/models/beta/beta_text_citation_param.rb', line 64 def self.new(type:, **args) case type.to_sym when :char_location Anthropic::Beta::BetaCitationCharLocationParam.new(**args) when :page_location Anthropic::Beta::BetaCitationPageLocationParam.new(**args) when :content_block_location Anthropic::Beta::BetaCitationContentBlockLocationParam.new(**args) when :web_search_result_location Anthropic::Beta::BetaCitationWebSearchResultLocationParam.new(**args) when :search_result_location Anthropic::Beta::BetaCitationSearchResultLocationParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::BetaCitationCharLocationParam, Anthropic::Models::Beta::BetaCitationPageLocationParam, Anthropic::Models::Beta::BetaCitationContentBlockLocationParam, Anthropic::Models::Beta::BetaCitationWebSearchResultLocationParam, Anthropic::Models::Beta::BetaCitationSearchResultLocationParam)
|
|
# File 'lib/anthropic/models/beta/beta_text_citation_param.rb', line 21
|