Class: Anthropic::Models::Beta::BetaThinkingBlock
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaThinkingBlock
- Defined in:
- lib/anthropic/models/beta/beta_thinking_block.rb,
sig/anthropic/models/beta/beta_thinking_block.rbs
Instance Attribute Summary collapse
-
#signature ⇒ String
A value used to verify that this thinking block was generated by Claude when it is passed back to the API.
-
#thinking ⇒ String
The text of Claude's thinking process for this block.
- #type ⇒ Symbol, :thinking
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ { signature: String, thinking: String, type: :thinking }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
16 |
# File 'sig/anthropic/models/beta/beta_thinking_block.rbs', line 16
def initialize: (
|
Instance Attribute Details
#signature ⇒ String
A value used to verify that this thinking block was generated by Claude when it is passed back to the API.
This is an opaque field and should not be interpreted or parsed. When passing thinking blocks back to the API (required when using tools with extended thinking), pass them back exactly as received, with this field intact.
See extended thinking for details.
20 |
# File 'lib/anthropic/models/beta/beta_thinking_block.rb', line 20 required :signature, String |
#thinking ⇒ String
The text of Claude's thinking process for this block.
26 |
# File 'lib/anthropic/models/beta/beta_thinking_block.rb', line 26 required :thinking, String |
#type ⇒ Symbol, :thinking
31 |
# File 'lib/anthropic/models/beta/beta_thinking_block.rb', line 31 required :type, const: :thinking |
Instance Method Details
#to_hash ⇒ { signature: String, thinking: String, type: :thinking }
22 |
# File 'sig/anthropic/models/beta/beta_thinking_block.rbs', line 22
def to_hash: -> { signature: String, thinking: String, type: :thinking }
|