Class: Anthropic::Models::Beta::BetaTunnel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaTunnel
- Defined in:
- lib/anthropic/models/beta/beta_tunnel.rb,
sig/anthropic/models/beta/beta_tunnel.rbs
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#display_name ⇒ String?
Human-readable name for the tunnel (1-255 characters).
-
#domain ⇒ String
Anthropic-assigned hostname for the tunnel.
-
#id ⇒ String
Unique identifier for the tunnel, prefixed with
tnl_. - #type ⇒ Symbol, :tunnel
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
29 |
# File 'sig/anthropic/models/beta/beta_tunnel.rbs', line 29
def initialize: (
|
Instance Attribute Details
#archived_at ⇒ Time?
A timestamp in RFC 3339 format
18 |
# File 'lib/anthropic/models/beta/beta_tunnel.rb', line 18 required :archived_at, Time, nil?: true |
#created_at ⇒ Time
A timestamp in RFC 3339 format
24 |
# File 'lib/anthropic/models/beta/beta_tunnel.rb', line 24 required :created_at, Time |
#display_name ⇒ String?
Human-readable name for the tunnel (1-255 characters). Null if unset.
30 |
# File 'lib/anthropic/models/beta/beta_tunnel.rb', line 30 required :display_name, String, nil?: true |
#domain ⇒ String
Anthropic-assigned hostname for the tunnel. MCP server URLs whose host is a subdomain of this value are routed through the tunnel. Globally unique and never reused, even after the tunnel is archived.
38 |
# File 'lib/anthropic/models/beta/beta_tunnel.rb', line 38 required :domain, String |
#id ⇒ String
Unique identifier for the tunnel, prefixed with tnl_.
12 |
# File 'lib/anthropic/models/beta/beta_tunnel.rb', line 12 required :id, String |
#type ⇒ Symbol, :tunnel
43 |
# File 'lib/anthropic/models/beta/beta_tunnel.rb', line 43 required :type, const: :tunnel |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/anthropic/models/beta/beta_tunnel.rbs', line 38
def to_hash: -> {
|