Class: Anthropic::Models::Beta::BetaUserProfile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaUserProfile
- Defined in:
- lib/anthropic/models/beta/beta_user_profile.rb,
sig/anthropic/models/beta/beta_user_profile.rbs
Overview
Defined Under Namespace
Modules: Relationship, Type
Instance Attribute Summary collapse
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#external_id ⇒ String?
Platform's own identifier for this user.
-
#id ⇒ String
Unique identifier for this user profile, prefixed
uprof_. -
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata.
-
#name ⇒ String?
Display name of the entity this profile represents.
-
#relationship ⇒ Symbol, Anthropic::Models::Beta::BetaUserProfile::Relationship
How the entity behind a user profile relates to the platform that owns the API key.
-
#trust_grants ⇒ Hash{Symbol=>Anthropic::Models::Beta::BetaUserProfileTrustGrant}
Trust grants for this profile, keyed by grant name.
-
#type ⇒ Symbol, Anthropic::Models::Beta::BetaUserProfile::Type
Object type.
-
#updated_at ⇒ Time
A timestamp in RFC 3339 format.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, metadata:, relationship:, trust_grants:, type:, updated_at:, external_id: nil, name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaUserProfile for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, metadata:, relationship:, trust_grants:, type:, updated_at:, external_id: nil, name: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaUserProfile for more details.
|
|
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 68
|
Instance Attribute Details
#created_at ⇒ Time
A timestamp in RFC 3339 format
18 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 18 required :created_at, Time |
#external_id ⇒ String?
Platform's own identifier for this user. Not enforced unique.
59 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 59 optional :external_id, String, nil?: true |
#id ⇒ String
Unique identifier for this user profile, prefixed uprof_.
12 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata. Maximum 16 pairs, keys up to 64 chars, values up to 512 chars.
25 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 25 required :metadata, Anthropic::Internal::Type::HashOf[String] |
#name ⇒ String?
Display name of the entity this profile represents. For resold this is the
resold-to company's name.
66 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 66 optional :name, String, nil?: true |
#relationship ⇒ Symbol, Anthropic::Models::Beta::BetaUserProfile::Relationship
How the entity behind a user profile relates to the platform that owns the API
key. external: an individual end-user of the platform. resold: a company the
platform resells Claude access to. internal: the platform's own usage.
33 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 33 required :relationship, enum: -> { Anthropic::Beta::BetaUserProfile::Relationship } |
#trust_grants ⇒ Hash{Symbol=>Anthropic::Models::Beta::BetaUserProfileTrustGrant}
Trust grants for this profile, keyed by grant name. Key omitted when no grant is active or in flight.
40 41 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 40 required :trust_grants, -> { Anthropic::Internal::Type::HashOf[Anthropic::Beta::BetaUserProfileTrustGrant] } |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaUserProfile::Type
Object type. Always user_profile.
47 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 47 required :type, enum: -> { Anthropic::Beta::BetaUserProfile::Type } |
#updated_at ⇒ Time
A timestamp in RFC 3339 format
53 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 53 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 102
|
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/anthropic/models/beta/beta_user_profile.rbs', line 50
def to_hash: -> {
|