Class: Anthropic::Models::Beta::BetaUserProfile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::BetaUserProfile
- Defined in:
- lib/anthropic/models/beta/beta_user_profile.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#external_id ⇒ String?
Platform’s own identifier for this user.
-
#id ⇒ String
Unique identifier for this user profile, prefixed ‘uprof_`.
-
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata.
-
#trust_grants ⇒ Hash{Symbol=>Anthropic::Models::Beta::BetaUserProfileTrustGrant}
Trust grants for this profile, keyed by grant name.
-
#type ⇒ Symbol, Anthropic::Models::Beta::BetaUserProfile::Type
Object type.
-
#updated_at ⇒ Time
A timestamp in RFC 3339 format.
Instance Method Summary collapse
-
#initialize(id:, created_at:, metadata:, trust_grants:, type:, updated_at:, external_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaUserProfile for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, metadata:, trust_grants:, type:, updated_at:, external_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::BetaUserProfile for more details.
|
|
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 53
|
Instance Attribute Details
#created_at ⇒ Time
A timestamp in RFC 3339 format
18 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 18 required :created_at, Time |
#external_id ⇒ String?
Platform’s own identifier for this user. Not enforced unique.
51 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 51 optional :external_id, String, nil?: true |
#id ⇒ String
Unique identifier for this user profile, prefixed ‘uprof_`.
12 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Arbitrary key-value metadata. Maximum 16 pairs, keys up to 64 chars, values up to 512 chars.
25 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 25 required :metadata, Anthropic::Internal::Type::HashOf[String] |
#trust_grants ⇒ Hash{Symbol=>Anthropic::Models::Beta::BetaUserProfileTrustGrant}
Trust grants for this profile, keyed by grant name. Key omitted when no grant is active or in flight.
32 33 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 32 required :trust_grants, -> { Anthropic::Internal::Type::HashOf[Anthropic::Beta::BetaUserProfileTrustGrant] } |
#type ⇒ Symbol, Anthropic::Models::Beta::BetaUserProfile::Type
Object type. Always ‘user_profile`.
39 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 39 required :type, enum: -> { Anthropic::Beta::BetaUserProfile::Type } |
#updated_at ⇒ Time
A timestamp in RFC 3339 format
45 |
# File 'lib/anthropic/models/beta/beta_user_profile.rb', line 45 required :updated_at, Time |