Class: Anthropic::Models::Beta::DeploymentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/deployment_create_params.rb

Overview

Defined Under Namespace

Modules: Agent, Resource

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent:, environment_id:, initial_events:, name:, description: nil, metadata: nil, resources: nil, schedule: nil, vault_ids: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::DeploymentCreateParams for more details.

Parameters:



# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 81

Instance Attribute Details

#agentString, Anthropic::Models::Beta::BetaManagedAgentsAgentParams

Agent to deploy. Accepts the ‘agent` ID string, which pins the latest version, or an `agent` object with both id and version specified. The agent must exist and not be archived.



17
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 17

required :agent, union: -> { Anthropic::Beta::DeploymentCreateParams::Agent }

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



79
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 79

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#descriptionString?

Description of what the deployment does.

Returns:

  • (String, nil)


44
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 44

optional :description, String, nil?: true

#environment_idString

ID of the ‘environment` defining the container configuration for sessions created from this deployment.

Returns:

  • (String)


24
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 24

required :environment_id, String

#metadataHash{Symbol=>String}?

Arbitrary key-value metadata. Maximum 16 pairs, keys up to 64 chars, values up to 512 chars.

Returns:

  • (Hash{Symbol=>String}, nil)


51
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 51

optional :metadata, Anthropic::Internal::Type::HashOf[String]

#nameString

Human-readable name for the deployment.

Returns:

  • (String)


38
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 38

required :name, String

#resourcesArray<Anthropic::Models::Beta::BetaManagedAgentsGitHubRepositoryResourceParams, Anthropic::Models::Beta::BetaManagedAgentsFileResourceParams, Anthropic::Models::Beta::BetaManagedAgentsMemoryStoreResourceParam>?

Resources (e.g. repositories, files) to mount into each session’s container. Maximum 500.



58
59
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 58

optional :resources,
-> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::DeploymentCreateParams::Resource] }

#scheduleAnthropic::Models::Beta::BetaManagedAgentsScheduleParams?

5-field POSIX cron schedule. Literal wall-clock matching in the configured timezone.



66
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 66

optional :schedule, -> { Anthropic::Beta::BetaManagedAgentsScheduleParams }, nil?: true

#vault_idsArray<String>?

Vault IDs for stored credentials the agent can use during sessions created from this deployment. Maximum 50.

Returns:

  • (Array<String>, nil)


73
# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 73

optional :vault_ids, Anthropic::Internal::Type::ArrayOf[String]

Class Method Details

.variantsArray(String, Anthropic::Models::Beta::BetaManagedAgentsAgentParams)



# File 'lib/anthropic/models/beta/deployment_create_params.rb', line 118