Class: Anthropic::Models::Beta::DeploymentRunListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::DeploymentRunListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/deployment_run_list_params.rb
Overview
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#created_at_gt ⇒ Time?
Return runs created strictly after this time (exclusive).
-
#created_at_gte ⇒ Time?
Return runs created at or after this time (inclusive).
-
#created_at_lt ⇒ Time?
Return runs created strictly before this time (exclusive).
-
#created_at_lte ⇒ Time?
Return runs created at or before this time (inclusive).
-
#deployment_id ⇒ String?
Filter to a specific deployment.
-
#has_error ⇒ Boolean?
Filter: true for runs with non-null error, false for runs with non-null session_id.
-
#limit ⇒ Integer?
Maximum results per page.
-
#page ⇒ String?
Opaque pagination cursor.
-
#trigger_type ⇒ Symbol, ...
Filter runs by what triggered them.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(created_at_gt: nil, created_at_gte: nil, created_at_lt: nil, created_at_lte: nil, deployment_id: nil, has_error: nil, limit: nil, page: nil, trigger_type: nil, betas: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DeploymentRunListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at_gt: nil, created_at_gte: nil, created_at_lt: nil, created_at_lte: nil, deployment_id: nil, has_error: nil, limit: nil, page: nil, trigger_type: nil, betas: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::DeploymentRunListParams for more details.
session_
|
|
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 75
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
73 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 73 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#created_at_gt ⇒ Time?
Return runs created strictly after this time (exclusive).
15 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 15 optional :created_at_gt, Time |
#created_at_gte ⇒ Time?
Return runs created at or after this time (inclusive).
21 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 21 optional :created_at_gte, Time |
#created_at_lt ⇒ Time?
Return runs created strictly before this time (exclusive).
27 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 27 optional :created_at_lt, Time |
#created_at_lte ⇒ Time?
Return runs created at or before this time (inclusive).
33 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 33 optional :created_at_lte, Time |
#deployment_id ⇒ String?
Filter to a specific deployment. Omit to list across all deployments in the workspace. Filtering by a non-existent deployment_id returns 200 with empty data.
41 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 41 optional :deployment_id, String |
#has_error ⇒ Boolean?
Filter: true for runs with non-null error, false for runs with non-null session_id. Omit for all.
48 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 48 optional :has_error, Anthropic::Internal::Type::Boolean |
#limit ⇒ Integer?
Maximum results per page. Default 20, maximum 1000.
54 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 54 optional :limit, Integer |
#page ⇒ String?
Opaque pagination cursor. Pass next_page from the previous response. Invalid or expired cursors return 400.
61 |
# File 'lib/anthropic/models/beta/deployment_run_list_params.rb', line 61 optional :page, String |