Class: Anthropic::Models::Beta::DreamCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::DreamCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/dream_create_params.rb,
sig/anthropic/models/beta/dream_create_params.rbs
Overview
Defined Under Namespace
Modules: Model
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
- #inputs ⇒ Array<Anthropic::Models::Beta::BetaDreamMemoryStoreInput, Anthropic::Models::Beta::BetaDreamSessionsInput>
- #instructions ⇒ String?
-
#model ⇒ String, Anthropic::Models::Beta::BetaDreamModelConfigParam
Model identifier and configuration applied to every pipeline stage.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(inputs:, model:, instructions: nil, betas: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(inputs:, model:, instructions: nil, betas: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/anthropic/models/beta/dream_create_params.rb', line 33
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
31 |
# File 'lib/anthropic/models/beta/dream_create_params.rb', line 31 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#inputs ⇒ Array<Anthropic::Models::Beta::BetaDreamMemoryStoreInput, Anthropic::Models::Beta::BetaDreamSessionsInput>
14 |
# File 'lib/anthropic/models/beta/dream_create_params.rb', line 14 required :inputs, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::Beta::BetaDreamInput] } |
#instructions ⇒ String?
25 |
# File 'lib/anthropic/models/beta/dream_create_params.rb', line 25 optional :instructions, String, nil?: true |
#model ⇒ String, Anthropic::Models::Beta::BetaDreamModelConfigParam
Model identifier and configuration applied to every pipeline stage.
20 |
# File 'lib/anthropic/models/beta/dream_create_params.rb', line 20 required :model, union: -> { Anthropic::Beta::DreamCreateParams::Model } |
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/anthropic/models/beta/dream_create_params.rbs', line 37
def to_hash: -> {
|