Class: Anthropic::Models::Beta::Environments::BetaSessionWorkData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Environments::BetaSessionWorkData
- Defined in:
- lib/anthropic/models/beta/environments/beta_session_work_data.rb
Instance Attribute Summary collapse
-
#id ⇒ String
Session identifier (e.g., ‘session_…’).
-
#type ⇒ Symbol, :session
Type of work data.
Instance Method Summary collapse
-
#initialize(id:, type: :session) ⇒ Object
constructor
Work data for session work items.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, type: :session) ⇒ Object
Work data for session work items.
This resource type is used when work represents a session that needs to be executed in a self-hosted environment.
|
|
# File 'lib/anthropic/models/beta/environments/beta_session_work_data.rb', line 20
|
Instance Attribute Details
#id ⇒ String
Session identifier (e.g., ‘session_…’)
12 |
# File 'lib/anthropic/models/beta/environments/beta_session_work_data.rb', line 12 required :id, String |
#type ⇒ Symbol, :session
Type of work data
18 |
# File 'lib/anthropic/models/beta/environments/beta_session_work_data.rb', line 18 required :type, const: :session |