Class: Anthropic::Models::Beta::Environments::WorkPollParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Environments::WorkPollParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/environments/work_poll_params.rb
Overview
Instance Attribute Summary collapse
-
#anthropic_worker_id ⇒ String?
Unique identifier for the specific worker polling, used to track aggregated environment-level work metrics in Console.
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#block_ms ⇒ Integer?
How long to wait for work to arrive before returning.
- #environment_id ⇒ String
-
#reclaim_older_than_ms ⇒ Integer?
Reclaim unacknowledged work items older than this many milliseconds.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(environment_id:, block_ms: nil, reclaim_older_than_ms: nil, betas: nil, anthropic_worker_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WorkPollParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(environment_id:, block_ms: nil, reclaim_older_than_ms: nil, betas: nil, anthropic_worker_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Environments::WorkPollParams for more details.
|
|
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 45
|
Instance Attribute Details
#anthropic_worker_id ⇒ String?
Unique identifier for the specific worker polling, used to track aggregated environment-level work metrics in Console
43 |
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 43 optional :anthropic_worker_id, String |
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
36 |
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 36 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#block_ms ⇒ Integer?
How long to wait for work to arrive before returning. Must be 1-999 in milliseconds. Defaults to non-blocking (returns immediately if no work is available).
23 |
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 23 optional :block_ms, Integer, nil?: true |
#environment_id ⇒ String
15 |
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 15 required :environment_id, String |
#reclaim_older_than_ms ⇒ Integer?
Reclaim unacknowledged work items older than this many milliseconds. If omitted, uses the default (5000ms).
30 |
# File 'lib/anthropic/models/beta/environments/work_poll_params.rb', line 30 optional :reclaim_older_than_ms, Integer, nil?: true |