Class: Anthropic::Models::Beta::FileUploadParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::FileUploadParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/file_upload_params.rb,
sig/anthropic/models/beta/file_upload_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#expires_in_seconds ⇒ Integer?
Seconds from upload until the file expires and its bytes become permanently unavailable.
-
#file ⇒ Pathname, ...
The file to upload.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(file:, expires_in_seconds: nil, betas: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FileUploadParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file:, expires_in_seconds: nil, betas: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::FileUploadParams for more details.
|
|
# File 'lib/anthropic/models/beta/file_upload_params.rb', line 30
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
28 |
# File 'lib/anthropic/models/beta/file_upload_params.rb', line 28 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#expires_in_seconds ⇒ Integer?
Seconds from upload until the file expires and its bytes become permanently unavailable. Must be between 3600 (one hour) and 7776000 (ninety days).
22 |
# File 'lib/anthropic/models/beta/file_upload_params.rb', line 22 optional :expires_in_seconds, Integer |
#file ⇒ Pathname, ...
The file to upload
15 |
# File 'lib/anthropic/models/beta/file_upload_params.rb', line 15 required :file, Anthropic::Internal::Type::FileInput |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/anthropic/models/beta/file_upload_params.rbs', line 35
def to_hash: -> {
|