Module: Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryListItem
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_list_item.rb,
sig/anthropic/models/beta/memory_stores/beta_managed_agents_memory_list_item.rbs
Overview
One item in a List memories
response: either a memory object or, when depth is set, a memory_prefix
rollup marker.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemory, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemory, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemory, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryListItem for more details.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_list_item.rb', line 57 def self.new(type:, **args) case type.to_sym when :memory Anthropic::Beta::MemoryStores::BetaManagedAgentsMemory.new(**args) when :memory_prefix Anthropic::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemory, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix)
|
|
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_list_item.rb', line 23
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::MemoryStores::beta_managed_agents_memory_list_item]
12 |
# File 'sig/anthropic/models/beta/memory_stores/beta_managed_agents_memory_list_item.rbs', line 12
def self?.variants: -> ::Array[Anthropic::Models::Beta::MemoryStores::beta_managed_agents_memory_list_item]
|