Class: Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix
- Defined in:
- lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_prefix.rb
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#path ⇒ String
The rolled-up path prefix, including a trailing ‘/` (e.g. `/projects/foo/`).
- #type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix::Type
Instance Method Summary collapse
-
#initialize(path:, type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsMemoryPrefix for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(path:, type:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix for more details.
A rolled-up directory marker returned by [List memories](/en/api/beta/memory_stores/memories/list) when ‘depth` is set. Indicates that one or more memories exist deeper than the requested depth under this prefix. This is a list-time rollup, not a stored resource; it has no ID and no lifecycle. Each prefix counts toward the page `limit` and interleaves with `memory` items in path order.
|
|
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_prefix.rb', line 21
|
Instance Attribute Details
#path ⇒ String
The rolled-up path prefix, including a trailing ‘/` (e.g. `/projects/foo/`). Pass this value as `path_prefix` on a subsequent list call to drill into the directory.
14 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_prefix.rb', line 14 required :path, String |
#type ⇒ Symbol, Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix::Type
19 |
# File 'lib/anthropic/models/beta/memory_stores/beta_managed_agents_memory_prefix.rb', line 19 required :type, enum: -> { Anthropic::Beta::MemoryStores::BetaManagedAgentsMemoryPrefix::Type } |