Class: Anthropic::Models::Beta::MemoryStores::MemoryUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::MemoryStores::MemoryUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/memory_stores/memory_update_params.rb
Overview
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#content ⇒ String?
New UTF-8 text content for the memory.
- #memory_id ⇒ String
- #memory_store_id ⇒ String
-
#path ⇒ String?
New path for the memory (a rename).
-
#precondition ⇒ Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsPrecondition?
Optimistic-concurrency precondition: the update applies only if the memory’s stored ‘content_sha256` equals the supplied value.
-
#view ⇒ Symbol, ...
Query parameter for view.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(memory_store_id:, memory_id:, view: nil, content: nil, path: nil, precondition: nil, betas: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MemoryUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(memory_store_id:, memory_id:, view: nil, content: nil, path: nil, precondition: nil, betas: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::MemoryStores::MemoryUpdateParams for more details.
|
|
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 62
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
60 |
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 60 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#content ⇒ String?
New UTF-8 text content for the memory. Maximum 100 kB (102,400 bytes). Omit to leave the content unchanged (e.g., for a rename-only update).
33 |
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 33 optional :content, String, nil?: true |
#memory_id ⇒ String
20 |
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 20 required :memory_id, String |
#memory_store_id ⇒ String
15 |
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 15 required :memory_store_id, String |
#path ⇒ String?
New path for the memory (a rename). Must start with ‘/`, contain at least one non-empty segment, and be at most 1,024 bytes. Must not contain empty segments, `.` or `..` segments, control or format characters, and must be NFC-normalized. Paths are case-sensitive. The memory’s ‘id` is preserved across renames. Omit to leave the path unchanged.
43 |
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 43 optional :path, String, nil?: true |
#precondition ⇒ Anthropic::Models::Beta::MemoryStores::BetaManagedAgentsPrecondition?
Optimistic-concurrency precondition: the update applies only if the memory’s stored ‘content_sha256` equals the supplied value. On mismatch, the request returns `memory_precondition_failed_error` (HTTP 409); re-read the memory and retry against the fresh state. If the precondition fails but the stored state already exactly matches the requested `content` and `path`, the server returns 200 instead of 409.
54 |
# File 'lib/anthropic/models/beta/memory_stores/memory_update_params.rb', line 54 optional :precondition, -> { Anthropic::Beta::MemoryStores::BetaManagedAgentsPrecondition } |