Class: Anthropic::Models::Beta::Organization::BetaOrganizationInvite
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::BetaOrganizationInvite
- Defined in:
- lib/anthropic/models/beta/organization/beta_organization_invite.rb,
sig/anthropic/models/beta/organization/beta_organization_invite.rbs
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#accepted_at ⇒ Time?
RFC 3339 datetime string indicating when the Invite was accepted, or null.
-
#email ⇒ String
Email of the User being invited.
-
#expires_at ⇒ Time
RFC 3339 datetime string indicating when the Invite expires.
-
#id ⇒ String
ID of the Invite.
-
#invited_at ⇒ Time
RFC 3339 datetime string indicating when the Invite was created.
-
#rbac_group_ids ⇒ Array<String>
RBAC group IDs recorded on the Invite (Claude Enterprise organizations), to be assigned to the User when the Invite is accepted.
-
#role ⇒ Symbol, Anthropic::Models::Beta::BetaOrganizationRole
Organization role of the User.
-
#status ⇒ Symbol, Anthropic::Models::Beta::Organization::BetaOrganizationInvite::Status
Status of the Invite.
-
#type ⇒ Symbol, :invite
Object type.
Instance Method Summary collapse
-
#initialize(id:, accepted_at:, email:, expires_at:, invited_at:, rbac_group_ids:, role:, status:, type: :invite) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaOrganizationInvite for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, accepted_at:, email:, expires_at:, invited_at:, rbac_group_ids:, role:, status:, type: :invite) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaOrganizationInvite for more details.
|
|
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 66
|
Instance Attribute Details
#accepted_at ⇒ Time?
RFC 3339 datetime string indicating when the Invite was accepted, or null.
19 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 19 required :accepted_at, Time, nil?: true |
#email ⇒ String
Email of the User being invited.
25 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 25 required :email, String |
#expires_at ⇒ Time
RFC 3339 datetime string indicating when the Invite expires.
31 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 31 required :expires_at, Time |
#id ⇒ String
ID of the Invite.
13 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 13 required :id, String |
#invited_at ⇒ Time
RFC 3339 datetime string indicating when the Invite was created.
37 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 37 required :invited_at, Time |
#rbac_group_ids ⇒ Array<String>
RBAC group IDs recorded on the Invite (Claude Enterprise organizations), to be
assigned to the User when the Invite is accepted. [] when none.
44 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 44 required :rbac_group_ids, Anthropic::Internal::Type::ArrayOf[String] |
#role ⇒ Symbol, Anthropic::Models::Beta::BetaOrganizationRole
Organization role of the User.
50 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 50 required :role, enum: -> { Anthropic::Beta::BetaOrganizationRole } |
#status ⇒ Symbol, Anthropic::Models::Beta::Organization::BetaOrganizationInvite::Status
Status of the Invite.
56 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 56 required :status, enum: -> { Anthropic::Beta::Organization::BetaOrganizationInvite::Status } |
#type ⇒ Symbol, :invite
Object type.
For Invites, this is always "invite".
64 |
# File 'lib/anthropic/models/beta/organization/beta_organization_invite.rb', line 64 required :type, const: :invite |
Instance Method Details
#to_hash ⇒ {
49 |
# File 'sig/anthropic/models/beta/organization/beta_organization_invite.rbs', line 49
def to_hash: -> {
|