Class: Anthropic::Models::Beta::Organization::BetaOrganizationUser

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/beta_organization_user.rb,
sig/anthropic/models/beta/organization/beta_organization_user.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Users#retrieve

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, added_at:, email:, name:, role:, type: :user) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaOrganizationUser for more details.

Parameters:

  • id (String)

    ID of the User.

  • added_at (Time)

    RFC 3339 datetime string indicating when the User joined the Organization.

  • email (String)

    Email of the User.

  • name (String)

    Name of the User.

  • role (Symbol, Anthropic::Models::Beta::BetaOrganizationRole)

    Organization role of the User.

  • type (Symbol, :user) (defaults to: :user)

    Object type.



# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 47

Instance Attribute Details

#added_atTime

RFC 3339 datetime string indicating when the User joined the Organization.

Parameters:

  • value (Time)

Returns:

  • (Time)


19
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 19

required :added_at, Time

#emailString

Email of the User.

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 25

required :email, String

#idString

ID of the User.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 13

required :id, String

#nameString

Name of the User.

Parameters:

  • value (String)

Returns:

  • (String)


31
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 31

required :name, String

#roleSymbol, Anthropic::Models::Beta::BetaOrganizationRole

Organization role of the User.

Parameters:

  • value (Anthropic::Models::Beta::beta_organization_role)

Returns:



37
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 37

required :role, enum: -> { Anthropic::Beta::BetaOrganizationRole }

#typeSymbol, :user

Object type.

For Users, this is always "user".

Parameters:

  • value (:user)

Returns:

  • (Symbol, :user)


45
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 45

required :type, const: :user

Instance Method Details

#to_hash{

Returns:

  • ({)


37
# File 'sig/anthropic/models/beta/organization/beta_organization_user.rbs', line 37

def to_hash: -> {