Class: Anthropic::Models::Beta::Organization::BetaOrganizationUser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::BetaOrganizationUser
- Defined in:
- lib/anthropic/models/beta/organization/beta_organization_user.rb,
sig/anthropic/models/beta/organization/beta_organization_user.rbs
Overview
Instance Attribute Summary collapse
-
#added_at ⇒ Time
RFC 3339 datetime string indicating when the User joined the Organization.
-
#email ⇒ String
Email of the User.
-
#id ⇒ String
ID of the User.
-
#name ⇒ String
Name of the User.
-
#role ⇒ Symbol, Anthropic::Models::Beta::BetaOrganizationRole
Organization role of the User.
-
#type ⇒ Symbol, :user
Object type.
Instance Method Summary collapse
-
#initialize(id:, added_at:, email:, name:, role:, type: :user) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaOrganizationUser for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, added_at:, email:, name:, role:, type: :user) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaOrganizationUser for more details.
|
|
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 47
|
Instance Attribute Details
#added_at ⇒ Time
RFC 3339 datetime string indicating when the User joined the Organization.
19 |
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 19 required :added_at, Time |
#email ⇒ String
Email of the User.
25 |
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 25 required :email, String |
#id ⇒ String
ID of the User.
13 |
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 13 required :id, String |
#name ⇒ String
Name of the User.
31 |
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 31 required :name, String |
#role ⇒ Symbol, Anthropic::Models::Beta::BetaOrganizationRole
Organization role of the User.
37 |
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 37 required :role, enum: -> { Anthropic::Beta::BetaOrganizationRole } |
#type ⇒ Symbol, :user
Object type.
For Users, this is always "user".
45 |
# File 'lib/anthropic/models/beta/organization/beta_organization_user.rb', line 45 required :type, const: :user |
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/anthropic/models/beta/organization/beta_organization_user.rbs', line 37
def to_hash: -> {
|