Class: Anthropic::Models::Beta::Organization::BetaServiceAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::BetaServiceAccount
- Defined in:
- lib/anthropic/models/beta/organization/beta_service_account.rb,
sig/anthropic/models/beta/organization/beta_service_account.rbs
Overview
Defined Under Namespace
Modules: OrganizationRole
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
If set, this service account is archived.
-
#archived_by_actor_id ⇒ String?
Tagged ID (
user_/svac_) of the actor that archived this service account. -
#created_at ⇒ Time
When this service account was created.
-
#created_by_actor_id ⇒ String?
Tagged ID (
user_/svac_) of the actor that created this service account. -
#description ⇒ String?
Optional free-text description.
-
#id ⇒ String
Tagged ID of the service account.
-
#name ⇒ String
Admin-chosen slug identifier.
-
#organization_role ⇒ Symbol, Anthropic::Models::Beta::Organization::BetaServiceAccount::OrganizationRole
Org-level role.
- #type ⇒ Symbol, :service_account
-
#updated_at ⇒ Time
When this service account was last updated.
-
#updated_by_actor_id ⇒ String?
Tagged ID (
user_/svac_) of the actor that last updated this service account.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, archived_by_actor_id:, created_at:, created_by_actor_id:, description:, name:, organization_role:, updated_at:, updated_by_actor_id:, type: :service_account) ⇒ Object
constructor
Named non-human identity within the caller's organization.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, archived_by_actor_id:, created_at:, created_by_actor_id:, description:, name:, organization_role:, updated_at:, updated_by_actor_id:, type: :service_account) ⇒ Object
Named non-human identity within the caller's organization.
A service account is a pure identity: name + org. Authorization lives on whatever references it (federation rules).
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaServiceAccount for more details.
|
|
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 78
|
Instance Attribute Details
#archived_at ⇒ Time?
If set, this service account is archived.
19 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 19 required :archived_at, Time, nil?: true |
#archived_by_actor_id ⇒ String?
Tagged ID (user_/svac_) of the actor that archived this service account.
25 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 25 required :archived_by_actor_id, String, nil?: true |
#created_at ⇒ Time
When this service account was created.
31 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 31 required :created_at, Time |
#created_by_actor_id ⇒ String?
Tagged ID (user_/svac_) of the actor that created this service account.
37 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 37 required :created_by_actor_id, String, nil?: true |
#description ⇒ String?
Optional free-text description.
43 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 43 required :description, String, nil?: true |
#id ⇒ String
Tagged ID of the service account.
13 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 13 required :id, String |
#name ⇒ String
Admin-chosen slug identifier.
49 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 49 required :name, String |
#organization_role ⇒ Symbol, Anthropic::Models::Beta::Organization::BetaServiceAccount::OrganizationRole
Org-level role. A federation rule may only be created or retargeted to grant
org:admin scope when this is admin. A rule granting org:admin whose target
is later demoted to developer is rejected at token exchange. Rules granting
org:admin are managed in the Console.
58 59 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 58 required :organization_role, enum: -> { Anthropic::Beta::Organization::BetaServiceAccount::OrganizationRole } |
#type ⇒ Symbol, :service_account
64 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 64 required :type, const: :service_account |
#updated_at ⇒ Time
When this service account was last updated.
70 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 70 required :updated_at, Time |
#updated_by_actor_id ⇒ String?
Tagged ID (user_/svac_) of the actor that last updated this service account.
76 |
# File 'lib/anthropic/models/beta/organization/beta_service_account.rb', line 76 required :updated_by_actor_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
57 |
# File 'sig/anthropic/models/beta/organization/beta_service_account.rbs', line 57
def to_hash: -> {
|