Class: Anthropic::Models::Beta::Organization::BetaWorkspace

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/anthropic/models/beta/organization/beta_workspace.rb,
sig/anthropic/models/beta/organization/beta_workspace.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Workspaces#create

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_at:, compartment_id:, created_at:, data_residency:, display_color:, external_key_id:, name:, tags:, type: :workspace) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaWorkspace for more details.

Parameters:

  • id (String)

    ID of the Workspace.

  • archived_at (Time, nil)

    RFC 3339 datetime string indicating when the Workspace was archived, or null i

  • compartment_id (String)

    Identifier for this Workspace's encryption compartment. When you configure a

  • created_at (Time)

    RFC 3339 datetime string indicating when the Workspace was created.

  • data_residency (Anthropic::Models::Beta::Organization::BetaDataResidency)

    Data residency configuration.

  • display_color (String)

    Hex color code representing the Workspace in the Anthropic Console.

  • external_key_id (String, nil)

    ID of the customer-managed encryption key (CMEK) configuration to use for this

  • name (String)

    Name of the Workspace.

  • tags (Hash{Symbol=>String})

    User-defined tags as string key-value pairs. Keys may not begin with anthropic

  • type (Symbol, :workspace) (defaults to: :workspace)

    Object type.



# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 85

Instance Attribute Details

#archived_atTime?

RFC 3339 datetime string indicating when the Workspace was archived, or null if the Workspace is not archived.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


20
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 20

required :archived_at, Time, nil?: true

#compartment_idString

Identifier for this Workspace's encryption compartment. When you configure a customer-managed encryption key (CMEK) on AWS, reference this value in your KMS key-policy condition so the key is scoped to this compartment. On GCP and Azure, Anthropic enforces the compartment binding automatically; you do not need to reference this value in your key configuration. See the CMEK integration guide for the required key configuration, including the value used during key validation.

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 32

required :compartment_id, String

#created_atTime

RFC 3339 datetime string indicating when the Workspace was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


38
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 38

required :created_at, Time

#data_residencyAnthropic::Models::Beta::Organization::BetaDataResidency

Data residency configuration.

Parameters:

  • value (Anthropic::Beta::Organization::BetaDataResidency)

Returns:



44
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 44

required :data_residency, -> { Anthropic::Beta::Organization::BetaDataResidency }

#display_colorString

Hex color code representing the Workspace in the Anthropic Console.

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 50

required :display_color, String

#external_key_idString?

ID of the customer-managed encryption key (CMEK) configuration to use for this Workspace. Setting this field requires CMEK to be enabled for your organization. When set, data stored for this Workspace is encrypted with the referenced key. Create key configurations with the External Keys API. This field is write-once: once a key is attached to a Workspace it cannot be detached or replaced. To rotate key material, rotate the underlying key on your cloud KMS; the external_key_id stays the same.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


62
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 62

required :external_key_id, String, nil?: true

#idString

ID of the Workspace.

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 13

required :id, String

#nameString

Name of the Workspace.

Parameters:

  • value (String)

Returns:

  • (String)


68
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 68

required :name, String

#tagsHash{Symbol=>String}

User-defined tags as string key-value pairs. Keys may not begin with anthropic.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


75
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 75

required :tags, Anthropic::Internal::Type::HashOf[String]

#typeSymbol, :workspace

Object type.

For Workspaces, this is always "workspace".

Parameters:

  • value (:workspace)

Returns:

  • (Symbol, :workspace)


83
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 83

required :type, const: :workspace

Instance Method Details

#to_hash{

Returns:

  • ({)


53
# File 'sig/anthropic/models/beta/organization/beta_workspace.rbs', line 53

def to_hash: -> {