Class: Anthropic::Models::Beta::Organization::BetaWorkspace
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::BetaWorkspace
- Defined in:
- lib/anthropic/models/beta/organization/beta_workspace.rb,
sig/anthropic/models/beta/organization/beta_workspace.rbs
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
RFC 3339 datetime string indicating when the Workspace was archived, or
nullif the Workspace is not archived. -
#compartment_id ⇒ String
Identifier for this Workspace's encryption compartment.
-
#created_at ⇒ Time
RFC 3339 datetime string indicating when the Workspace was created.
-
#data_residency ⇒ Anthropic::Models::Beta::Organization::BetaDataResidency
Data residency configuration.
-
#display_color ⇒ String
Hex color code representing the Workspace in the Anthropic Console.
-
#external_key_id ⇒ String?
ID of the customer-managed encryption key (CMEK) configuration to use for this Workspace.
-
#id ⇒ String
ID of the Workspace.
-
#name ⇒ String
Name of the Workspace.
-
#tags ⇒ Hash{Symbol=>String}
User-defined tags as string key-value pairs.
-
#type ⇒ Symbol, :workspace
Object type.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, compartment_id:, created_at:, data_residency:, display_color:, external_key_id:, name:, tags:, type: :workspace) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaWorkspace for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, compartment_id:, created_at:, data_residency:, display_color:, external_key_id:, name:, tags:, type: :workspace) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::BetaWorkspace for more details.
|
|
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 85
|
Instance Attribute Details
#archived_at ⇒ Time?
RFC 3339 datetime string indicating when the Workspace was archived, or null
if the Workspace is not archived.
20 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 20 required :archived_at, Time, nil?: true |
#compartment_id ⇒ String
Identifier for this Workspace's encryption compartment. When you configure a customer-managed encryption key (CMEK) on AWS, reference this value in your KMS key-policy condition so the key is scoped to this compartment. On GCP and Azure, Anthropic enforces the compartment binding automatically; you do not need to reference this value in your key configuration. See the CMEK integration guide for the required key configuration, including the value used during key validation.
32 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 32 required :compartment_id, String |
#created_at ⇒ Time
RFC 3339 datetime string indicating when the Workspace was created.
38 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 38 required :created_at, Time |
#data_residency ⇒ Anthropic::Models::Beta::Organization::BetaDataResidency
Data residency configuration.
44 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 44 required :data_residency, -> { Anthropic::Beta::Organization::BetaDataResidency } |
#display_color ⇒ String
Hex color code representing the Workspace in the Anthropic Console.
50 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 50 required :display_color, String |
#external_key_id ⇒ String?
ID of the customer-managed encryption key (CMEK) configuration to use for this
Workspace. Setting this field requires CMEK to be enabled for your organization.
When set, data stored for this Workspace is encrypted with the referenced key.
Create key configurations with the External Keys API. This field is write-once:
once a key is attached to a Workspace it cannot be detached or replaced. To
rotate key material, rotate the underlying key on your cloud KMS; the
external_key_id stays the same.
62 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 62 required :external_key_id, String, nil?: true |
#id ⇒ String
ID of the Workspace.
13 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 13 required :id, String |
#name ⇒ String
Name of the Workspace.
68 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 68 required :name, String |
#tags ⇒ Hash{Symbol=>String}
User-defined tags as string key-value pairs. Keys may not begin with
anthropic.
75 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 75 required :tags, Anthropic::Internal::Type::HashOf[String] |
#type ⇒ Symbol, :workspace
Object type.
For Workspaces, this is always "workspace".
83 |
# File 'lib/anthropic/models/beta/organization/beta_workspace.rb', line 83 required :type, const: :workspace |
Instance Method Details
#to_hash ⇒ {
53 |
# File 'sig/anthropic/models/beta/organization/beta_workspace.rbs', line 53
def to_hash: -> {
|