Class: Anthropic::Models::Beta::Organization::Federation::BetaFederationRuleWorkspace
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::Federation::BetaFederationRuleWorkspace
- Defined in:
- lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb,
sig/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ Time
When this workspace was enabled for the rule.
-
#created_by_actor_id ⇒ String?
Tagged ID (
user_...orsvac_...) of the actor that enabled this workspace for the rule, if known. -
#federation_rule_id ⇒ String
Tagged ID of the federation rule.
- #type ⇒ Symbol, :federation_rule_workspace
-
#workspace_id ⇒ String
Tagged ID of the workspace this rule is enabled for.
-
#workspace_name ⇒ String?
Workspace display name.
Instance Method Summary collapse
-
#initialize(created_at:, created_by_actor_id:, federation_rule_id:, workspace_id:, workspace_name:, type: :federation_rule_workspace) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaFederationRuleWorkspace for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, created_by_actor_id:, federation_rule_id:, workspace_id:, workspace_name:, type: :federation_rule_workspace) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::Federation::BetaFederationRuleWorkspace for more details.
|
|
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 45
|
Instance Attribute Details
#created_at ⇒ Time
When this workspace was enabled for the rule.
13 |
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 13 required :created_at, Time |
#created_by_actor_id ⇒ String?
Tagged ID (user_... or svac_...) of the actor that enabled this workspace
for the rule, if known.
20 |
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 20 required :created_by_actor_id, String, nil?: true |
#federation_rule_id ⇒ String
Tagged ID of the federation rule.
26 |
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 26 required :federation_rule_id, String |
#type ⇒ Symbol, :federation_rule_workspace
31 |
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 31 required :type, const: :federation_rule_workspace |
#workspace_id ⇒ String
Tagged ID of the workspace this rule is enabled for.
37 |
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 37 required :workspace_id, String |
#workspace_name ⇒ String?
Workspace display name. Populated when listing; null in the enable response.
43 |
# File 'lib/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rb', line 43 required :workspace_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/anthropic/models/beta/organization/federation/beta_federation_rule_workspace.rbs', line 38
def to_hash: -> {
|