Class: Anthropic::Models::Beta::Organization::Federation::Rules::WorkspaceRemoveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::Federation::Rules::WorkspaceRemoveResponse
- Defined in:
- lib/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rb,
sig/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rbs
Overview
Instance Attribute Summary collapse
-
#federation_rule_id ⇒ String
Tagged ID of the federation rule.
- #type ⇒ Symbol, :federation_rule_workspace_deleted
-
#workspace_id ⇒ String
Tagged ID of the workspace named in the delete request.
Instance Method Summary collapse
- #initialize(federation_rule_id:, workspace_id:, type: :federation_rule_workspace_deleted) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(federation_rule_id:, workspace_id:, type: :federation_rule_workspace_deleted) ⇒ Object
|
|
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rb', line 28
|
Instance Attribute Details
#federation_rule_id ⇒ String
Tagged ID of the federation rule.
15 |
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rb', line 15 required :federation_rule_id, String |
#type ⇒ Symbol, :federation_rule_workspace_deleted
20 |
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rb', line 20 required :type, const: :federation_rule_workspace_deleted |
#workspace_id ⇒ String
Tagged ID of the workspace named in the delete request. Removal is idempotent.
26 |
# File 'lib/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rb', line 26 required :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/anthropic/models/beta/organization/federation/rules/workspace_remove_response.rbs', line 27
def to_hash: -> {
|