Class: Anthropic::Models::Beta::Organization::InviteCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::InviteCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/organization/invite_create_params.rb,
sig/anthropic/models/beta/organization/invite_create_params.rbs
Overview
Defined Under Namespace
Modules: Role
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#email ⇒ String
Email of the User.
-
#rbac_group_ids ⇒ Array<String>?
RBAC group IDs to assign to the User when the Invite is accepted.
-
#role ⇒ Symbol, Anthropic::Models::Beta::Organization::InviteCreateParams::Role
Role for the invited User.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(email:, role:, rbac_group_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InviteCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email:, role:, rbac_group_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::InviteCreateParams for more details.
|
|
# File 'lib/anthropic/models/beta/organization/invite_create_params.rb', line 37
|
Instance Attribute Details
#email ⇒ String
Email of the User.
16 |
# File 'lib/anthropic/models/beta/organization/invite_create_params.rb', line 16 required :email, String |
#rbac_group_ids ⇒ Array<String>?
RBAC group IDs to assign to the User when the Invite is accepted. A non-empty
array is accepted only for a Claude Enterprise organization with RBAC groups,
and requires the key to carry the write:rbac_groups scope.
35 |
# File 'lib/anthropic/models/beta/organization/invite_create_params.rb', line 35 optional :rbac_group_ids, Anthropic::Internal::Type::ArrayOf[String] |
#role ⇒ Symbol, Anthropic::Models::Beta::Organization::InviteCreateParams::Role
Role for the invited User.
The accepted values depend on the organization type. Console and API
organizations accept user, developer, billing, and claude_code_user;
admin cannot be assigned through the API. Claude Enterprise organizations
accept user and managed.
27 |
# File 'lib/anthropic/models/beta/organization/invite_create_params.rb', line 27 required :role, enum: -> { Anthropic::Beta::Organization::InviteCreateParams::Role } |
Instance Method Details
#to_hash ⇒ {
32 |
# File 'sig/anthropic/models/beta/organization/invite_create_params.rbs', line 32
def to_hash: -> {
|