Class: Anthropic::Models::Beta::Organization::InviteListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::InviteListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/organization/invite_list_params.rb,
sig/anthropic/models/beta/organization/invite_list_params.rbs
Overview
Defined Under Namespace
Modules: Status
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Anthropic
Instance Attribute Summary collapse
-
#after_id ⇒ String?
ID of the object to use as a cursor for pagination.
-
#before_id ⇒ String?
ID of the object to use as a cursor for pagination.
-
#email ⇒ String?
Filter by the email address the Invite was sent to.
-
#limit ⇒ Integer?
Number of items to return per page.
-
#roles ⇒ Array<String>?
Filter to items whose
roleequals one of the supplied values. -
#statuses ⇒ Array<Symbol, Anthropic::Models::Beta::Organization::InviteListParams::Status>?
Filter by Invite status.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
46 |
# File 'sig/anthropic/models/beta/organization/invite_list_params.rbs', line 46
def initialize: (
|
Instance Attribute Details
#after_id ⇒ String?
ID of the object to use as a cursor for pagination. When provided, returns the page of results immediately after this object.
17 |
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 17 optional :after_id, String |
#before_id ⇒ String?
ID of the object to use as a cursor for pagination. When provided, returns the page of results immediately before this object.
24 |
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 24 optional :before_id, String |
#email ⇒ String?
Filter by the email address the Invite was sent to. Matches the same way as the
Users list's email filter (normalized, case-insensitive).
31 |
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 31 optional :email, String |
#limit ⇒ Integer?
Number of items to return per page.
Defaults to 20. Ranges from 1 to 1000.
39 |
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 39 optional :limit, Integer |
#roles ⇒ Array<String>?
Filter to items whose role equals one of the supplied values. Repeatable;
values are OR'ed together.
Accepted values depend on the organization type: Console and API organizations
accept user, developer, billing, admin, and claude_code_user; Claude
Enterprise organizations accept user, owner, primary_owner,
membership_admin, and managed.
51 |
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 51 optional :roles, Anthropic::Internal::Type::ArrayOf[String] |
#statuses ⇒ Array<Symbol, Anthropic::Models::Beta::Organization::InviteListParams::Status>?
Filter by Invite status. Repeatable; values are OR'ed together. Omit to return
pending, accepted, and expired Invites alike.
58 59 |
# File 'lib/anthropic/models/beta/organization/invite_list_params.rb', line 58 optional :statuses, -> { Anthropic::Internal::Type::ArrayOf[enum: Anthropic::Beta::Organization::InviteListParams::Status] } |
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/anthropic/models/beta/organization/invite_list_params.rbs', line 56
def to_hash: -> {
|