Class: Anthropic::Models::Beta::Organization::WorkspaceUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/organization/workspace_update_params.rb,
sig/anthropic/models/beta/organization/workspace_update_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::Organization::Workspaces#update

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(workspace_id:, data_residency: nil, display_color: nil, external_key_id: nil, name: nil, tags: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::WorkspaceUpdateParams for more details.

Parameters:

  • workspace_id (String)
  • data_residency (Anthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig, nil) (defaults to: nil)

    Data residency configuration for the workspace.

  • display_color (String) (defaults to: nil)

    Hex color code representing the Workspace in the Anthropic Console.

  • external_key_id (String) (defaults to: nil)

    ID of the customer-managed encryption key (CMEK) configuration to use for this

  • name (String) (defaults to: nil)

    Name of the Workspace.

  • tags (Hash{Symbol=>String, nil}, nil) (defaults to: nil)

    User-defined tags as string key-value pairs. Keys may not begin with anthropic

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 58

Instance Attribute Details

#data_residencyAnthropic::Models::Beta::Organization::BetaDataResidencyUpdateConfig?

Data residency configuration for the workspace.

Parameters:

  • value (Anthropic::Beta::Organization::BetaDataResidencyUpdateConfig, nil)

Returns:



21
22
23
24
25
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 21

optional :data_residency,
-> {
  Anthropic::Beta::Organization::BetaDataResidencyUpdateConfig
},
nil?: true

#display_colorString?

Hex color code representing the Workspace in the Anthropic Console.

Parameters:

  • (String)

Returns:

  • (String, nil)


31
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 31

optional :display_color, String

#external_key_idString?

ID of the customer-managed encryption key (CMEK) configuration to use for this Workspace. Setting this field requires CMEK to be enabled for your organization. When set, data stored for this Workspace is encrypted with the referenced key. Create key configurations with the External Keys API. This field is write-once: once a key is attached to a Workspace it cannot be detached or replaced. To rotate key material, rotate the underlying key on your cloud KMS; the external_key_id stays the same.

Parameters:

  • (String)

Returns:

  • (String, nil)


43
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 43

optional :external_key_id, String

#nameString?

Name of the Workspace.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 49

optional :name, String

#tagsHash{Symbol=>String, nil}?

User-defined tags as string key-value pairs. Keys may not begin with anthropic.

Parameters:

  • value (::Hash[Symbol, String?], nil)

Returns:

  • (Hash{Symbol=>String, nil}, nil)


56
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 56

optional :tags, Anthropic::Internal::Type::HashOf[String, nil?: true], nil?: true

#workspace_idString

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/anthropic/models/beta/organization/workspace_update_params.rb', line 15

required :workspace_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


48
# File 'sig/anthropic/models/beta/organization/workspace_update_params.rbs', line 48

def to_hash: -> {