Class: Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit
- Defined in:
- lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb,
sig/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rbs
Overview
Defined Under Namespace
Modules: GroupType
Instance Attribute Summary collapse
-
#group_type ⇒ Symbol, Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit::GroupType
The kind of rate-limit group this entry represents.
-
#limits ⇒ Array<Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue>
The limiter values overridden for this group in this workspace.
-
#models ⇒ Array<String>?
Model names this entry's limits apply to, including aliases.
-
#rate_limit_id ⇒ String
The
idof the RateLimit group this override applies to. -
#type ⇒ Symbol, :workspace_rate_limit
Object type.
-
#workspace_id ⇒ String
ID of the Workspace this override applies to.
Instance Method Summary collapse
-
#initialize(group_type:, limits:, models:, rate_limit_id:, workspace_id:, type: :workspace_rate_limit) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaWorkspaceRateLimit for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(group_type:, limits:, models:, rate_limit_id:, workspace_id:, type: :workspace_rate_limit) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit for more details.
`group_
|
|
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 52
|
Instance Attribute Details
#group_type ⇒ Symbol, Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimit::GroupType
The kind of rate-limit group this entry represents. model_group entries apply
to a family of models (listed in models); other values apply to an API-surface
category and have models set to null.
16 17 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 16 required :group_type, enum: -> { Anthropic::Beta::Organization::Workspaces::BetaWorkspaceRateLimit::GroupType } |
#limits ⇒ Array<Anthropic::Models::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue>
The limiter values overridden for this group in this workspace. Limiter types without a workspace override are omitted and inherit the organization value.
24 25 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 24 required :limits, -> { Anthropic::Internal::Type::ArrayOf[Anthropic::Beta::Organization::Workspaces::BetaWorkspaceRateLimitValue] } |
#models ⇒ Array<String>?
Model names this entry's limits apply to, including aliases. null when
group_type is not "model_group".
32 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 32 required :models, Anthropic::Internal::Type::ArrayOf[String], nil?: true |
#rate_limit_id ⇒ String
The id of the RateLimit group this override applies to.
38 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 38 required :rate_limit_id, String |
#type ⇒ Symbol, :workspace_rate_limit
Object type. Always workspace_rate_limit for workspace rate-limit entries.
44 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 44 required :type, const: :workspace_rate_limit |
#workspace_id ⇒ String
ID of the Workspace this override applies to.
50 |
# File 'lib/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rb', line 50 required :workspace_id, String |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/anthropic/models/beta/organization/workspaces/beta_workspace_rate_limit.rbs', line 38
def to_hash: -> {
|