Module: Anthropic::Models::Beta::SessionCreateParams::InitialEvent

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/session_create_params.rb,
sig/anthropic/models/beta/session_create_params.rbs

Overview

An event sent to the session immediately after it is created. Supports user.message and user.define_outcome.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserMessageEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [Array<Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsImageBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock, Anthropic::Models::Beta::Sessions::BetaManagedAgentsRedactedBlock>] :content Array of content blocks for the user message.

    @option args [String] :description What the agent should produce. This is the task specification.

    @option args [Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubricParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubricParams] :rubric Rubric for grading the quality of an outcome.

    @option args [Integer, nil] :max_iterations Eval→revision cycles before giving up. Default 3, max 20.

Returns:

Raises:

  • (ArgumentError)


146
147
148
149
150
151
152
153
154
155
# File 'lib/anthropic/models/beta/session_create_params.rb', line 146

def self.new(type:, **args)
  case type.to_sym
  when :"user.message"
    Anthropic::Beta::Sessions::BetaManagedAgentsUserMessageEventParams.new(**args)
  when :"user.define_outcome"
    Anthropic::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::SessionCreateParams::initial_event]

Returns:

  • (::Array[Anthropic::Models::Beta::SessionCreateParams::initial_event])


104
# File 'sig/anthropic/models/beta/session_create_params.rbs', line 104

def self?.variants: -> ::Array[Anthropic::Models::Beta::SessionCreateParams::initial_event]