Module: Anthropic::Models::Beta::SessionCreateParams::InitialEvent
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/session_create_params.rb,
sig/anthropic/models/beta/session_create_params.rbs
Overview
An event sent to the session immediately after it is created. Supports
user.message and user.define_outcome.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserMessageEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserMessageEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserMessageEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/anthropic/models/beta/session_create_params.rb', line 146 def self.new(type:, **args) case type.to_sym when :"user.message" Anthropic::Beta::Sessions::BetaManagedAgentsUserMessageEventParams.new(**args) when :"user.define_outcome" Anthropic::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserMessageEventParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams)
|
|
# File 'lib/anthropic/models/beta/session_create_params.rb', line 126
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::SessionCreateParams::initial_event]
104 |
# File 'sig/anthropic/models/beta/session_create_params.rbs', line 104
def self?.variants: -> ::Array[Anthropic::Models::Beta::SessionCreateParams::initial_event]
|