Module: Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_document_block.rbs
Overview
Union type for document source variants.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource)
Instance Method Summary collapse
- #self?.variants ⇒ ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::source]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 83 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Beta::Sessions::BetaManagedAgentsBase64DocumentSource.new(**args) when :text Anthropic::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource.new(**args) when :url Anthropic::Beta::Sessions::BetaManagedAgentsURLDocumentSource.new(**args) when :file Anthropic::Beta::Sessions::BetaManagedAgentsFileDocumentSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource)
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_document_block.rb', line 63
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::source]
45 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_document_block.rbs', line 45
def self?.variants: -> ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsDocumentBlock::source]
|