Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsMemoryStoreResource
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsMemoryStoreResource
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access ⇒ Symbol, ...
Access mode for an attached memory store.
-
#description ⇒ String?
Description of the memory store, snapshotted at attach time.
-
#instructions ⇒ String?
Per-attachment guidance for the agent on how to use this store.
-
#memory_store_id ⇒ String
The memory store ID (memstore_…).
-
#mount_path ⇒ String?
Filesystem path where the store is mounted in the session container, e.g.
-
#name ⇒ String?
Display name of the memory store, snapshotted at attach time.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsMemoryStoreResource::Type
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(memory_store_id:, type:, access: nil, description: nil, instructions: nil, mount_path: nil, name: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsMemoryStoreResource for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(memory_store_id:, type:, access: nil, description: nil, instructions: nil, mount_path: nil, name: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsMemoryStoreResource for more details.
A memory store attached to an agent session.
and
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 56
|
Instance Attribute Details
#access ⇒ Symbol, ...
Access mode for an attached memory store.
24 25 26 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 24 optional :access, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsMemoryStoreResource::Access }, nil?: true |
#description ⇒ String?
Description of the memory store, snapshotted at attach time. Rendered into the agent’s system prompt. Empty string when the store has no description.
33 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 33 optional :description, String |
#instructions ⇒ String?
Per-attachment guidance for the agent on how to use this store. Rendered into the memory section of the system prompt. Max 4096 chars.
40 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 40 optional :instructions, String, nil?: true |
#memory_store_id ⇒ String
The memory store ID (memstore_…). Must belong to the caller’s organization and workspace.
13 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 13 required :memory_store_id, String |
#mount_path ⇒ String?
Filesystem path where the store is mounted in the session container, e.g. /mnt/memory/user-preferences. Derived from the store’s name. Output-only.
47 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 47 optional :mount_path, String, nil?: true |
#name ⇒ String?
Display name of the memory store, snapshotted at attach time. Later edits to the store’s name do not propagate to this resource.
54 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 54 optional :name, String, nil?: true |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsMemoryStoreResource::Type
18 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 18 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsMemoryStoreResource::Type } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_memory_store_resource.rb', line 84
|