Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#agent ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadAgent
Resolved ‘agent` definition for a single `session_thread`.
-
#archived_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#id ⇒ String
Unique identifier for this thread.
-
#parent_thread_id ⇒ String?
Parent thread that spawned this thread.
-
#session_id ⇒ String
The session this thread belongs to.
-
#stats ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats?
Timing statistics for a session thread.
-
#status ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatus
SessionThreadStatus enum.
- #type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread::Type
-
#updated_at ⇒ Time
A timestamp in RFC 3339 format.
-
#usage ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadUsage?
Cumulative token usage for a session thread across all turns.
Instance Method Summary collapse
-
#initialize(id:, agent:, archived_at:, created_at:, parent_thread_id:, session_id:, stats:, status:, type:, updated_at:, usage:) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsSessionThread for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, agent:, archived_at:, created_at:, parent_thread_id:, session_id:, stats:, status:, type:, updated_at:, usage:) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread for more details.
An execution thread within a ‘session`. Each session has one primary thread plus zero or more child threads spawned by the coordinator.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 76
|
Instance Attribute Details
#agent ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadAgent
Resolved ‘agent` definition for a single `session_thread`. Snapshot of the agent at thread creation time. The multiagent roster is not repeated here; read it from `Session.agent`.
21 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 21 required :agent, -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadAgent } |
#archived_at ⇒ Time?
A timestamp in RFC 3339 format
27 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 27 required :archived_at, Time, nil?: true |
#created_at ⇒ Time
A timestamp in RFC 3339 format
33 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 33 required :created_at, Time |
#id ⇒ String
Unique identifier for this thread.
13 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 13 required :id, String |
#parent_thread_id ⇒ String?
Parent thread that spawned this thread. Null for the primary thread.
39 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 39 required :parent_thread_id, String, nil?: true |
#session_id ⇒ String
The session this thread belongs to.
45 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 45 required :session_id, String |
#stats ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats?
Timing statistics for a session thread.
51 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 51 required :stats, -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStats }, nil?: true |
#status ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStatus
SessionThreadStatus enum
57 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 57 required :status, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadStatus } |
#type ⇒ Symbol, Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThread::Type
62 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 62 required :type, enum: -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThread::Type } |
#updated_at ⇒ Time
A timestamp in RFC 3339 format
68 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 68 required :updated_at, Time |
#usage ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadUsage?
Cumulative token usage for a session thread across all turns.
74 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread.rb', line 74 required :usage, -> { Anthropic::Beta::Sessions::BetaManagedAgentsSessionThreadUsage }, nil?: true |