Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb
Instance Attribute Summary collapse
-
#active_seconds ⇒ Float?
Cumulative time in seconds the thread spent actively running.
-
#duration_seconds ⇒ Float?
Elapsed time since thread creation in seconds.
-
#startup_seconds ⇒ Float?
Time in seconds for the thread to begin running.
Instance Method Summary collapse
-
#initialize(active_seconds: nil, duration_seconds: nil, startup_seconds: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BetaManagedAgentsSessionThreadStats for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(active_seconds: nil, duration_seconds: nil, startup_seconds: nil) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadStats for more details.
Timing statistics for a session thread.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 29
|
Instance Attribute Details
#active_seconds ⇒ Float?
Cumulative time in seconds the thread spent actively running. Excludes idle time.
13 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 13 optional :active_seconds, Float |
#duration_seconds ⇒ Float?
Elapsed time since thread creation in seconds. For archived threads, frozen at the final update.
20 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 20 optional :duration_seconds, Float |
#startup_seconds ⇒ Float?
Time in seconds for the thread to begin running. Zero for child threads, which start immediately.
27 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_stats.rb', line 27 optional :startup_seconds, Float |