Class: Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadUsage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::BetaManagedAgentsSessionThreadUsage
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_usage.rb
Instance Attribute Summary collapse
-
#cache_creation ⇒ Anthropic::Models::Beta::BetaManagedAgentsCacheCreationUsage?
Prompt-cache creation token usage broken down by cache lifetime.
-
#cache_read_input_tokens ⇒ Integer?
Total tokens read from prompt cache.
-
#input_tokens ⇒ Integer?
Total input tokens consumed across all turns.
-
#output_tokens ⇒ Integer?
Total output tokens generated across all turns.
Instance Method Summary collapse
-
#initialize(cache_creation: nil, cache_read_input_tokens: nil, input_tokens: nil, output_tokens: nil) ⇒ Object
constructor
Cumulative token usage for a session thread across all turns.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(cache_creation: nil, cache_read_input_tokens: nil, input_tokens: nil, output_tokens: nil) ⇒ Object
Cumulative token usage for a session thread across all turns.
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_usage.rb', line 32
|
Instance Attribute Details
#cache_creation ⇒ Anthropic::Models::Beta::BetaManagedAgentsCacheCreationUsage?
Prompt-cache creation token usage broken down by cache lifetime.
12 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_usage.rb', line 12 optional :cache_creation, -> { Anthropic::Beta::BetaManagedAgentsCacheCreationUsage } |
#cache_read_input_tokens ⇒ Integer?
Total tokens read from prompt cache.
18 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_usage.rb', line 18 optional :cache_read_input_tokens, Integer |
#input_tokens ⇒ Integer?
Total input tokens consumed across all turns.
24 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_usage.rb', line 24 optional :input_tokens, Integer |
#output_tokens ⇒ Integer?
Total output tokens generated across all turns.
30 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_session_thread_usage.rb', line 30 optional :output_tokens, Integer |