Module: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::Content

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rbs

Overview

Content block in a tool result. Can be text, image, document, or search_result.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextBlock, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :text The text content.

    @option args [Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64ImageSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLImageSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileImageSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsBase64DocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsPlainTextDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsURLDocumentSource, Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileDocumentSource, String] :source Union type for image source variants.

    @option args [String, nil] :context Additional context about the document for the model.

    @option args [String, nil, String] :title The title of the document.

    @option args [Anthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultCitations] :citations Citation settings for a search result.

    @option args [ArrayAnthropic::Models::Beta::Sessions::BetaManagedAgentsSearchResultContent] :content Array of text content blocks from the search result.

Returns:

Raises:

  • (ArgumentError)


104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rb', line 104

def self.new(type:, **args)
  case type.to_sym
  when :text
    Anthropic::Beta::Sessions::BetaManagedAgentsTextBlock.new(**args)
  when :image
    Anthropic::Beta::Sessions::BetaManagedAgentsImageBlock.new(**args)
  when :document
    Anthropic::Beta::Sessions::BetaManagedAgentsDocumentBlock.new(**args)
  when :search_result
    Anthropic::Beta::Sessions::BetaManagedAgentsSearchResultBlock.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::content]

Returns:

  • (::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::content])


59
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_user_custom_tool_result_event_params.rbs', line 59

def self?.variants: -> ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserCustomToolResultEventParams::content]