Module: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEvent::Rubric
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event.rbs
Overview
Rubric for grading the quality of an outcome.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubric, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubric
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubric, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubric)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubric, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubric
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event.rb', line 102 def self.new(type:, **args) case type.to_sym when :file Anthropic::Beta::Sessions::BetaManagedAgentsFileRubric.new(**args) when :text Anthropic::Beta::Sessions::BetaManagedAgentsTextRubric.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubric, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubric)
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event.rb', line 86
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEvent::rubric]
58 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event.rbs', line 58
def self?.variants: -> ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEvent::rubric]
|