Module: Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams::Rubric
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event_params.rb,
sig/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event_params.rbs
Overview
Rubric for grading the quality of an outcome.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubricParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubricParams
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubricParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubricParams)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubricParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubricParams
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams::Rubric for more details.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event_params.rb', line 79 def self.new(type:, **args) case type.to_sym when :file Anthropic::Beta::Sessions::BetaManagedAgentsFileRubricParams.new(**args) when :text Anthropic::Beta::Sessions::BetaManagedAgentsTextRubricParams.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Beta::Sessions::BetaManagedAgentsFileRubricParams, Anthropic::Models::Beta::Sessions::BetaManagedAgentsTextRubricParams)
|
|
# File 'lib/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event_params.rb', line 59
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams::rubric]
43 |
# File 'sig/anthropic/models/beta/sessions/beta_managed_agents_user_define_outcome_event_params.rbs', line 43
def self?.variants: -> ::Array[Anthropic::Models::Beta::Sessions::BetaManagedAgentsUserDefineOutcomeEventParams::rubric]
|