Class: Anthropic::Models::Beta::Sessions::EventListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Sessions::EventListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/anthropic/models/beta/sessions/event_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
-
#created_at_gt ⇒ Time?
Return events created after this time (exclusive).
-
#created_at_gte ⇒ Time?
Return events created at or after this time (inclusive).
-
#created_at_lt ⇒ Time?
Return events created before this time (exclusive).
-
#created_at_lte ⇒ Time?
Return events created at or before this time (inclusive).
-
#limit ⇒ Integer?
Query parameter for limit.
-
#order ⇒ Symbol, ...
Sort direction for results, ordered by created_at.
-
#page ⇒ String?
Opaque pagination cursor from a previous response’s next_page.
- #session_id ⇒ String
-
#types ⇒ Array<String>?
Filter by event type.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(session_id:, created_at_gt: nil, created_at_gte: nil, created_at_lt: nil, created_at_lte: nil, limit: nil, order: nil, page: nil, types: nil, betas: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(session_id:, created_at_gt: nil, created_at_gte: nil, created_at_lt: nil, created_at_lte: nil, limit: nil, order: nil, page: nil, types: nil, betas: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::Beta::Sessions::EventListParams for more details.
|
|
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 73
|
Instance Attribute Details
#betas ⇒ Array<String, Symbol, Anthropic::Models::AnthropicBeta>?
Optional header to specify the beta version(s) you want to use.
71 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 71 optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] } |
#created_at_gt ⇒ Time?
Return events created after this time (exclusive).
21 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 21 optional :created_at_gt, Time |
#created_at_gte ⇒ Time?
Return events created at or after this time (inclusive).
27 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 27 optional :created_at_gte, Time |
#created_at_lt ⇒ Time?
Return events created before this time (exclusive).
33 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 33 optional :created_at_lt, Time |
#created_at_lte ⇒ Time?
Return events created at or before this time (inclusive).
39 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 39 optional :created_at_lte, Time |
#limit ⇒ Integer?
Query parameter for limit
45 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 45 optional :limit, Integer |
#order ⇒ Symbol, ...
Sort direction for results, ordered by created_at. Defaults to asc (chronological).
52 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 52 optional :order, enum: -> { Anthropic::Beta::Sessions::EventListParams::Order } |
#page ⇒ String?
Opaque pagination cursor from a previous response’s next_page.
58 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 58 optional :page, String |
#session_id ⇒ String
15 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 15 required :session_id, String |
#types ⇒ Array<String>?
Filter by event type. Values match the ‘type` field on returned events (for example, `user.message` or `agent.tool_use`). Omit to return all event types.
65 |
# File 'lib/anthropic/models/beta/sessions/event_list_params.rb', line 65 optional :types, Anthropic::Internal::Type::ArrayOf[String] |