Class: Anthropic::Models::Beta::Tunnels::BetaTunnelCertificate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Beta::Tunnels::BetaTunnelCertificate
- Defined in:
- lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb,
sig/anthropic/models/beta/tunnels/beta_tunnel_certificate.rbs
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#created_at ⇒ Time
A timestamp in RFC 3339 format.
-
#expires_at ⇒ Time?
A timestamp in RFC 3339 format.
-
#fingerprint ⇒ String
Lowercase hex SHA-256 fingerprint of the certificate's DER encoding.
-
#id ⇒ String
Unique identifier for the certificate, prefixed with
tcrt_. -
#tunnel_id ⇒ String
ID of the tunnel the certificate is registered against.
- #type ⇒ Symbol, :tunnel_certificate
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, expires_at:, fingerprint:, tunnel_id:, type: :tunnel_certificate) ⇒ Object
constructor
A CA certificate attached to a tunnel.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, expires_at:, fingerprint:, tunnel_id:, type: :tunnel_certificate) ⇒ Object
A CA certificate attached to a tunnel.
|
|
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 50
|
Instance Attribute Details
#archived_at ⇒ Time?
A timestamp in RFC 3339 format
19 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 19 required :archived_at, Time, nil?: true |
#created_at ⇒ Time
A timestamp in RFC 3339 format
25 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 25 required :created_at, Time |
#expires_at ⇒ Time?
A timestamp in RFC 3339 format
31 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 31 required :expires_at, Time, nil?: true |
#fingerprint ⇒ String
Lowercase hex SHA-256 fingerprint of the certificate's DER encoding.
37 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 37 required :fingerprint, String |
#id ⇒ String
Unique identifier for the certificate, prefixed with tcrt_.
13 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 13 required :id, String |
#tunnel_id ⇒ String
ID of the tunnel the certificate is registered against.
43 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 43 required :tunnel_id, String |
#type ⇒ Symbol, :tunnel_certificate
48 |
# File 'lib/anthropic/models/beta/tunnels/beta_tunnel_certificate.rb', line 48 required :type, const: :tunnel_certificate |
Instance Method Details
#to_hash ⇒ {
41 |
# File 'sig/anthropic/models/beta/tunnels/beta_tunnel_certificate.rbs', line 41
def to_hash: -> {
|