Class: Anthropic::Models::Beta::UserProfileCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/anthropic/models/beta/user_profile_create_params.rb,
sig/anthropic/models/beta/user_profile_create_params.rbs

Overview

See Also:

  • Anthropic::Resources::Beta::UserProfiles#create

Defined Under Namespace

Modules: Relationship

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::Anthropic

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_id: nil, metadata: nil, name: nil, relationship: nil, betas: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Anthropic::Models::Beta::UserProfileCreateParams for more details.

Parameters:

  • external_id (String, nil) (defaults to: nil)

    Platform's own identifier for this user. Not enforced unique. Maximum 255 charac

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Free-form key-value data to attach to this user profile. Maximum 16 keys, with k

  • name (String, nil) (defaults to: nil)

    Display name of the entity this profile represents. Required when relationship i

  • relationship (Symbol, Anthropic::Models::Beta::UserProfileCreateParams::Relationship) (defaults to: nil)

    How the entity behind a user profile relates to the platform that owns the API k

  • betas (Array<String, Symbol, Anthropic::Models::AnthropicBeta>) (defaults to: nil)

    Optional header to specify the beta version(s) you want to use.

  • request_options (Anthropic::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 48

Instance Attribute Details

#betasArray<String, Symbol, Anthropic::Models::AnthropicBeta>?

Optional header to specify the beta version(s) you want to use.

Returns:



46
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 46

optional :betas, -> { Anthropic::Internal::Type::ArrayOf[union: Anthropic::AnthropicBeta] }

#external_idString?

Platform's own identifier for this user. Not enforced unique. Maximum 255 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


16
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 16

optional :external_id, String, nil?: true

#metadataHash{Symbol=>String}?

Free-form key-value data to attach to this user profile. Maximum 16 keys, with keys up to 64 characters and values up to 512 characters. Values must be non-empty strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


24
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 24

optional :metadata, Anthropic::Internal::Type::HashOf[String]

#nameString?

Display name of the entity this profile represents. Required when relationship is resold (the resold-to company's name); optional otherwise. Maximum 255 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 32

optional :name, String, nil?: true

#relationshipSymbol, ...

How the entity behind a user profile relates to the platform that owns the API key. external: an individual end-user of the platform. resold: a company the platform resells Claude access to. internal: the platform's own usage.



40
# File 'lib/anthropic/models/beta/user_profile_create_params.rb', line 40

optional :relationship, enum: -> { Anthropic::Beta::UserProfileCreateParams::Relationship }

Instance Method Details

#to_hash{

Returns:

  • ({)


47
# File 'sig/anthropic/models/beta/user_profile_create_params.rbs', line 47

def to_hash: -> {