Class: Anthropic::Models::BrowserStateTabEntry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::BrowserStateTabEntry
- Defined in:
- lib/anthropic/models/browser_state_tab_entry.rb,
sig/anthropic/models/browser_state_tab_entry.rbs
Instance Attribute Summary collapse
-
#active ⇒ Boolean?
Whether this tab is the active tab after this call.
-
#tab_id ⇒ String
The caller-assigned identifier for this tab, unique within the inventory.
-
#title ⇒ String
The title of the page the tab is showing.
-
#url ⇒ String
The URL of the page the tab is showing.
Instance Method Summary collapse
-
#initialize(tab_id:, title:, url:, active: nil) ⇒ Object
constructor
One open browser tab reported in a
browser_stateblock'stabsinventory. - #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tab_id:, title:, url:, active: nil) ⇒ Object
One open browser tab reported in a browser_state block's tabs inventory.
tab_id is the caller-assigned identifier for the tab; title and url
describe the page the tab is currently showing and may be empty strings (a blank
tab legitimately has both empty). active marks the tab that is active after
this call; whenever tabs is non-empty, exactly one entry is marked.
Some parameter documentations has been truncated, see Anthropic::Models::BrowserStateTabEntry for more details.
|
|
# File 'lib/anthropic/models/browser_state_tab_entry.rb', line 31
|
Instance Attribute Details
#active ⇒ Boolean?
Whether this tab is the active tab after this call. Whenever tabs is
non-empty, exactly one entry is marked active: true.
29 |
# File 'lib/anthropic/models/browser_state_tab_entry.rb', line 29 optional :active, Anthropic::Internal::Type::Boolean |
#tab_id ⇒ String
The caller-assigned identifier for this tab, unique within the inventory.
10 |
# File 'lib/anthropic/models/browser_state_tab_entry.rb', line 10 required :tab_id, String |
#title ⇒ String
The title of the page the tab is showing. May be empty.
16 |
# File 'lib/anthropic/models/browser_state_tab_entry.rb', line 16 required :title, String |
#url ⇒ String
The URL of the page the tab is showing. May be empty.
22 |
# File 'lib/anthropic/models/browser_state_tab_entry.rb', line 22 required :url, String |
Instance Method Details
#to_hash ⇒ {
24 |
# File 'sig/anthropic/models/browser_state_tab_entry.rbs', line 24
def to_hash: -> {
|