Module: Anthropic::Models::ContentBlockSourceContent
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/content_block_source_content.rb,
sig/anthropic/models/content_block_source_content.rbs
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/anthropic/models/content_block_source_content.rb', line 34 def self.new(type:, **args) case type.to_sym when :text Anthropic::TextBlockParam.new(**args) when :image Anthropic::ImageBlockParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam)
|
|
# File 'lib/anthropic/models/content_block_source_content.rb', line 14
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::content_block_source_content]
9 |
# File 'sig/anthropic/models/content_block_source_content.rbs', line 9
def self?.variants: -> ::Array[Anthropic::Models::content_block_source_content]
|