Module: Anthropic::Models::DocumentBlock::Source

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/document_block.rb,
sig/anthropic/models/document_block.rbs

Overview

See Also:

  • Anthropic::Models::DocumentBlock#source

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :data

    @option args [Symbol, :"application/pdf", Symbol, :"text/plain"] :media_type

Returns:

Raises:

  • (ArgumentError)


63
64
65
66
67
68
69
70
71
72
# File 'lib/anthropic/models/document_block.rb', line 63

def self.new(type:, **args)
  case type.to_sym
  when :base64
    Anthropic::Base64PDFSource.new(**args)
  when :text
    Anthropic::PlainTextSource.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

.variantsArray(Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource)



# File 'lib/anthropic/models/document_block.rb', line 47

Instance Method Details

#self?.variants::Array[Anthropic::Models::DocumentBlock::source]

Returns:

  • (::Array[Anthropic::Models::DocumentBlock::source])


39
# File 'sig/anthropic/models/document_block.rbs', line 39

def self?.variants: -> ::Array[Anthropic::Models::DocumentBlock::source]