Module: Anthropic::Models::DocumentBlockParam::Source
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/document_block_param.rb,
sig/anthropic/models/document_block_param.rbs
Overview
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::Base64PDFSource, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource, Anthropic::Models::ContentBlockSource, Anthropic::Models::URLPDFSource)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::Base64PDFSource, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/anthropic/models/document_block_param.rb', line 84 def self.new(type:, **args) case type.to_sym when :base64 Anthropic::Base64PDFSource.new(**args) when :text Anthropic::PlainTextSource.new(**args) when :content Anthropic::ContentBlockSource.new(**args) when :url Anthropic::URLPDFSource.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource, Anthropic::Models::ContentBlockSource, Anthropic::Models::URLPDFSource)
|
|
# File 'lib/anthropic/models/document_block_param.rb', line 64
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::DocumentBlockParam::source]
53 |
# File 'sig/anthropic/models/document_block_param.rbs', line 53
def self?.variants: -> ::Array[Anthropic::Models::DocumentBlockParam::source]
|