Module: Anthropic::Models::Model
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/model.rb,
sig/anthropic/models/model.rbs
Overview
The model that will complete your prompt.
See models for additional details and options.
collapse
- CLAUDE_FABLE_5 =
Next generation of intelligence for the hardest knowledge work and coding problems
:"claude-fable-5"- CLAUDE_MYTHOS_5 =
Most capable model for cybersecurity and biology research
:"claude-mythos-5"- CLAUDE_OPUS_4_8 =
Frontier intelligence for long-running agents and coding
:"claude-opus-4-8"- CLAUDE_OPUS_4_7 =
Frontier intelligence for long-running agents and coding
:"claude-opus-4-7"- CLAUDE_MYTHOS_PREVIEW =
New class of intelligence, strongest in coding and cybersecurity
:"claude-mythos-preview"- CLAUDE_OPUS_4_6 =
Frontier intelligence for long-running agents and coding
:"claude-opus-4-6"- CLAUDE_SONNET_4_6 =
Best combination of speed and intelligence
:"claude-sonnet-4-6"- CLAUDE_HAIKU_4_5 =
Fastest model with near-frontier intelligence
:"claude-haiku-4-5"- CLAUDE_HAIKU_4_5_20251001 =
Fastest model with near-frontier intelligence
:"claude-haiku-4-5-20251001"- CLAUDE_OPUS_4_5 =
Premium model combining maximum intelligence with practical performance
:"claude-opus-4-5"- CLAUDE_OPUS_4_5_20251101 =
Premium model combining maximum intelligence with practical performance
:"claude-opus-4-5-20251101"- CLAUDE_SONNET_4_5 =
High-performance model for agents and coding
:"claude-sonnet-4-5"- CLAUDE_SONNET_4_5_20250929 =
High-performance model for agents and coding
:"claude-sonnet-4-5-20250929"- CLAUDE_OPUS_4_1 =
Exceptional model for specialized complex tasks
:"claude-opus-4-1"- CLAUDE_OPUS_4_1_20250805 =
Exceptional model for specialized complex tasks
:"claude-opus-4-1-20250805"
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(Symbol, String)
47 48 49 |
# File 'lib/anthropic/models/model.rb', line 47 define_sorbet_constant!(:Variants) do T.type_alias { T.any(Anthropic::Model::TaggedSymbol, String) } end |
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::model]
24 |
# File 'sig/anthropic/models/model.rbs', line 24
def self?.variants: -> ::Array[Anthropic::Models::model]
|