Module: Anthropic::Models::RawContentBlockDelta
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/raw_content_block_delta.rb,
sig/anthropic/models/raw_content_block_delta.rbs
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::TextDelta, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::TextDelta, Anthropic::Models::InputJSONDelta, Anthropic::Models::CitationsDelta, Anthropic::Models::ThinkingDelta, Anthropic::Models::SignatureDelta)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::TextDelta, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
Some parameter documentations has been truncated, see Anthropic::Models::RawContentBlockDelta for more details.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/anthropic/models/raw_content_block_delta.rb', line 45 def self.new(type:, **args) case type.to_sym when :text_delta Anthropic::TextDelta.new(**args) when :input_json_delta Anthropic::InputJSONDelta.new(**args) when :citations_delta Anthropic::CitationsDelta.new(**args) when :thinking_delta Anthropic::ThinkingDelta.new(**args) when :signature_delta Anthropic::SignatureDelta.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::TextDelta, Anthropic::Models::InputJSONDelta, Anthropic::Models::CitationsDelta, Anthropic::Models::ThinkingDelta, Anthropic::Models::SignatureDelta)
|
|
# File 'lib/anthropic/models/raw_content_block_delta.rb', line 20
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::raw_content_block_delta]
13 |
# File 'sig/anthropic/models/raw_content_block_delta.rbs', line 13
def self?.variants: -> ::Array[Anthropic::Models::raw_content_block_delta]
|