Class: Anthropic::Models::Skills::SkillVersion
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::Skills::SkillVersion
- Defined in:
- lib/anthropic/models/skills/skill_version.rb,
sig/anthropic/models/skills/skill_version.rbs
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
ISO 8601 timestamp of when the skill was created.
-
#description ⇒ String
Description of the skill version.
-
#id ⇒ String
Unique identifier for this Skill Version.
-
#name ⇒ String
The Skill's immutable kebab-case slug, set at creation from the first upload's SKILL.md frontmatter
name(or its enclosing directory). -
#skill_id ⇒ String
Unique identifier for the skill.
-
#type ⇒ Symbol, :skill_version
Object type.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
29 |
# File 'sig/anthropic/models/skills/skill_version.rbs', line 29
def initialize: (
|
Instance Attribute Details
#created_at ⇒ Time
ISO 8601 timestamp of when the skill was created.
19 |
# File 'lib/anthropic/models/skills/skill_version.rb', line 19 required :created_at, Time |
#description ⇒ String
Description of the skill version.
This is extracted from the SKILL.md file in the skill upload.
27 |
# File 'lib/anthropic/models/skills/skill_version.rb', line 27 required :description, String |
#id ⇒ String
Unique identifier for this Skill Version. The id addresses the version in paths and pins it in references.
13 |
# File 'lib/anthropic/models/skills/skill_version.rb', line 13 required :id, String |
#name ⇒ String
The Skill's immutable kebab-case slug, set at creation from the first upload's
SKILL.md frontmatter name (or its enclosing directory). Every later upload
must resolve to the same value. Also the top-level directory of the Skill's
mounted files and the base name of a downloaded archive.
36 |
# File 'lib/anthropic/models/skills/skill_version.rb', line 36 required :name, String |
#skill_id ⇒ String
Unique identifier for the skill.
The format and length of IDs may change over time.
44 |
# File 'lib/anthropic/models/skills/skill_version.rb', line 44 required :skill_id, String |
#type ⇒ Symbol, :skill_version
Object type.
For Skill Versions, this is always "skill_version".
52 |
# File 'lib/anthropic/models/skills/skill_version.rb', line 52 required :type, const: :skill_version |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/anthropic/models/skills/skill_version.rbs', line 38
def to_hash: -> {
|