Class: Anthropic::Models::ThinkingBlockParam
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Anthropic::Models::ThinkingBlockParam
- Defined in:
- lib/anthropic/models/thinking_block_param.rb,
sig/anthropic/models/thinking_block_param.rbs
Instance Attribute Summary collapse
-
#signature ⇒ String
The
signaturevalue of this thinking block, exactly as returned by the API in a previous response. -
#thinking ⇒ String
The
thinkingtext of this block as returned by the API. - #type ⇒ Symbol, :thinking
Instance Method Summary collapse
-
#initialize(signature:, thinking:, type: :thinking) ⇒ Object
constructor
Some parameter documentations has been truncated, see ThinkingBlockParam for more details.
- #to_hash ⇒ { signature: String, thinking: String, type: :thinking }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(signature:, thinking:, type: :thinking) ⇒ Object
Some parameter documentations has been truncated, see Anthropic::Models::ThinkingBlockParam for more details.
|
|
# File 'lib/anthropic/models/thinking_block_param.rb', line 27
|
Instance Attribute Details
#signature ⇒ String
The signature value of this thinking block, exactly as returned by the API in
a previous response. Used to verify that the block was generated by Claude.
Thinking blocks must be passed back unmodified and in their original order; a
modified block results in a 400 invalid_request_error.
14 |
# File 'lib/anthropic/models/thinking_block_param.rb', line 14 required :signature, String |
#thinking ⇒ String
The thinking text of this block as returned by the API.
20 |
# File 'lib/anthropic/models/thinking_block_param.rb', line 20 required :thinking, String |
#type ⇒ Symbol, :thinking
25 |
# File 'lib/anthropic/models/thinking_block_param.rb', line 25 required :type, const: :thinking |
Instance Method Details
#to_hash ⇒ { signature: String, thinking: String, type: :thinking }
19 |
# File 'sig/anthropic/models/thinking_block_param.rbs', line 19
def to_hash: -> { signature: String, thinking: String, type: :thinking }
|