Module: Anthropic::Models::ToolResultBlockParam::Content::Content

Extended by:
Internal::Type::Union
Defined in:
lib/anthropic/models/tool_result_block_param.rb,
sig/anthropic/models/tool_result_block_param.rbs

Overview

Tool reference block that can be included in tool_result content.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, ...

Creates a new instance of the variant class whose type matches the given value, passing the remaining arguments to its constructor.

Parameters:

  • type (Symbol, String)
  • args (Hash{Symbol=>Object})

    Attributes for the chosen variant.

    @option args [String] :text

    @option args [Anthropic::Models::CacheControlEphemeral, nil] :cache_control Create a cache control breakpoint at this content block.

    @option args [Array<Anthropic::Models::CitationCharLocationParam, Anthropic::Models::CitationPageLocationParam, Anthropic::Models::CitationContentBlockLocationParam, Anthropic::Models::CitationWebSearchResultLocationParam, Anthropic::Models::CitationSearchResultLocationParam>, nil, Anthropic::Models::CitationsConfigParam, Anthropic::Models::CitationsConfigParam, nil] :citations

    @option args [Anthropic::Models::Base64ImageSource, Anthropic::Models::URLImageSource, String, Anthropic::Models::Base64PDFSource, Anthropic::Models::PlainTextSource, Anthropic::Models::ContentBlockSource, Anthropic::Models::URLPDFSource] :source

    @option args [ArrayAnthropic::Models::TextBlockParam] :content

    @option args [String, String, nil] :title

    @option args [String, nil] :context

    @option args [String] :tool_name

Returns:

Raises:

  • (ArgumentError)


96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/anthropic/models/tool_result_block_param.rb', line 96

def self.new(type:, **args)
  case type.to_sym
  when :text
    Anthropic::TextBlockParam.new(**args)
  when :image
    Anthropic::ImageBlockParam.new(**args)
  when :search_result
    Anthropic::SearchResultBlockParam.new(**args)
  when :document
    Anthropic::DocumentBlockParam.new(**args)
  when :tool_reference
    Anthropic::ToolReferenceBlockParam.new(**args)
  else
    raise ArgumentError, "unknown type: #{type}"
  end
end

Instance Method Details

#self?.variants::Array[Anthropic::Models::ToolResultBlockParam::Content::content]

Returns:

  • (::Array[Anthropic::Models::ToolResultBlockParam::Content::content])


62
# File 'sig/anthropic/models/tool_result_block_param.rbs', line 62

def self?.variants: -> ::Array[Anthropic::Models::ToolResultBlockParam::Content::content]