Module: Anthropic::Models::ToolResultBlockParam::Content::Content
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/anthropic/models/tool_result_block_param.rb,
sig/anthropic/models/tool_result_block_param.rbs
Overview
Tool reference block that can be included in tool_result content.
Class Method Summary collapse
-
.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, ...
Creates a new instance of the variant class whose
typematches the given value, passing the remaining arguments to its constructor. - .variants ⇒ Array(Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam, Anthropic::Models::SearchResultBlockParam, Anthropic::Models::DocumentBlockParam, Anthropic::Models::ToolReferenceBlockParam)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.new(type:, **args) ⇒ Anthropic::Models::TextBlockParam, ...
Creates a new instance of the variant class whose type matches the given
value, passing the remaining arguments to its constructor.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/anthropic/models/tool_result_block_param.rb', line 96 def self.new(type:, **args) case type.to_sym when :text Anthropic::TextBlockParam.new(**args) when :image Anthropic::ImageBlockParam.new(**args) when :search_result Anthropic::SearchResultBlockParam.new(**args) when :document Anthropic::DocumentBlockParam.new(**args) when :tool_reference Anthropic::ToolReferenceBlockParam.new(**args) else raise ArgumentError, "unknown type: #{type}" end end |
.variants ⇒ Array(Anthropic::Models::TextBlockParam, Anthropic::Models::ImageBlockParam, Anthropic::Models::SearchResultBlockParam, Anthropic::Models::DocumentBlockParam, Anthropic::Models::ToolReferenceBlockParam)
|
|
# File 'lib/anthropic/models/tool_result_block_param.rb', line 68
|
Instance Method Details
#self?.variants ⇒ ::Array[Anthropic::Models::ToolResultBlockParam::Content::content]
62 |
# File 'sig/anthropic/models/tool_result_block_param.rbs', line 62
def self?.variants: -> ::Array[Anthropic::Models::ToolResultBlockParam::Content::content]
|